@@ -1,6 +1,6 @@
 /*      -*- linux-c -*-
  *
- * (C) Copyright IBM Corp. 2003, 2004
+ * (C) Copyright IBM Corp. 2003, 2004, 2007
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,6 +12,7 @@
  * Author(s):
  *      Peter D Phan <pdphan@us.ibm.com>
  *      Steve Sherman <stevees@us.ibm.com>
+ *	Renier Morales <renier@openhpi.org>
  *
  *     10/13/2004 kouzmich  changed -t option for infinite wait
  *			    added -d option for call saHpiDiscover after saHpiSubscribe
@@ -25,12 +26,14 @@
 
 #include <SaHpi.h>
 #include <oh_utils.h>
+#include <oh_clients.h>
+
+#define OH_SVN_REV "$Revision: 6620 $"
 
 #include <unistd.h>
 
 #define HPI_NSEC_PER_SEC 1000000000LL
 
-char progver[] = "0.2";
 int fdebug = 0;
 
 static void Usage(char **argv)
@@ -61,7 +64,7 @@ int main(int argc, char **argv)
 
 	memset(&rptentry, 0, sizeof(rptentry));
 
-	printf("%s: version %s\n", argv[0], progver); 
+	oh_prog_version(argv[0], OH_SVN_REV);
 
 	while ( (c = getopt( argc, argv,"t:xd?")) != EOF ) {
 		switch(c) {
@@ -170,6 +173,7 @@ int main(int argc, char **argv)
 	printf( "Go and get the event\n");
 	while (1) {
 		rdr.RdrType = SAHPI_NO_RECORD;
+                rptentry.ResourceId = 0;
 
 		rv = saHpiEventGet( sessionid, timeout, &event, &rdr, &rptentry, NULL);
 		if (rv != SA_OK) {
@@ -188,10 +192,20 @@ int main(int argc, char **argv)
 			}
 			break;
 		} else {
-			if (rdr.RdrType == SAHPI_NO_RECORD)
-				oh_print_event(&event, NULL, 4);
-			else 
+			if (rdr.RdrType != SAHPI_NO_RECORD)
 				oh_print_event(&event, &rdr.Entity, 4);
+                        else if (rptentry.ResourceId != 0)
+                                oh_print_event(&event, &rptentry.ResourceEntity, 4);
+                        else {
+                                rptentryid = event.Source;
+                                rv = saHpiRptEntryGet(sessionid, rptentryid, &nextrptentryid, &rptentry);
+                                if(rv == SA_OK)
+                                        oh_print_event(&event, &rptentry.ResourceEntity, 4);
+                                else {
+                                        printf("Wrong resource Id <%d> detected", event.Source);
+                                        oh_print_event(&event, NULL, 4);
+                                }
+                        }
 		}
 	}
 
