@@ -28,6 +28,7 @@
 #include <unistd.h>
 #include <config.h>
 #include <oh_config.h>
+#include <oHpi.h>
 #include <hpi_ui.h>
 #include "hpi_cmd.h"
 
@@ -113,7 +114,9 @@ static ret_code_t help_cmd(void)
 
 static ret_code_t add_config(void)
 {
-#ifndef OH_DAEMON_ENABLED
+#if 0
+// This code needs to call oHpi APIs instead of internal functions
+
         SaErrorT        rv;
         term_def_t      *term;
         struct oh_parsed_config config = {NULL, NULL, 0, 0, 0, 0};
@@ -201,7 +204,7 @@ static ret_code_t moreset(void)
 
         term = get_next_term();
         if (term == NULL) {
-                 if (is_more) val = "NO";
+                 if (is_more) val = "ON";
 		 else val = "OFF";
                 printf("more = %s\n", val);
                 return(HPI_SHELL_OK);
@@ -748,7 +751,7 @@ static ret_code_t show_rdr(void)
                 if (read_file) return(HPI_SHELL_CMD_ERROR);
                 i = get_string_param("RDR Type (s|a|c|w|i|d|f) ==> ",
                         buf, 9);
-                if (i != 0 || strnlen(buf, 3) > 1)
+                if ( (i != 0) || (buf[0] == '\0') || (buf[1] != 0) )
 			return HPI_SHELL_PARM_ERROR;
         } else {
                 memset(buf, 0, 10);
@@ -780,6 +783,17 @@ static ret_code_t show_rdr(void)
         return HPI_SHELL_OK;
 }
 
+static ret_code_t show_ver(void)
+{
+   SaHpiVersionT ver = saHpiVersionGet();
+
+   printf("\nPackage version: %s\n", PACKAGE_VERSION);
+   printf("HPI specification version: SAI_HPI-%c.%02d.%02d\n\n",
+   	  ('A' + (ver >> 16) -1), (ver >> 8) & 0xFF, (ver) & 0xFF);
+
+   return(HPI_SHELL_OK);
+}
+
 static ret_code_t wtd_get(void)
 {
         SaHpiResourceIdT        rptid;
@@ -1159,7 +1173,7 @@ static ret_code_t domain_info(void)
         time2str(info.DatUpdateTimestamp, date, 30);
         printf("    DAT update count: %d   DAT Timestamp : %s\n",
                 info.DatUpdateCount, date);
-        printf("        ActiveAlarms: %d   CriticalAlarms: %d   Major: %d"
+        printf("        ActiveAlarms: %d   CriticalAlarms: %d   Major: %d "
                 "Minor: %d   Limit: %d\n",
                 info.ActiveAlarms, info.CriticalAlarms, info.MajorAlarms,
                 info.MinorAlarms, info.DatUserAlarmLimit);
@@ -1356,6 +1370,8 @@ const char showrdrhelp[] = "showrdr: show resource data record\n"
 const char showrpthelp[] = "showrpt: show resource information\n"
                         "Usage: showrpt [<resource id>]\n"
                         "   or  rpt [<resource id>]";
+const char versionhelp[] = "ver: show HPI specification, package versions\n"
+                        "Usage: ver";
 const char wtdgethelp[] = "wtdget: show watchdog timer\n"
                         "Usage: wtdget <resource id> <watchdogNum>";
 const char wtdresethelp[] = "wtdreset: reset watchdog timer\n"
@@ -1519,6 +1535,7 @@ command_def_t commands[] = {
     { "showinv",        show_inv,       showinvhelp,    MAIN_COM },
     { "showrdr",        show_rdr,       showrdrhelp,    MAIN_COM },
     { "showrpt",        show_rpt,       showrpthelp,    MAIN_COM },
+    { "ver",            show_ver,       versionhelp,    UNDEF_COM },
     { "wtdget",         wtd_get,        wtdgethelp,     MAIN_COM },
     { "wtdreset",       wtd_reset,      wtdresethelp,   MAIN_COM },
     { "wtdset",         wtd_set,        wtdsethelp,     MAIN_COM },
