@@ -12,7 +12,7 @@
  *
  * Authors:
  *     Louis Zhuang <louis.zhuang@linux.intel.com>
- *     Renier Morales <renierm@users.sf.net>
+ *     Renier Morales <renier@openhpi.org>
  */
 
 #ifndef __OH_LOCK_H
@@ -45,7 +45,6 @@ int data_access_block_times(void);
 #define dbg_lock(format, ...)
 #endif
 		 
-#ifdef HAVE_THREAD_SAFE
 /* multi-threading support, use Posix mutex for data access */
 /* initialize mutex used for data locking */
 #include <glib.h>
@@ -78,12 +77,4 @@ extern int lockcount;
                 dbg_lock("%p - released the lock",  g_thread_self());      \
         } while(0)
 
-#else 
-
-#define data_access_lock_init()
-#define data_access_lock()
-#define data_access_unlock()
-
-#endif /*HAVE_THREAD_SAFE*/
-
 #endif /* __OH_LOCK_H */
