@@ -17,9 +17,9 @@
 
 #include <stdlib.h>
 // #include <stdio.h>
+#include <string.h>
 #include <assert.h>
-#include <endian.h>
-#include <byteswap.h>
+#include <glib.h>
 #include "marshal.h"
 
 
@@ -82,7 +82,7 @@ cMarshalType Marshal_Float64Type =
 int
 MarshalByteOrder()
 {
-  if ( __BYTE_ORDER == __LITTLE_ENDIAN )
+  if ( G_BYTE_ORDER == G_LITTLE_ENDIAN )
        return 1;
 
   return 0;
@@ -265,13 +265,12 @@ MarshalSimpleTypes( tMarshalType type, const void *data,
   switch( type )
      {
        case eMtVoid:
-	    return 0;
+            return 0;
 
        case eMtUint8:
        case eMtInt8:
             {
-              tUint8 v = *(const tUint8 *)data;
-              *(tUint8 *)buffer = v;
+              memcpy(buffer, data, sizeof(tUint8));
             }
 
             return sizeof( tUint8 );
@@ -279,8 +278,7 @@ MarshalSimpleTypes( tMarshalType type, const void *data,
        case eMtInt16:
        case eMtUint16:
             {
-              tUint16 v = *(const tUint16 *)data;
-              *(tUint16 *)buffer = v;
+              memcpy(buffer, data, sizeof(tUint16));
             }
 
             return sizeof( tUint16 );
@@ -288,8 +286,7 @@ MarshalSimpleTypes( tMarshalType type, const void *data,
        case eMtUint32:
        case eMtInt32:
             {
-              tUint32 v = *(const tUint32 *)data;
-              *(tUint32 *)buffer = v;
+              memcpy(buffer, data, sizeof(tUint32));
             }
 
             return sizeof( tUint32 );
@@ -297,24 +294,21 @@ MarshalSimpleTypes( tMarshalType type, const void *data,
        case eMtUint64:
        case eMtInt64:
             {
-              tUint64 v = *(const tUint64 *)data;
-              *(tUint64 *)buffer = v;
+              memcpy(buffer, data, sizeof(tUint64));
             }
 
             return sizeof( tUint64 );
 
        case eMtFloat32:
             {
-              tFloat32 v = *(const tFloat32 *)data;
-              *(tFloat32 *)buffer = v;
+              memcpy(buffer, data, sizeof(tFloat32));
             }
 
             return sizeof( tFloat32 );
 
        case eMtFloat64:
             {
-              tFloat64 v = *(const tFloat64 *)data;
-              *(tFloat64 *)buffer = v;
+              memcpy(buffer, data, sizeof(tFloat64));
             }
 
             return sizeof( tFloat64 );
@@ -493,11 +487,13 @@ Marshal( const cMarshalType *type, const void *d, void *b )
 			int array_size = FindArraySize( type, st_type, data );
 
                         // only simple types can be array elements
-                        assert( IsSimpleType( st_type->m_u.m_var_array.m_type->m_type ) );
+                        //assert( IsSimpleType( st_type->m_u.m_var_array.m_type->m_type ) );
 
-                        unsigned char *bb = buffer;
-                        const unsigned char *dd = data + struct_element->m_u.m_struct_element.m_offset;
+                        unsigned char *bb = buffer;                        
+                        const unsigned char *vardata = data + struct_element->m_u.m_struct_element.m_offset;
+                        const unsigned char *dd;
                         tUint32 j;
+                        memcpy(&dd, vardata, sizeof(void *));
 
                         for( j = 0; j < array_size; j++ )
                            {
@@ -611,10 +607,11 @@ DemarshalSimpleTypes( int byte_order, tMarshalType type,
        case eMtInt16:
        case eMtUint16:
             {
-              tUint16 v = *(const tUint16 *)buffer;
+              tUint16 v;
+              memcpy( &v, buffer, sizeof( tUint16 ) );
 
               if ( MarshalByteOrder() != byte_order )
-                   v = bswap_16( v );
+                   v = GUINT16_SWAP_LE_BE( v );
               
               *(tUint16 *)data = v;
             }            
@@ -624,10 +621,11 @@ DemarshalSimpleTypes( int byte_order, tMarshalType type,
        case eMtUint32:
        case eMtInt32:
             {
-              tUint32 v = *(const tUint32 *)buffer;
+              tUint32 v;
+              memcpy( &v, buffer, sizeof( tUint32 ) );
 
               if ( MarshalByteOrder() != byte_order )
-                   v = bswap_32( v );
+                   v = GUINT32_SWAP_LE_BE( v );
 
               *(tUint32 *)data = v;
             }
@@ -637,10 +635,11 @@ DemarshalSimpleTypes( int byte_order, tMarshalType type,
        case eMtUint64:
        case eMtInt64:
             {
-              tUint64 v = *(const tUint64 *)buffer;
+              tUint64 v;
+              memcpy( &v, buffer, sizeof( tUint64 ) );
 
               if ( MarshalByteOrder() != byte_order )
-                   v = bswap_64( v );
+                   v = GUINT64_SWAP_LE_BE( v );
 
               *(tUint64 *)data = v;
             }
@@ -651,10 +650,10 @@ DemarshalSimpleTypes( int byte_order, tMarshalType type,
             {
               // this has been tested for i386 and PPC
               tFloat32Uint32 v;
-              v.m_f32 = *(const tFloat32 *)buffer;
+              memcpy( &(v.m_f32), buffer, sizeof( tFloat32 ) );
 
               if ( MarshalByteOrder() != byte_order )
-                   v.m_u32 = bswap_32( v.m_u32 );
+                   v.m_u32 = GUINT32_SWAP_LE_BE( v.m_u32 );
 
               *(tFloat32 *)data = v.m_f32;
             }
@@ -665,10 +664,10 @@ DemarshalSimpleTypes( int byte_order, tMarshalType type,
             {
               // this has been tested for i386 and PPC
               tFloat64Uint64 v;
-              v.m_f64 = *(const tFloat64 *)buffer;
+              memcpy( &(v.m_f64), buffer, sizeof( tFloat64 ) );
 
               if ( MarshalByteOrder() != byte_order )
-                   v.m_u64 = bswap_64( v.m_u64 );
+                   v.m_u64 = GUINT64_SWAP_LE_BE( v.m_u64 );
 
               *(tFloat64 *)data = v.m_f64;
             }
@@ -760,11 +759,19 @@ Demarshal( int byte_order, const cMarshalType *type,
 			tUint32 array_size = FindArraySize( type, st_type, data );
 
                         // only simple types can be array elements
-                        assert( IsSimpleType( st_type->m_u.m_var_array.m_type->m_type ) );
-
+                        //assert( IsSimpleType( st_type->m_u.m_var_array.m_type->m_type ) );			
+			
                         const unsigned char *bb = buffer;
-                        unsigned char       *dd = data + struct_element->m_u.m_struct_element.m_offset;
+                        const cMarshalType *va_type = st_type->m_u.m_var_array.m_type;
+                        // FIXME: This is a hack! I'm assuming the elements in
+                        // the variable array are structs. That's because this
+                        // is the only instance for which we use var arrays.
+                        unsigned char *dd =
+                        	(unsigned char *)malloc(va_type->m_u.m_struct.m_size*array_size);
+			memset(dd, 0, va_type->m_u.m_struct.m_size*array_size);
+                        unsigned char *vardata = data + struct_element->m_u.m_struct_element.m_offset;
                         tUint32 j;
+                        memcpy(vardata, &dd, sizeof(void *));
 
                         for( j = 0; j < array_size; j++ )
                            {
