@@ -33,14 +33,14 @@ struct oh_client_session {
         GHashTable *connxs; /* Connections for this session (per thread) */
 };
 
-extern GHashTable *domains;
-extern GHashTable *sessions;
-extern GStaticRecMutex sessions_sem;
+extern GHashTable *ohd_domains;
+extern GHashTable *ohd_sessions;
+extern GStaticRecMutex ohd_sessions_sem;
 
 SaErrorT oh_create_connx(SaHpiDomainIdT, pcstrmsock *);
 void oh_delete_connx(pcstrmsock);
 SaErrorT oh_close_connx(SaHpiSessionIdT);
-SaErrorT oh_get_connx(SaHpiSessionIdT, SaHpiSessionIdT *, pcstrmsock *);
+SaErrorT oh_get_connx(SaHpiSessionIdT, SaHpiSessionIdT *, pcstrmsock *, SaHpiDomainIdT *);
 
 SaHpiSessionIdT oh_open_session(SaHpiDomainIdT, SaHpiSessionIdT, pcstrmsock);
 SaErrorT oh_close_session(SaHpiSessionIdT);
