@@ -37,7 +37,7 @@ extern int __ipmi_debug_malloc;
 extern int ipmicmd_mv(struct ohoi_handler *ipmi_handler,
                uchar cmd, uchar netfn, uchar lun, uchar *pdata,
                uchar sdata, uchar *presp, int sresp, int *rlen);
-	       
+
 FILE *trace_msg_file = NULL;
 
 /**
@@ -91,7 +91,9 @@ static void ipmi_domain_fully_up(ipmi_domain_t *domain,
  * could be SMI (local) or LAN.
  *
  **/
-static void *ipmi_open(GHashTable *handler_config)
+static void *ipmi_open(GHashTable *handler_config,
+                       unsigned int hid,
+                       oh_evt_queue *eventq)
 {
         struct oh_handler_state *handler = NULL;
         struct ohoi_handler *ipmi_handler = NULL;
@@ -104,19 +106,23 @@ static void *ipmi_open(GHashTable *handler_config)
         const char *scan_time;
         const char *real_write_fru;
         int rv = 0;
-        int *hid;
-        char *multi_domains;
 	char *trace_file_name;
-
+	/*
         SaHpiTextBufferT        buf = {
                                         .DataType = SAHPI_TL_TYPE_TEXT,
                                         .Language = SAHPI_LANG_ENGLISH,
-                                };
+                                };*/
 
         trace_ipmi("ipmi_open");
         if (!handler_config) {
-                dbg("No config file provided.....ooops!");
+                err("No config file provided.....ooops!");
                 return(NULL);
+        } else if (!hid) {
+                err("Bad handler id passed.");
+                return NULL;
+        } else if (!eventq) {
+                err("No event queue was passed.");
+                return NULL;
         }
 
         name = g_hash_table_lookup(handler_config, "name");
@@ -129,22 +135,22 @@ static void *ipmi_open(GHashTable *handler_config)
         handler = (struct oh_handler_state *)malloc(sizeof(
                         struct oh_handler_state));
 	if (handler == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		return NULL;
 	}
 	memset(handler, 0, sizeof(struct oh_handler_state));
         ipmi_handler = (struct ohoi_handler *)malloc(sizeof(
 					struct ohoi_handler));
         if (ipmi_handler == NULL) {
-                dbg("Out of memory");
+                err("Out of memory");
 		free(handler);
                 return NULL;
         }
 	memset(ipmi_handler, 0, sizeof(struct ohoi_handler));
-	
+
         handler->rptcache = (RPTable *)malloc(sizeof(RPTable));
 	if (handler->rptcache == NULL) {
-		dbg("Out of memory");
+		err("Out of memory");
 		free(handler);
 		free(ipmi_handler);
 		return NULL;
@@ -153,7 +159,9 @@ static void *ipmi_open(GHashTable *handler_config)
 
         handler->data = ipmi_handler;
         handler->config = handler_config;
-	
+        handler->hid = hid;
+        handler->eventq = eventq;
+
         g_static_rec_mutex_init(&(ipmi_handler->ohoih_lock));
 
         snprintf(domain_name, 24, "%s %s", name, addr);
@@ -173,20 +181,22 @@ static void *ipmi_open(GHashTable *handler_config)
         ipmi_handler->openipmi_scan_time = 0;
         ipmi_handler->real_write_fru = 0;
 
-        multi_domains = g_hash_table_lookup(handler_config, "MultipleDomains");
+        /** This code has been commented due to the multi domain changes
+	 ** in the infrastructure. (Renier Morales 11/21/06)
+	multi_domains = g_hash_table_lookup(handler_config, "MultipleDomains");
         if (multi_domains != (char *)NULL) {
-                hid = g_hash_table_lookup(handler_config, "handler-id");
                 if (domain_tag != NULL) {
                         oh_append_textbuffer(&buf, domain_tag);
                 } else {
                         oh_append_textbuffer(&buf, "IPMI Domain");
                 }
 
-                ipmi_handler->did = oh_request_new_domain_aitimeout(*hid, &buf,
+                ipmi_handler->did = oh_request_new_domain_aitimeout(hid, &buf,
                         SAHPI_DOMAIN_CAP_AUTOINSERT_READ_ONLY,
                         SAHPI_TIMEOUT_BLOCK, 0, 0);
         } else
                 ipmi_handler->did = oh_get_default_domain_id();
+	*/
 
         if (timeout != NULL) {
                 ipmi_handler->fullup_timeout = (time_t)strtol(timeout,
@@ -206,7 +216,7 @@ static void *ipmi_open(GHashTable *handler_config)
                                         "entity_root");
 
         if ( !name || !addr || !ipmi_handler->entity_root) {
-                dbg("Problem getting correct required parameters! \
+                err("Problem getting correct required parameters! \
                                 check config file");
                 goto free_and_out;
         } else
@@ -250,7 +260,7 @@ static void *ipmi_open(GHashTable *handler_config)
 
                 tok = g_hash_table_lookup(handler_config, "addr");
                 if (tok == NULL) {
-                        dbg("no ""addr"" token in config file");
+                        err("no ""addr"" token in config file");
                         goto free_and_out;
                 }
 		val = strtok_r(tok, " \t\n", &pptr);
@@ -259,7 +269,7 @@ static void *ipmi_open(GHashTable *handler_config)
 				vals_len += 10;
 				char **nv = malloc(sizeof(char *) * vals_len);
 				if (!nv) {
-					dbg("Out of memory");
+					err("Out of memory");
 					if (argv)
 						free(argv);
 					goto free_and_out;
@@ -274,7 +284,7 @@ static void *ipmi_open(GHashTable *handler_config)
 		}
 
 		if (!argv) {
-                        dbg("""addr"" token in config file was empty");
+                        err("""addr"" token in config file was empty");
 			goto free_and_out;
 		}
 
@@ -284,7 +294,7 @@ static void *ipmi_open(GHashTable *handler_config)
 			rv = ipmi_parse_args2(&curr_arg, argc, argv,
 					      &iargs[curr_iarg]);
 			if (rv) {
-				dbg("Cannot parse connection arguments");
+				err("Cannot parse connection arguments");
 				free(argv);
 				goto free_and_out;
 			}
@@ -298,7 +308,7 @@ static void *ipmi_open(GHashTable *handler_config)
 						 ipmi_handler->ohoi_sel,
 						 &ipmi_handler->cons[i]);
 			if (rv) {
-				dbg("Cannot setup connection");
+				err("Cannot setup connection");
 				for (j=0; j<i; j++)
 					ipmi_free_args(iargs[j]);
 				for (j=0; j<curr_iarg; j++)
@@ -314,7 +324,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 ipmi_handler->islan = strcmp(ipmi_handler->cons[0]->con_type,
 					     "smi") != 0;
 #else
-                dbg("Unsupported IPMI connection method: %s",name);
+                err("Unsupported IPMI connection method: %s",name);
                 goto free_and_out;
 #endif
         } else if (strcmp(name, "smi") == 0) {
@@ -324,7 +334,7 @@ static void *ipmi_open(GHashTable *handler_config)
                                 ipmi_handler->ohoi_sel,
 				&ipmi_handler->cons[0]);
                 if (rv) {
-                        dbg("Cannot setup connection");
+                        err("Cannot setup connection");
                         goto free_and_out;
                 }
 		ipmi_handler->num_cons = 1;
@@ -341,13 +351,13 @@ static void *ipmi_open(GHashTable *handler_config)
                 /* Address */
                 tok = g_hash_table_lookup(handler_config, "addr");
                 if (tok == NULL) {
-                        dbg("no ""addr"" token in config file");
+                        err("no ""addr"" token in config file");
                         goto free_and_out;
                 }
                 trace_ipmi("IPMI LAN Address: %s", tok);
                 struct hostent *ent = gethostbyname(tok);
                 if (!ent) {
-                        dbg("Unable to resolve IPMI LAN address");
+                        err("Unable to resolve IPMI LAN address");
                         goto free_and_out;
                 }
 
@@ -356,7 +366,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 /* Port */
                 tok = g_hash_table_lookup(handler_config, "port");
                 if (tok == NULL) {
-                        dbg("no ""port"" token in config file. set 623");
+                        err("no ""port"" token in config file. set 623");
                         lan_port = 623;
                 } else {
                         lan_port = atoi(tok);
@@ -366,7 +376,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 /* Authentication type */
                 tok = g_hash_table_lookup(handler_config, "auth_type");
                 if (tok == NULL) {
-                        dbg("no ""auth_type"" token in config file. set ""none""");
+                        err("no ""auth_type"" token in config file. set ""none""");
                         auth = IPMI_AUTHTYPE_NONE;
                 } else if (strcmp(tok, "none") == 0) {
                         auth = IPMI_AUTHTYPE_NONE;
@@ -377,7 +387,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 } else if (strcmp(tok, "md5") == 0) {
                         auth = IPMI_AUTHTYPE_MD5;
                 } else {
-                        dbg("Invalid IPMI LAN authenication method: %s", tok);
+                        err("Invalid IPMI LAN authenication method: %s", tok);
                         goto free_and_out;
                 }
 
@@ -386,7 +396,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 /* Priviledge */
                 tok = g_hash_table_lookup(handler_config, "auth_level");
                 if (tok == NULL) {
-                        dbg("no ""auth_level"" token in config file."
+                        err("no ""auth_level"" token in config file."
                                 " set ""admin""");
                         priv = IPMI_PRIVILEGE_ADMIN;
                 } else if (strcmp(tok, "callback") == 0) {
@@ -400,7 +410,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 } else if (strcmp(tok, "oem") == 0) {
                         priv = IPMI_PRIVILEGE_OEM;
                 } else {
-                        dbg("Invalid IPMI LAN authenication method: %s", tok);
+                        err("Invalid IPMI LAN authenication method: %s", tok);
                         goto free_and_out;
                 }
 
@@ -409,7 +419,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 /* User Name */
                 tok = g_hash_table_lookup(handler_config, "username");
                 if (tok == NULL) {
-                        dbg("no ""username"" token in config file");
+                        err("no ""username"" token in config file");
                         strncpy(user, "", 32);
                 } else {
                         strncpy(user, tok, 32);
@@ -419,7 +429,7 @@ static void *ipmi_open(GHashTable *handler_config)
                 /* Password */
                 tok = g_hash_table_lookup(handler_config, "password");
                 if (tok == NULL) {
-                        dbg("no ""password"" token in config file");
+                        err("no ""password"" token in config file");
                         strncpy(passwd, "", 32);
                 } else {
                         strncpy(passwd, tok, 32);
@@ -436,13 +446,13 @@ static void *ipmi_open(GHashTable *handler_config)
                                         ipmi_handler->ohoi_sel,
                                         &ipmi_handler->cons[0]);
                 if (rv) {
-			dbg("ipmi_lan_setup_con rv = %d", rv);
+			err("ipmi_lan_setup_con rv = %d", rv);
                 	goto free_and_out;
 		}
 		ipmi_handler->num_cons = 1;
                 ipmi_handler->islan = 1;
         } else {
-                dbg("Unsupported IPMI connection method: %s",name);
+                err("Unsupported IPMI connection method: %s",name);
                 goto free_and_out;
         }
 
@@ -472,7 +482,7 @@ free_and_out:
 /**
  * ipmi_close: close this instance of ipmi plug-in
  * @hnd: pointer to handler
- *
+ 
  * This functions closes connection with OpenIPMI and frees
  * all allocated events and sensors
  *
@@ -503,9 +513,6 @@ static void ipmi_close(void *hnd)
         oh_flush_rpt(handler->rptcache);
         free(handler->rptcache);
 
-        g_slist_foreach(handler->eventq, (GFunc)free, NULL);
-        g_slist_free(handler->eventq);
-
         free(ipmi_handler);
         free(handler);
 }
@@ -513,28 +520,16 @@ static void ipmi_close(void *hnd)
 /**
  * ipmi_get_event: get events populated earlier by OpenIPMI
  * @hnd: pointer to handler
- * @event: pointer to an openhpi event structure
- * @timeout: time to block
- *
- *
  *
  * Return value: 1 or 0
  **/
-static int ipmi_get_event(void *hnd, struct oh_event *event)
+static int ipmi_get_event(void *hnd)
 {
         struct oh_handler_state *handler = hnd;
         struct ohoi_handler *ipmi_handler = (struct ohoi_handler *)handler->data;
         int sel_select_done = 0;
 
         for (;;) {
-                if(g_slist_length(handler->eventq)>0) {
-                        memcpy(event, handler->eventq->data, sizeof(*event));
-                        event->did = ipmi_handler->did;
-                        g_free(handler->eventq->data);
-                        handler->eventq = g_slist_remove_link(handler->eventq,
-                                        handler->eventq);
-                        return 1;
-                };
 
                 if (sel_select_done) {
                         break;
@@ -601,8 +596,9 @@ int ipmi_discover_resources(void *hnd)
         int was_connected = 0;
         struct ohoi_resource_info       *res_info;
 
-        trace("ipmi discover_resources");
+        dbg("ipmi discover_resources");
 
+	// Look for IPMI events until we get the ipmi_domain_fully_up callback
         time(&tm0);
         while (ipmi_handler->fully_up == 0) {
                 if (!ipmi_handler->connected) {
@@ -611,7 +607,7 @@ int ipmi_discover_resources(void *hnd)
                 }
                 if ((ipmi_handler->connected == 1) && !was_connected) {
                         // set new time stamp. IPMI is alive
-                         was_connected = 1;
+                        was_connected = 1;
                         time(&tm0);
                 }
 
@@ -623,7 +619,7 @@ int ipmi_discover_resources(void *hnd)
 
                 time(&tm);
                 if ((tm - tm0) > ipmi_handler->fullup_timeout) {
-                        dbg("timeout on waiting for discovery. "
+                        err("timeout on waiting for discovery. "
                                 "SDR_read_done = %d;"
                                 "scan_done = %d; mc_count = %d",
                                 ipmi_handler->SDRs_read_done,
@@ -631,13 +627,14 @@ int ipmi_discover_resources(void *hnd)
                                 ipmi_handler->mc_count);
                         return SA_ERR_HPI_NO_RESPONSE;
                 }
-        }
+        } // while (! ipmi_handler->fully_up)
 
+	// BJS: Why are we doing this some more?
         while(rv == 1) {
                 rv = sel_select(ipmi_handler->ohoi_sel, NULL, 0 , NULL, NULL);
         }
         if (rv != 0) {
-                dbg("failed to scan SEL. error = %d", rv);
+                err("failed to scan SEL. error = %d", rv);
                 return SA_ERR_HPI_INTERNAL_ERROR;
         }
 
@@ -647,16 +644,19 @@ int ipmi_discover_resources(void *hnd)
 		return 0;
 	}
 	ipmi_handler->updated = 0;
+	// BJS: Loop over all rpt_entries (doing what?)
         rpt_entry = oh_get_resource_next(handler->rptcache, SAHPI_FIRST_ENTRY);
         while (rpt_entry) {
                 res_info = oh_get_resource_data(handler->rptcache,
                         rpt_entry->ResourceId);
                 trace_ipmi_resources(rpt_entry, res_info);
+		// If this rpt has already been processed, skip it
                 if (res_info->updated == 0) {
                         rpt_entry = oh_get_resource_next(handler->rptcache,
                                 rpt_entry->ResourceId);
                         continue;
                 }
+		// If this rpt has been deleted, skip it
                 if (res_info->deleted) {
 			// We have already sent the event
                         rpt_entry = oh_get_resource_next(handler->rptcache,
@@ -665,16 +665,11 @@ int ipmi_discover_resources(void *hnd)
                 }
                 event = malloc(sizeof(*event));
 		if (event == NULL) {
-			dbg("Out of memory");
+			err("Out of memory");
         		g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
 			return SA_ERR_HPI_OUT_OF_MEMORY;
 		}
                 memset(event, 0, sizeof(*event));
-                event->type = res_info->presence ?
-                        OH_ET_RESOURCE : OH_ET_RESOURCE_DEL;
-                memcpy(&event->u.res_event.entry, rpt_entry,
-                        sizeof(SaHpiRptEntryT));
-                handler->eventq = g_slist_append(handler->eventq, event);
 
                 if (res_info->presence == 1) {
                         /* Add all RDRs of this RPTe */
@@ -682,32 +677,50 @@ int ipmi_discover_resources(void *hnd)
                                                         rpt_entry->ResourceId,
                                                         SAHPI_FIRST_ENTRY);
                         while (rdr_entry) {
-                                event = malloc(sizeof(*event));
-				if (event == NULL) {
-					dbg("Out of memory");
-        				g_static_rec_mutex_unlock(
-						&ipmi_handler->ohoih_lock);
-					return SA_ERR_HPI_OUT_OF_MEMORY;
-				}
-                                memset(event, 0, sizeof(*event));
-                                event->type = OH_ET_RDR;
-                                event->u.rdr_event.parent =
-                                        rpt_entry->ResourceId;
-
-                                memcpy(&event->u.rdr_event.rdr, rdr_entry,
-                                        sizeof(SaHpiRdrT));
-                                handler->eventq =
-                                        g_slist_append(handler->eventq, event);
-
+                                event->rdrs = g_slist_append(event->rdrs,
+                                	g_memdup(rdr_entry, sizeof(SaHpiRdrT)));
                                 rdr_entry = oh_get_rdr_next(handler->rptcache,
                                         rpt_entry->ResourceId,
                                         rdr_entry->RecordId);
                         }
                 }
+
+		SaHpiEventUnionT *u = &event->event.EventDataUnion;
+		if (rpt_entry->ResourceCapabilities & SAHPI_CAPABILITY_FRU) {
+			event->event.EventType = SAHPI_ET_HOTSWAP;
+			if (res_info->presence) {
+				u->HotSwapEvent.HotSwapState =
+					SAHPI_HS_STATE_ACTIVE;
+				u->HotSwapEvent.PreviousHotSwapState =
+					SAHPI_HS_STATE_ACTIVE;
+			} else {
+				u->HotSwapEvent.HotSwapState =
+					SAHPI_HS_STATE_NOT_PRESENT;
+				u->HotSwapEvent.PreviousHotSwapState =
+					SAHPI_HS_STATE_ACTIVE;
+			}
+		} else {
+			event->event.EventType = SAHPI_ET_RESOURCE;
+			if (res_info->presence) {
+				u->ResourceEvent.ResourceEventType =
+					SAHPI_RESE_RESOURCE_ADDED;
+			} else {
+				u->ResourceEvent.ResourceEventType =
+					SAHPI_RESE_RESOURCE_FAILURE;
+			}
+		}
+		event->event.Source = rpt_entry->ResourceId;
+		oh_gettimeofday(&event->event.Timestamp);
+		event->event.Severity = rpt_entry->ResourceSeverity;
+		event->resource = *rpt_entry;
+                event->hid = handler->hid;
+                oh_evt_queue_push(handler->eventq, event);
+
+		// We're now done with this rpt
                 res_info->updated = 0;
                 rpt_entry = oh_get_resource_next(handler->rptcache,
                         rpt_entry->ResourceId);
-        }
+        } // while (rpt_entry)
         g_static_rec_mutex_unlock(&ipmi_handler->ohoih_lock);
         return 0;
 }
@@ -739,14 +752,14 @@ static SaErrorT ipmi_get_el_info(void               *hnd,
         while (0 == ipmi_handler->fully_up) {
                 rv = sel_select(ipmi_handler->ohoi_sel, NULL, 0 , NULL, NULL);
                 if (rv<0) {
-                        dbg("error on waiting for SEL");
+                        err("error on waiting for SEL");
                         return SA_ERR_HPI_INTERNAL_ERROR;
                 }
         }
 
         ohoi_res_info = oh_get_resource_data(handler->rptcache, id);
         if (!(ohoi_res_info->type & OHOI_RESOURCE_MC)) {
-                dbg("BUG: try to get sel in unsupported resource");
+                err("BUG: try to get sel in unsupported resource");
                 return SA_ERR_HPI_INVALID_CMD;
         }
 
@@ -767,7 +780,7 @@ static SaErrorT ipmi_get_el_info(void               *hnd,
 //                                                 (int *)&info->Enabled);
                                                  (int *)(void *)&info->Enabled);
         if (rv != SA_OK) {
-                dbg("couldn't get sel state rv = %d", rv);
+                err("couldn't get sel state rv = %d", rv);
                 return rv;
         }
         info->UserEventMaxSize = 0;
@@ -799,7 +812,7 @@ static int ipmi_set_el_time(void               *hnd,
 
         ohoi_res_info = oh_get_resource_data(handler->rptcache, id);
         if (!(ohoi_res_info->type & OHOI_RESOURCE_MC)) {
-                dbg("BUG: try to get sel in unsupported resource");
+                err("BUG: try to get sel in unsupported resource");
                 return SA_ERR_HPI_INVALID_CMD;
         }
 
@@ -830,7 +843,7 @@ static SaErrorT ipmi_set_sel_state(void      *hnd,
 
         ohoi_res_info = oh_get_resource_data(handler->rptcache, id);
         if (!(ohoi_res_info->type & OHOI_RESOURCE_MC)) {
-                dbg("BUG: try to set sel state in unsupported resource");
+                err("BUG: try to set sel state in unsupported resource");
                 return SA_ERR_HPI_CAPABILITY;
         }
         return ohoi_set_sel_state(ipmi_handler, ohoi_res_info->u.entity.mc_id, enable);
@@ -891,7 +904,7 @@ static int ipmi_get_el_entry(void *hnd, SaHpiResourceIdT id,
 
         ohoi_res_info = oh_get_resource_data(handler->rptcache, id);
         if (!(ohoi_res_info->type & OHOI_RESOURCE_MC)) {
-                dbg("BUG: try to get sel in unsupported resource");
+                err("BUG: try to get sel in unsupported resource");
                 return SA_ERR_HPI_INVALID_CMD;
         }
 
@@ -931,7 +944,7 @@ static int ipmi_get_el_entry(void *hnd, SaHpiResourceIdT id,
                         break;
 
                 case SAHPI_NO_MORE_ENTRIES:
-                        dbg("SEL is empty!");
+                        err("SEL is empty!");
                         if (!event)
                                 return SA_ERR_HPI_INVALID_PARAMS;
 
@@ -979,24 +992,23 @@ static int ipmi_get_el_entry(void *hnd, SaHpiResourceIdT id,
                 myrpt = ohoi_get_resource_by_entityid(handler->rptcache, &et);
 		if (myrpt == NULL) {
 			goto no_rpt;
-		} 
+		}
                 myrdr = ohoi_get_rdr_by_data(handler->rptcache,
                                  myrpt->ResourceId, SAHPI_SENSOR_RDR, &sid);
-                e->u.hpi_event.event.Source = myrpt->ResourceId;
+                e->event.Source = myrpt->ResourceId;
                 if (rptentry) {
                         memcpy(rptentry, myrpt, sizeof (*myrpt));
                 }
                 if (myrdr) {
-                        e->u.hpi_event.event.EventDataUnion.SensorEvent.SensorNum =
-                                             myrdr->RdrTypeUnion.SensorRec.Num;
+                        e->event.EventDataUnion.SensorEvent.SensorNum =
+                        	myrdr->RdrTypeUnion.SensorRec.Num;
 			if (rdr) {
                         	memcpy(rdr, myrdr, sizeof (*myrdr));
 			}
                 }
 no_rpt:
-                memcpy(&entry->Event, &e->u.hpi_event.event,
-                                                   sizeof (SaHpiEventT));
-                free(e);
+                memcpy(&entry->Event, &e->event, sizeof (SaHpiEventT));
+                oh_event_free(e, FALSE);
                 entry->Event.EventType = SAHPI_ET_SENSOR;
                 entry->Timestamp = ipmi_event_get_timestamp(event);
                 return SA_OK;
@@ -1007,7 +1019,7 @@ no_sensor_event:
         entry->Event.Source = SAHPI_UNSPECIFIED_RESOURCE_ID;
 
         if (data_len != 13) {
-                dbg("Strange data len in ipmi event: %d instead of 13\n",
+                err("Strange data len in ipmi event: %d instead of 13\n",
                                   data_len);
                 return SA_ERR_HPI_ERROR;
         }
@@ -1061,7 +1073,7 @@ static SaErrorT ipmi_clear_el(void *hnd, SaHpiResourceIdT id)
 
         ohoi_res_info = oh_get_resource_data(handler->rptcache, id);
         if (!(ohoi_res_info->type & OHOI_RESOURCE_MC)) {
-                dbg("BUG: try to get sel in unsupported resource");
+                err("BUG: try to get sel in unsupported resource");
                 return SA_ERR_HPI_INVALID_CMD;
         }
 
@@ -1070,7 +1082,7 @@ static SaErrorT ipmi_clear_el(void *hnd, SaHpiResourceIdT id)
         rv = ohoi_clear_sel(ohoi_res_info->u.entity.mc_id, ipmi_handler);
 
         if (rv != SA_OK) {
-                dbg("Error in attempting to clear sel");
+                err("Error in attempting to clear sel");
                 return rv;
         }
 
@@ -1095,7 +1107,7 @@ do {                                                                          \
         rdr = oh_get_rdr_by_type(handler->rptcache, id,                       \
                                  SAHPI_SENSOR_RDR, num);                      \
         if (!rdr) {                                                           \
-                dbg("no rdr");                                                \
+                err("no rdr");                                                \
                 return SA_ERR_HPI_NOT_PRESENT;                                \
         }                                                                     \
                                                                               \
@@ -1159,7 +1171,8 @@ static int ipmi_set_sensor_event_enable(void *hnd,
         struct oh_handler_state	*handler = (struct oh_handler_state *)hnd;
         struct ohoi_sensor_info	*sensor_info;
         struct oh_event		*e;
-        SaHpiRdrT		*rdr;
+        SaHpiRdrT		*rdr = NULL;
+        SaHpiRptEntryT		*rpte = NULL;
         SaHpiSensorEnableChangeEventT	*sen_evt;
 
         SENSOR_CHECK(handler, sensor_info, id, num);
@@ -1178,24 +1191,29 @@ static int ipmi_set_sensor_event_enable(void *hnd,
  //       sensor_info->saved_enable = enable;
         e = malloc(sizeof(*e));
         if (!e) {
-                dbg("Out of space");
+                err("Out of space");
                 return IPMI_EVENT_NOT_HANDLED;
         }
+        memset(e, 0, sizeof(*e));
+
+        rpte = oh_get_resource_by_id(handler->rptcache, id);
+        if (rpte) {
+        	e->resource = *rpte;
+        }
 
         rdr = oh_get_rdr_by_type(handler->rptcache, id, SAHPI_SENSOR_RDR, num);
-
         if (!rdr) {
-                dbg("no rdr");
+                err("no rdr");
                 return SA_ERR_HPI_NOT_PRESENT;
-        };
-        memset(e, 0, sizeof(*e));
-        e->type = OH_ET_HPI;
-        e->u.hpi_event.event.Source = id;
-        e->u.hpi_event.event.EventType = SAHPI_ET_SENSOR_ENABLE_CHANGE;
-        e->u.hpi_event.event.Severity = SAHPI_INFORMATIONAL;
-        oh_gettimeofday(&e->u.hpi_event.event.Timestamp);
+        }
+
+        e->event.Source = id;
+        e->event.EventType = SAHPI_ET_SENSOR_ENABLE_CHANGE;
+        e->event.Severity = SAHPI_INFORMATIONAL;
+        oh_gettimeofday(&e->event.Timestamp);
+        e->rdrs = g_slist_append(e->rdrs, g_memdup(rdr, sizeof(SaHpiRdrT)));
 //      e->u.hpi_event.event.Timestamp = SAHPI_TIME_UNSPECIFIED;
-        sen_evt = &(e->u.hpi_event.event.EventDataUnion.SensorEnableChangeEvent);
+        sen_evt = &(e->event.EventDataUnion.SensorEnableChangeEvent);
         sen_evt->SensorNum = num;
         sen_evt->SensorType = rdr->RdrTypeUnion.SensorRec.Type;
         sen_evt->EventCategory = rdr->RdrTypeUnion.SensorRec.Category;
@@ -1203,8 +1221,8 @@ static int ipmi_set_sensor_event_enable(void *hnd,
         sen_evt->SensorEventEnable = sensor_info->enable;
         sen_evt->AssertEventMask = sensor_info->assert;
         sen_evt->DeassertEventMask = sensor_info->deassert;
-
-        handler->eventq = g_slist_append(handler->eventq, e);
+        e->hid = handler->hid;
+        oh_evt_queue_push(handler->eventq, e);
         return SA_OK;
 
 }
@@ -1357,7 +1375,7 @@ static int ipmi_set_sensor_enable(void *hnd, SaHpiResourceIdT id,
 					  sensor_info->support_assert,
 					  sensor_info->support_deassert);
         if (rv != SA_OK) {
-		dbg("ipmi_set_sensor_event_enable = %d", rv);
+		err("ipmi_set_sensor_event_enable = %d", rv);
 		sensor_info->enable = SAHPI_FALSE;
         }
 	sensor_info->sen_enabled = SAHPI_TRUE;
@@ -1389,7 +1407,7 @@ static int ipmi_get_sensor_event_masks(void *hnd,
         if (rv)
                 return rv;
 
-        
+
 	if (sensor_info->sen_enabled) {
 		sensor_info->enable = t_enable;
         	sensor_info->assert = t_assert;
@@ -1414,7 +1432,8 @@ static int ipmi_set_sensor_event_masks(void *hnd, SaHpiResourceIdT id,
         SaHpiEventStateT	t_assert;
         SaHpiEventStateT	t_deassert;
         struct oh_event 	*e;
-        SaHpiRdrT		*rdr;
+        SaHpiRptEntryT		*rpte = NULL;
+        SaHpiRdrT		*rdr = NULL;
         SaHpiSensorEnableChangeEventT	*sen_evt;
 
         SENSOR_CHECK(handler, sensor_info, id, num);
@@ -1443,24 +1462,29 @@ static int ipmi_set_sensor_event_masks(void *hnd, SaHpiResourceIdT id,
         sensor_info->deassert = t_deassert;
         e = malloc(sizeof(*e));
         if (!e) {
-                dbg("Out of space");
+                err("Out of space");
                 return IPMI_EVENT_NOT_HANDLED;
         }
+        memset(e, 0, sizeof(*e));
+
+	rpte = oh_get_resource_by_id(handler->rptcache, id);
+	if (rpte) {
+		e->resource = *rpte;
+	}
 
         rdr = oh_get_rdr_by_type(handler->rptcache, id, SAHPI_SENSOR_RDR, num);
-
         if (!rdr) {
-                dbg("no rdr");
+                err("no rdr");
                 return SA_ERR_HPI_NOT_PRESENT;
-        };
-        memset(e, 0, sizeof(*e));
-        e->type = OH_ET_HPI;
-        e->u.hpi_event.event.Source = id;
-        e->u.hpi_event.event.EventType = SAHPI_ET_SENSOR_ENABLE_CHANGE;
-        e->u.hpi_event.event.Severity = SAHPI_INFORMATIONAL;
-        oh_gettimeofday(&e->u.hpi_event.event.Timestamp);
+        }
+
+        e->event.Source = id;
+        e->event.EventType = SAHPI_ET_SENSOR_ENABLE_CHANGE;
+        e->event.Severity = SAHPI_INFORMATIONAL;
+        oh_gettimeofday(&e->event.Timestamp);
+        e->rdrs = g_slist_append(e->rdrs, g_memdup(rdr, sizeof(SaHpiRdrT)));
 //      e->u.hpi_event.event.Timestamp = SAHPI_TIME_UNSPECIFIED;
-        sen_evt = &(e->u.hpi_event.event.EventDataUnion.SensorEnableChangeEvent);
+        sen_evt = &(e->event.EventDataUnion.SensorEnableChangeEvent);
         sen_evt->SensorNum = num;
         sen_evt->SensorType = rdr->RdrTypeUnion.SensorRec.Type;
         sen_evt->EventCategory = rdr->RdrTypeUnion.SensorRec.Category;
@@ -1468,8 +1492,8 @@ static int ipmi_set_sensor_event_masks(void *hnd, SaHpiResourceIdT id,
         sen_evt->SensorEventEnable = sensor_info->enable;
         sen_evt->AssertEventMask = sensor_info->assert;
         sen_evt->DeassertEventMask = sensor_info->deassert;
-
-        handler->eventq = g_slist_append(handler->eventq, e);
+        e->hid = handler->hid;
+        oh_evt_queue_push(handler->eventq, e);
         return SA_OK;
 }
 
@@ -1506,7 +1530,7 @@ static int ipmi_get_watchdog_info(void *hnd,
          */
         if (ipmi_handler->islan) return(SA_ERR_HPI_UNSUPPORTED_API);
         if (num != SAHPI_DEFAULT_WATCHDOG_NUM) {
-		dbg("num = %d", num);
+		err("num = %d", num);
                 return SA_ERR_HPI_INVALID_PARAMS;
 	}
         rlen = sizeof(response);
@@ -1637,7 +1661,7 @@ static int ipmi_set_watchdog_info(void *hnd,
         if (ipmi_handler->islan) return(SA_ERR_HPI_UNSUPPORTED_API);
 
         if (num != SAHPI_DEFAULT_WATCHDOG_NUM) {
-		dbg("watchdog num = %d", num);
+		err("watchdog num = %d", num);
                 return SA_ERR_HPI_INVALID_PARAMS;
 	}
         /* translate HPI values to IPMI */
@@ -1732,7 +1756,7 @@ static int ipmi_set_watchdog_info(void *hnd,
 
         rv = response[0];  /*completion code*/
 	if (rv != 0) {
-		dbg("wdog_set response: %02x", rv);
+		err("wdog_set response: %02x", rv);
 		OHOI_MAP_ERROR(rv, rv);
 	} else {
 		rv = SA_OK;
@@ -1753,7 +1777,7 @@ static int ipmi_reset_watchdog(void *hnd,
         if (ipmi_handler->islan) return(SA_ERR_HPI_UNSUPPORTED_API);
 
         if (num != SAHPI_DEFAULT_WATCHDOG_NUM) {
-		dbg("watchdog num = %d", num);
+		err("watchdog num = %d", num);
                 return SA_ERR_HPI_INVALID_PARAMS;
 	}
 
@@ -1761,10 +1785,10 @@ static int ipmi_reset_watchdog(void *hnd,
         rv = ipmicmd_mv(ipmi_handler, WATCHDOG_RESET, NETFN_APP, 0,
 		NULL, 0, response, rlen, &rlen);
         if (rv != 0) return(rv);
-	
+
         rv = response[0];  /*completion code*/
 		if (rv != 0) {
-		dbg("wdog_set response: %02x", rv);
+		err("wdog_set response: %02x", rv);
 		OHOI_MAP_ERROR(rv, rv);
 	} else {
 		rv = SA_OK;
@@ -1778,7 +1802,7 @@ void ohoi_set_resource_tag(ipmi_entity_t *entity, void *cb_data)
 {
 //              SaHpiTextBufferT *tag = cb_data;
 //              ipmi_entity_set_entity_id_string(entity, (char *)tag);
-                dbg("New resource Tag set");
+                err("New resource Tag set");
 }
 
 static SaErrorT ipmi_set_res_tag (void                  *hnd,
@@ -1792,11 +1816,11 @@ static SaErrorT ipmi_set_res_tag (void                  *hnd,
 
         res_info = oh_get_resource_data(handler->rptcache, id);
         if (!res_info)
-                        dbg("No private resource info for resource %d", id);
+                        err("No private resource info for resource %d", id);
 
         rpt_entry = oh_get_resource_by_id(handler->rptcache, id);
         if (!rpt_entry) {
-                dbg("No rpt for resource %d?", id);
+                err("No rpt for resource %d?", id);
                 return  SA_ERR_HPI_NOT_PRESENT;
         }
 
@@ -1808,7 +1832,7 @@ static SaErrorT ipmi_set_res_tag (void                  *hnd,
                 rv = ipmi_entity_pointer_cb(res_info->u.entity.entity_id, ohoi_set_resource_tag,
                                     tag->Data);
                 if (rv)
-                        dbg("Error retrieving entity pointer for resource %d",
+                        err("Error retrieving entity pointer for resource %d",
                         rpt_entry->ResourceId);
         }
 
@@ -1835,14 +1859,14 @@ static SaErrorT ipmi_set_res_sev(void                   *hnd,
 
         res_info = oh_get_resource_data(handler->rptcache, res_id);
         if (res_info == NULL) {
-                dbg("Failed to retrieve RPT private data");
+                err("Failed to retrieve RPT private data");
                 return SA_ERR_HPI_NOT_PRESENT;
         }
 
         rpt_entry = oh_get_resource_by_id(handler->rptcache, res_id);
 
         if (!rpt_entry) {
-                dbg("Can't find RPT for resource id: %d", res_id);
+                err("Can't find RPT for resource id: %d", res_id);
                 return  SA_ERR_HPI_NOT_PRESENT;
         }
 
@@ -1858,11 +1882,11 @@ static SaErrorT ipmi_set_res_sev(void                   *hnd,
 }
 
 
-void * oh_open (GHashTable *) __attribute__ ((weak, alias("ipmi_open")));
+void * oh_open (GHashTable *, unsigned int, oh_evt_queue *) __attribute__ ((weak, alias("ipmi_open")));
 
 void * oh_close (void *) __attribute__ ((weak, alias("ipmi_close")));
 
-void * oh_get_event (void *, struct oh_event *)
+void * oh_get_event (void *)
                 __attribute__ ((weak, alias("ipmi_get_event")));
 
 void * oh_discover_resources (void *)
