@@ -13,6 +13,7 @@
  * Authors:
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
  *     Pierre Sangouard  <psangouard@eso-tech.com>
+ *     Andy Cress        <arcress@users.sourceforge.net>
  */
 
 #include <netdb.h>
@@ -129,6 +130,44 @@ VerifyControlAndEnter( void *hnd, SaHpiResourceIdT rid, SaHpiCtrlNumT num,
   return control;
 }
 
+static cIpmiWatchdog *
+VerifyWatchdogAndEnter( void *hnd, SaHpiResourceIdT rid, SaHpiWatchdogNumT num,
+                        cIpmi *&ipmi )
+{
+  ipmi = VerifyIpmi( hnd );
+
+  if ( !ipmi )
+     {
+       return 0;
+     }
+
+  ipmi->IfEnter();
+
+  SaHpiRdrT *rdr = oh_get_rdr_by_type( ipmi->GetHandler()->rptcache,
+                                       rid, SAHPI_WATCHDOG_RDR, num );
+  if ( !rdr )
+     {
+       ipmi->IfLeave();
+       return 0;
+     }
+
+  cIpmiWatchdog *watchdog = (cIpmiWatchdog *)oh_get_rdr_data( ipmi->GetHandler()->rptcache,
+                                                              rid, rdr->RecordId );
+  if ( !watchdog )
+     {
+       ipmi->IfLeave();
+       return 0;
+     }
+
+  if ( !ipmi->VerifyWatchdog( watchdog ) )
+     {
+       ipmi->IfLeave();
+       return 0;
+     }
+
+  return watchdog;
+}
+
 static cIpmiInventory *
 VerifyInventoryAndEnter( void *hnd, SaHpiResourceIdT rid, SaHpiIdrIdT idrid,
                          cIpmi *&ipmi )
@@ -240,10 +279,10 @@ extern "C" {
 // ABI Interface functions
 
 static void *
-IpmiOpen( GHashTable * ) __attribute__((used));
+IpmiOpen( GHashTable *, unsigned int, oh_evt_queue * ) __attribute__((used));
 
 static void *
-IpmiOpen( GHashTable *handler_config )
+IpmiOpen( GHashTable *handler_config, unsigned int hid, oh_evt_queue *eventq )
 {
   // open log
   const char *logfile = 0;
@@ -255,7 +294,7 @@ IpmiOpen( GHashTable *handler_config )
 
   if ( !handler_config )
      {
-       dbg( "No config file provided.....ooops!" );
+       err( "No config file provided.....ooops!" );
        return 0;
      }
 
@@ -299,7 +338,7 @@ IpmiOpen( GHashTable *handler_config )
 
   if ( !handler )
      {
-       dbg("cannot allocate handler");
+       err("cannot allocate handler");
 
        delete ipmi;
 
@@ -312,7 +351,7 @@ IpmiOpen( GHashTable *handler_config )
   handler->rptcache = (RPTable *)g_malloc0( sizeof( RPTable ) );
   if ( !handler->rptcache )
      {
-       dbg("cannot allocate RPT cache");
+       err("cannot allocate RPT cache");
 
        g_free( handler );
 
@@ -324,6 +363,8 @@ IpmiOpen( GHashTable *handler_config )
      }
 
   handler->config   = handler_config;
+  handler->hid = hid;
+  handler->eventq = eventq;
 
   ipmi->SetHandler( handler );
 
@@ -360,7 +401,9 @@ IpmiClose( void *hnd )
      {
        return;
      }
-
+/** Commenting this code block due to the multi-domain changes
+ ** in the infrastructure.
+ ** (Renier Morales 11/21/06)
   if ( ipmi->DomainId() != oh_get_default_domain_id() )
   {
       stdlog << "Releasing domain id " << ipmi->DomainId() << "\n";
@@ -369,7 +412,7 @@ IpmiClose( void *hnd )
 
       if ( rv != SA_OK )
           stdlog << "oh_request_domain_delete error " << rv << "\n";
-  }
+  }*/
 
   ipmi->IfClose();
 
@@ -393,12 +436,13 @@ IpmiClose( void *hnd )
 
 
 static SaErrorT
-IpmiGetEvent( void *, struct oh_event * ) __attribute__((used));
+IpmiGetEvent( void * ) __attribute__((used));
 
 static SaErrorT
-IpmiGetEvent( void *hnd, struct oh_event *event )
+IpmiGetEvent( void *hnd )
 {
   cIpmi *ipmi = VerifyIpmi( hnd );
+  struct oh_event event;
 
   if ( !ipmi )
      {
@@ -407,7 +451,7 @@ IpmiGetEvent( void *hnd, struct oh_event *event )
 
   // there is no need to get a lock because
   // the event queue has its own lock
-  SaErrorT rv = ipmi->IfGetEvent( event );
+  SaErrorT rv = ipmi->IfGetEvent( &event );
 
   return rv;
 }
@@ -434,27 +478,6 @@ IpmiDiscoverResources( void *hnd )
 }
 
 
-static SaErrorT
-IpmiDiscoverDomainResources( void *, SaHpiDomainIdT ) __attribute__((used));
-
-static SaErrorT
-IpmiDiscoverDomainResources( void *hnd, SaHpiDomainIdT did )
-{
-  cIpmi *ipmi = VerifyIpmi( hnd );
-
-  if ( !ipmi )
-     {
-       return SA_ERR_HPI_INTERNAL_ERROR;
-     }
-
-  stdlog << "Dedicated discovery let's go " << hnd << " " << did << "\n";
-
-  SaErrorT rv = ipmi->IfDiscoverResources();
-
-  return rv;
-}
-
-
 static SaErrorT
 IpmiSetResourceTag( void *, SaHpiResourceIdT, SaHpiTextBufferT * ) __attribute__((used));
 
@@ -1471,23 +1494,82 @@ IpmiSetResetState( void *hnd,
   return rv;
 }
 
+static SaErrorT
+IpmiGetWatchdogInfo(void *,
+                    SaHpiResourceIdT,
+                    SaHpiWatchdogNumT,
+                    SaHpiWatchdogT *) __attribute__((used));
+
+static SaErrorT
+IpmiGetWatchdogInfo(void *hnd,
+                    SaHpiResourceIdT  id,
+                    SaHpiWatchdogNumT num,
+                    SaHpiWatchdogT    *watchdog)
+{
+  cIpmi *ipmi = 0;
+  cIpmiWatchdog *wd = VerifyWatchdogAndEnter( hnd, id, num, ipmi );
+  if ( !wd ) return SA_ERR_HPI_NOT_PRESENT;
+
+  SaErrorT rv = wd->GetWatchdogInfo( *watchdog );
+  ipmi->IfLeave();
+  return rv; 
+}
+
+static SaErrorT
+IpmiSetWatchdogInfo(void *,
+                    SaHpiResourceIdT,
+                    SaHpiWatchdogNumT,
+                    SaHpiWatchdogT *) __attribute__((used));
+
+static SaErrorT
+IpmiSetWatchdogInfo(void *hnd,
+                    SaHpiResourceIdT  id,
+                    SaHpiWatchdogNumT num,
+                    SaHpiWatchdogT    *watchdog)
+{
+  cIpmi *ipmi = 0;
+  cIpmiWatchdog *wd = VerifyWatchdogAndEnter( hnd, id, num, ipmi );
+  if ( !wd ) return SA_ERR_HPI_NOT_PRESENT;
+
+  SaErrorT rv = wd->SetWatchdogInfo( *watchdog );
+  ipmi->IfLeave();
+  return rv; 
+}
+
+static SaErrorT
+IpmiResetWatchdog(void *,
+                  SaHpiResourceIdT,
+                  SaHpiWatchdogNumT) __attribute__((used));
+
+static SaErrorT
+IpmiResetWatchdog(void *hnd,
+                  SaHpiResourceIdT  id,
+                  SaHpiWatchdogNumT num)
+{
+  cIpmi *ipmi = 0;
+  cIpmiWatchdog *wd = VerifyWatchdogAndEnter( hnd, id, num, ipmi );
+  if ( !wd ) return SA_ERR_HPI_NOT_PRESENT;
+
+  SaErrorT rv = wd->ResetWatchdog();
+  ipmi->IfLeave();
+  return rv; 
+}
+
+
 } // new plugin_loader
 
 extern "C" {
 
-void * oh_open (GHashTable *) __attribute__ ((weak, alias("IpmiOpen")));
+void * oh_open (GHashTable *, unsigned int, oh_evt_queue *) __attribute__ ((weak, alias("IpmiOpen")));
 
 void * oh_close (void *) __attribute__ ((weak, alias("IpmiClose")));
 
-void * oh_get_event (void *, struct oh_event *)
+void * oh_get_event (void *)
                 __attribute__ ((weak, alias("IpmiGetEvent")));
 
 void * oh_discover_resources (void *)
                 __attribute__ ((weak, alias("IpmiDiscoverResources")));
 
-void * oh_discover_domain_resource (void *)
-                __attribute__ ((weak, alias("IpmiDiscoverDomainResources")));
-
 void * oh_set_resource_tag (void *, SaHpiResourceIdT, SaHpiTextBufferT *)
                 __attribute__ ((weak, alias("IpmiSetResourceTag")));
 
@@ -1638,6 +1720,14 @@ void * oh_get_reset_state (void *, SaHpiResourceIdT, SaHpiResetActionT *)
 void * oh_set_reset_state (void *, SaHpiResourceIdT, SaHpiResetActionT)
                 __attribute__ ((weak, alias("IpmiSetResetState")));
 
+void * oh_get_watchdog_info (void *, SaHpiResourceIdT, SaHpiWatchdogNumT,
+                             SaHpiWatchdogT *)
+                __attribute__ ((weak, alias("IpmiGetWatchdogInfo")));
+void * oh_set_watchdog_info (void *, SaHpiResourceIdT, SaHpiWatchdogNumT,
+                             SaHpiWatchdogT *)
+                __attribute__ ((weak, alias("IpmiSetWatchdogInfo")));
+void * oh_reset_watchdog (void *, SaHpiResourceIdT , SaHpiWatchdogNumT )
+                __attribute__ ((weak, alias("IpmiResetWatchdog")));
 }
 
 
@@ -1794,6 +1884,9 @@ cIpmi::AllocConnection( GHashTable *handler_config )
      }
 
   m_own_domain = false;
+  /** This code block has been commented out due to the
+   ** multi-domain changes in the infrastructure.
+   ** (Renier Morales 11/21/06)
   const char *create_own_domain = (const char *)g_hash_table_lookup(handler_config, "MultipleDomains");
   if ((create_own_domain != (char *)NULL)
       && ((strcmp(create_own_domain, "YES") == 0)
@@ -1813,7 +1906,7 @@ cIpmi::AllocConnection( GHashTable *handler_config )
               m_domain_tag.SetAscii(domain_tag, SAHPI_TL_TYPE_TEXT, SAHPI_LANG_ENGLISH);
           }
       }
-  }
+  }*/
 
   m_insert_timeout = GetTimeout( handler_config, "InsertTimeout", SAHPI_TIMEOUT_IMMEDIATE );
   m_extract_timeout = GetTimeout( handler_config, "ExtractTimeout", SAHPI_TIMEOUT_IMMEDIATE );
@@ -1970,13 +2063,10 @@ cIpmi::AddHpiEvent( oh_event *event )
 {
   m_event_lock.Lock();
 
-  event->did = m_did;
-
   if ( m_handler )
   {
-    m_handler->eventq = g_slist_append( m_handler->eventq, event );
-
-    oh_wake_event_thread(SAHPI_FALSE);
+    event->hid = m_handler->hid;
+    oh_evt_queue_push(m_handler->eventq, event);
   }
 
   m_event_lock.Unlock();
@@ -2098,13 +2188,13 @@ cIpmi::IfOpen( GHashTable *handler_config )
 
   if ( !entity_root )
      {
-       dbg( "entity_root is missing in config file" );
+       err( "entity_root is missing in config file" );
        return false;
      }
 
   if ( !m_entity_root.FromString( entity_root ) )
      {
-       dbg( "cannot decode entity path string" );
+       err( "cannot decode entity path string" );
        return false;
      }
 
@@ -2163,14 +2253,6 @@ cIpmi::IfGetEvent( oh_event *event )
 
   m_event_lock.Lock();
 
-  if ( g_slist_length( m_handler->eventq ) > 0 )
-     {
-       memcpy( event, m_handler->eventq->data, sizeof( oh_event ) );
-       g_free( m_handler->eventq->data );
-       m_handler->eventq = g_slist_remove_link( m_handler->eventq, m_handler->eventq );
-       rv = 1;
-     }
-
   m_event_lock.Unlock();
 
   return rv;
@@ -2212,22 +2294,6 @@ cIpmi::IfSetResourceTag( cIpmiResource *ent, SaHpiTextBufferT *tag )
   oh_add_resource(ent->Domain()->GetHandler()->rptcache,
                     rptentry, ent, 1);
 
-  // send update event
-  struct oh_event *e = (struct oh_event *)g_malloc0( sizeof( struct oh_event ) );
-
-  if ( !e )
-     {
-       stdlog << "out of space !\n";
-       return SA_ERR_HPI_OUT_OF_SPACE;
-     }
-
-  memset( e, 0, sizeof( struct oh_event ) );
-  e->type               = OH_ET_RESOURCE;
-  e->u.res_event.entry = *rptentry;
-
-  stdlog << "IfSetResourceTag OH_ET_RESOURCE Event resource " << ent->m_resource_id << "\n";
-  AddHpiEvent( e );
-
   return SA_OK;
 }
 
@@ -2246,22 +2312,6 @@ cIpmi::IfSetResourceSeverity( cIpmiResource *ent, SaHpiSeverityT sev )
   oh_add_resource(ent->Domain()->GetHandler()->rptcache,
                     rptentry, ent, 1);
 
-  // send update event
-  struct oh_event *e = (struct oh_event *)g_malloc0( sizeof( struct oh_event ) );
-
-  if ( !e )
-     {
-       stdlog << "out of space !\n";
-       return SA_ERR_HPI_OUT_OF_SPACE;
-     }
-
-  memset( e, 0, sizeof( struct oh_event ) );
-  e->type               = OH_ET_RESOURCE;
-  e->u.res_event.entry = *rptentry;
-
-  stdlog << "IfSetResourceSeverity OH_ET_RESOURCE Event resource " << ent->m_resource_id << "\n";
-  AddHpiEvent( e );
-
   return SA_OK;
 }
 
