@@ -324,12 +324,12 @@ cIpmiMcThread::Discover( cIpmiMsg *get_device_id_rsp )
        return;
      }
 
-  m_mc->CheckAtca();
+  m_mc->CheckTca();
 
-  if ( m_domain->IsAtca() )
+  if ( m_domain->IsTca() )
   {
       // If board is not ATCA, just give up
-      if (!m_mc->IsAtcaBoard())
+      if (!m_mc->IsTcaMc())
       {
           m_mc->Cleanup();
           delete m_mc;
@@ -516,6 +516,25 @@ void
 cIpmiMcThread::HandleHotswapEvent( cIpmiSensorHotswap *sensor,
                                    cIpmiEvent *event )
 {
+  tIpmiFruState current_state = (tIpmiFruState)(event->m_data[10] & 0x0f);
+  tIpmiFruState prev_state    = (tIpmiFruState)(event->m_data[11] & 0x0f);
+  unsigned int fru_id         = event->m_data[12] & 0xff;
+
+  stdlog << "hot swap event at MC " << m_addr << ", sensor " << sensor->Num() << ",FRU " << fru_id << ",M" << (int)prev_state << " -> M"
+         << (int)current_state << ".\n";
+
+  if (sensor->Resource()->GetHotswapSensor() != sensor)
+  {
+        stdlog << "WARNING: sensor NOT resource hot swap sensor, discard event\n";
+        return;
+  }
+
+  if (sensor->Resource()->FruId() != fru_id)
+  {
+        stdlog << "WARNING: FRU id NOT resource FRU id, discard event\n";
+        return;
+  }
+
   // remove old task
   if (    ( m_mc  && (m_properties & dIpmiMcThreadPollAliveMc ) )
        || ( !m_mc && (m_properties & dIpmiMcThreadPollDeadMc ) ) )
@@ -524,12 +543,6 @@ cIpmiMcThread::HandleHotswapEvent( cIpmiSensorHotswap *sensor,
        RemMcTask( m_mc );
      }
 
-  tIpmiFruState current_state = (tIpmiFruState)(event->m_data[10] & 0x0f);
-  tIpmiFruState prev_state    = (tIpmiFruState)(event->m_data[11] & 0x0f);
-
-  stdlog << "hot swap event at MC " << m_addr << " M" << (int)prev_state << " -> M" 
-         << (int)current_state << ".\n";
-
   sensor->Resource()->PicmgFruState() = current_state;
   sensor->HandleEvent( event );
 
