@@ -1,6 +1,7 @@
 /*
  *
  * Copyright (c) 2003,2004 by FORCE Computers.
+ * Copyright (c) 2007 by ESO Technologies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -11,6 +12,7 @@
  *
  * Authors:
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
+ *     Pierre Sangouard  <psangouard@eso-tech.com>
  */
 
 #include <stdio.h>
@@ -86,7 +88,7 @@ cIpmiLog::Open( int properties, const char *filename, int max_log_files )
        // find a new one or the oldes logfile
        for( i = 0; i < max_log_files; i++ )
           {
-            sprintf( tf, "%s%02d.log", filename, i );
+            snprintf( tf, sizeof(tf), "%s%02d.log", filename, i );
 
             if ( file[0] == 0 )
                  strcpy( file, tf );
@@ -189,7 +191,11 @@ cIpmiLog::Start()
 
 	    char b[dDateTimeStringSize+5];
             IpmiDateTimeToString( tv.tv_sec, b );
-	    sprintf( b + dDateTimeStringSize - 1, ".%03ld ", tv.tv_usec / 1000 );
+#if defined(__sparc) || defined(__sparc__)
+	    snprintf( b + dDateTimeStringSize - 1, 6, ".%03ld ", (long)tv.tv_usec / 1000 );
+#else
+	    snprintf( b + dDateTimeStringSize - 1, 6, ".%03ld ", tv.tv_usec / 1000 );
+#endif
 
 	    Output( b );
 	  }
@@ -214,7 +220,7 @@ cIpmiLog::operator<<( unsigned char c )
   Start();
 
   char b[5];
-  sprintf( b, "0x%02x", c );
+  snprintf( b, sizeof(b), "0x%02x", c );
 
   Output( b );
 
@@ -228,7 +234,7 @@ cIpmiLog::operator<<( int i )
   Start();
 
   char b[20];
-  sprintf( b, "%d", i );
+  snprintf( b, sizeof(b), "%d", i );
   Output( b );
 
   return *this;
@@ -243,9 +249,9 @@ cIpmiLog::operator<<( unsigned int i )
   char b[20];
 
   if ( m_hex )
-       sprintf( b, "0x%08x", i );
+       snprintf( b, sizeof(b), "0x%08x", i );
   else
-       sprintf( b, "%u", i );
+       snprintf( b, sizeof(b), "%u", i );
 
   Output( b );
 
@@ -259,7 +265,7 @@ cIpmiLog::operator<<( double d )
   Start();
   
   char b[20];
-  sprintf( b, "%f", d );
+  snprintf( b, sizeof(b), "%f", d );
   Output( b );
 
   return *this;  
@@ -343,7 +349,7 @@ cIpmiLog::Hex( const unsigned char *data, int size )
 {
   char str[256];
   char *s = str;
-  int i;
+  int i, remaining;
 
   for( i = 0; i < size; i++ )
      {
@@ -352,8 +358,9 @@ cIpmiLog::Hex( const unsigned char *data, int size )
             Log( "%s\n", str );
             s = str;
           }
-
-       s += sprintf( s, " %02x", *data++ );
+       remaining = sizeof(str) - (s - str);
+       if (remaining > 0)
+          s += snprintf( s, remaining, " %02x", *data++ );
      }
 
   if ( s != str )
