@@ -305,27 +305,8 @@ cIpmiSensor::CreateRdr( SaHpiRptEntryT &resource, SaHpiRdrT &rdr )
   if ( cIpmiRdr::CreateRdr( resource, rdr ) == false )
        return false;
 
-  if (    !(resource.ResourceCapabilities & SAHPI_CAPABILITY_RDR)
-       || !(resource.ResourceCapabilities & SAHPI_CAPABILITY_SENSOR ) )
-     {
-       // update resource
-       resource.ResourceCapabilities |= SAHPI_CAPABILITY_RDR|SAHPI_CAPABILITY_SENSOR;
-
-       struct oh_event *e = (struct oh_event *)g_malloc0( sizeof( struct oh_event ) );
-
-       if ( !e )
-          {
-            stdlog << "out of space !\n";
-            return false;
-          }
-
-       memset( e, 0, sizeof( struct oh_event ) );
-       e->type              = OH_ET_RESOURCE;
-       e->u.res_event.entry = resource;
-
-       stdlog << "cIpmiSensor::CreateRdr OH_ET_RESOURCE Event resource " << resource.ResourceId << "\n";
-       m_mc->Domain()->AddHpiEvent( e );
-     }
+  // update resource
+  resource.ResourceCapabilities |= SAHPI_CAPABILITY_RDR|SAHPI_CAPABILITY_SENSOR;
 
   // sensor record
   SaHpiSensorRecT &rec = rdr.RdrTypeUnion.SensorRec;
@@ -697,49 +678,38 @@ cIpmiSensor::CreateEnableChangeEvent()
      }
 
   oh_event *e = (oh_event *)g_malloc0( sizeof( struct oh_event ) );
-  if ( !e )
-     {
-       stdlog << "CreateEnableChangeEvent: out of space !\n";
-       return;
-     }
-
-  memset( e, 0, sizeof( struct oh_event ) );
   
-  e->type = OH_ET_HPI;
-
-  oh_hpi_event &ohpi_event = e->u.hpi_event;
+  e->event.EventType = SAHPI_ET_SENSOR_ENABLE_CHANGE;
 
   SaHpiRptEntryT *rptentry = oh_get_resource_by_id( res->Domain()->GetHandler()->rptcache, res->m_resource_id );
   SaHpiRdrT *rdrentry = oh_get_rdr_by_id( res->Domain()->GetHandler()->rptcache, res->m_resource_id, m_record_id );
 
   if ( rptentry )
-      ohpi_event.res = *rptentry;
+      e->resource = *rptentry;
   else
-      ohpi_event.res.ResourceCapabilities = 0;
+      e->resource.ResourceCapabilities = 0;
 
   if ( rdrentry )
-      ohpi_event.rdr = *rdrentry;
+      e->rdrs = g_slist_append(e->rdrs, g_memdup(rdrentry, sizeof(SaHpiRdrT)));
   else
-      ohpi_event.rdr.RdrType = SAHPI_NO_RECORD;
+      e->rdrs = NULL;
 
   // hpi event
-  SaHpiEventT &hpie = ohpi_event.event;
-
-  hpie.Source    = res->m_resource_id;
-  hpie.EventType = SAHPI_ET_SENSOR_ENABLE_CHANGE;
-  hpie.Severity  = SAHPI_INFORMATIONAL;
+  e->event.Source    = res->m_resource_id;
+  e->event.EventType = SAHPI_ET_SENSOR_ENABLE_CHANGE;
+  e->event.Severity  = SAHPI_INFORMATIONAL;
   
-  oh_gettimeofday(&hpie.Timestamp);
+  oh_gettimeofday(&e->event.Timestamp);
   
   // sensor enable event
-  SaHpiSensorEnableChangeEventT &se = hpie.EventDataUnion.SensorEnableChangeEvent;
-  se.SensorNum     = m_num;
-  se.SensorType    = HpiSensorType(SensorType());
-  se.EventCategory = HpiEventCategory(EventReadingType());
-  se.SensorEnable  = m_enabled;
-  se.SensorEventEnable = m_events_enabled;
-  se.AssertEventMask   = m_current_hpi_assert_mask;
-  se.DeassertEventMask = m_current_hpi_deassert_mask;
+  SaHpiSensorEnableChangeEventT *se = &e->event.EventDataUnion.SensorEnableChangeEvent;
+  se->SensorNum     = m_num;
+  se->SensorType    = HpiSensorType(SensorType());
+  se->EventCategory = HpiEventCategory(EventReadingType());
+  se->SensorEnable  = m_enabled;
+  se->SensorEventEnable = m_events_enabled;
+  se->AssertEventMask   = m_current_hpi_assert_mask;
+  se->DeassertEventMask = m_current_hpi_deassert_mask;
   
   stdlog << "cIpmiSensor::CreateEnableChangeEvent OH_ET_HPI Event enable change resource " << res->m_resource_id << "\n";
   m_mc->Domain()->AddHpiEvent( e );
@@ -806,33 +776,23 @@ cIpmiSensor::HandleEvent( cIpmiEvent *event )
   stdlog << "reading event.\n";
 
   oh_event *e = (oh_event *)g_malloc0( sizeof( struct oh_event ) );
-  if ( !e )
-     {
-       stdlog << "out of space !\n";
-       return;
-     }
-
-  memset( e, 0, sizeof( struct oh_event ) );
-  e->type = OH_ET_HPI;
-
-  oh_hpi_event &hpi_event = e->u.hpi_event;
 
   rptentry = oh_get_resource_by_id( res->Domain()->GetHandler()->rptcache, res->m_resource_id );
   rdrentry = oh_get_rdr_by_id( res->Domain()->GetHandler()->rptcache, res->m_resource_id, m_record_id );
 
   if ( rptentry )
-      hpi_event.res = *rptentry;
+      e->resource = *rptentry;
   else
-      hpi_event.res.ResourceCapabilities = 0;
+      e->resource.ResourceCapabilities = 0;
 
   if ( rdrentry )
-      hpi_event.rdr = *rdrentry;
+      e->rdrs = g_slist_append(e->rdrs, g_memdup(rdrentry, sizeof(SaHpiRdrT)));
   else
-      hpi_event.rdr.RdrType = SAHPI_NO_RECORD;
+      e->rdrs = NULL;
 
   // hpi event
-  SaHpiEventT &he = hpi_event.event;
 
+  SaHpiEventT &he = e->event;
   int rv = CreateEvent( event, he );
 
   if ( rv != SA_OK )
