@@ -40,7 +40,7 @@
 
 
 /* Include files */
-#include <oa_soap_callsupport.h>
+#include "oa_soap_callsupport.h"
 
 
 /* Data types used to help us be more consistent with the WSDL description */
@@ -167,6 +167,67 @@ typedef unsigned char byte;
                         "<hpoa:bayNumber>%d</hpoa:bayNumber>" \
                         "</hpoa:getBladeMpInfo>\n"
 
+#define GET_THERMAL_SUBSYSTEM_INFO \
+                        "<hpoa:getThermalSubsystemInfo>" \
+                        "</hpoa:getThermalSubsystemInfo>\n"
+
+#define GET_FAN_ZONE_ARRAY \
+                        "<hpoa:getFanZoneArray>" \
+                        "<hpoa:bayArray>%s</hpoa:bayArray>" \
+                        "</hpoa:getFanZoneArray>\n"
+
+#define BAY             "<hpoa:bay>%d</hpoa:bay>"
+
+#define GET_ENCLOSURE_STATUS \
+                        "<hpoa:getEnclosureStatus>" \
+                        "</hpoa:getEnclosureStatus>\n"
+
+#define GET_POWER_SUPPLY_STATUS \
+                        "<hpoa:getPowerSupplyStatus>" \
+                        "<hpoa:bayNumber>%d</hpoa:bayNumber>" \
+                        "</hpoa:getPowerSupplyStatus>\n"
+
+#define GET_LCD_INFO \
+                        "<hpoa:getLcdInfo>" \
+                        "</hpoa:getLcdInfo>\n"
+
+#define GET_LCD_STATUS \
+                        "<hpoa:getLcdStatus>" \
+                        "</hpoa:getLcdStatus>\n"
+
+#define GET_BLADE_THERMAL_INFO_ARRAY \
+                        "<hpoa:getBladeThermalInfoArray>" \
+                        "<hpoa:bayNumber>%d</hpoa:bayNumber>" \
+                        "</hpoa:getBladeThermalInfoArray>\n"
+
+#define SET_ENCLOSURE_UID \
+                        "<hpoa:setEnclosureUid>" \
+                        "<hpoa:uid>%s</hpoa:uid>" \
+                        "</hpoa:setEnclosureUid>\n"
+
+#define SET_OA_UID \
+                        "<hpoa:setOaUid>" \
+                        "<hpoa:bayNumber>%d</hpoa:bayNumber>" \
+                        "<hpoa:uid>%s</hpoa:uid>" \
+                        "</hpoa:setOaUid>\n"
+
+#define SET_BLADE_UID \
+                        "<hpoa:setBladeUid>" \
+                        "<hpoa:bayNumber>%d</hpoa:bayNumber>" \
+                        "<hpoa:uid>%s</hpoa:uid>" \
+                        "</hpoa:setBladeUid>\n"
+
+#define SET_INTERCONNECT_TRAY_UID \
+                        "<hpoa:setInterconnectTrayUid>" \
+                        "<hpoa:bayNumber>%d</hpoa:bayNumber>" \
+                        "<hpoa:uid>%s</hpoa:uid>" \
+                        "</hpoa:setInterconnectTrayUid>\n"
+
+#define SET_LCD_BUTTON_LOCK \
+			"<hpoa:setLcdButtonLock>" \
+			"<hpoa:buttonLock>%d</hpoa:buttonLock>" \
+			"</hpoa:setLcdButtonLock>\n"
+
 /* Enumerated types used for specific SOAP commands */
 OA_SOAP_ENUM(hpoa_boolean,
         HPOA_FALSE,
@@ -504,6 +565,13 @@ OA_SOAP_ENUM(powerControl,
         COLD_BOOT,
         RESET)
 
+#define UID_CONTROL_LENGTH    15      /* Max length of these enums + 1 */
+OA_SOAP_ENUM(uidControl,
+        UID_CMD_TOGGLE,
+        UID_CMD_ON,
+        UID_CMD_OFF,
+        UID_CMD_BLINK)
+
 OA_SOAP_ENUM(eventType,
         EVENT_HEARTBEAT,
         EVENT_ENC_STATUS,
@@ -787,14 +855,11 @@ struct bladeNicInfo
         char *macAddress;
 };
 
-#if 0                                   /* TODO: This doesn't work yet */
-struct extraData
+struct extraDataInfo
 {
-        char *item;
         char *name;
-        char *mixed;
+        char *value;
 };
-#endif
 
 struct bladeInfo
 {
@@ -823,10 +888,7 @@ struct bladeInfo
         short mmDepth;
         int deviceId;
         int productId;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 /* Structures that supply information to OA SOAP calls */
@@ -854,7 +916,7 @@ struct diagnosticChecks
 
 struct diagnosticData
 {
-        enum diagnosticStatus item;
+        enum diagnosticStatus value;
         char *name;
 };
 
@@ -870,11 +932,8 @@ struct bladeStatus
         enum uidStatus uid;
         int powerConsumed;
         struct diagnosticChecks diagnosticChecks;
-#if 0
         xmlNode *diagnosticChecksEx;    /* Items are struct diagnosticData */
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getBladeStatus
@@ -887,10 +946,7 @@ struct syslog
         byte bayNumber;
         int syslogStrlen;
         char *logContents;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct encLink
@@ -902,20 +958,14 @@ struct encLink
         char *enclosureName;
         char *url;
         enum hpoa_boolean local;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct rackTopology
 {
         char *ruid;
         xmlNode *enclosures;            /* Items are struct encLink */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct enclosureStatus
@@ -924,11 +974,8 @@ struct enclosureStatus
         enum uidStatus uid;
         enum wizardStatus wizardStatus;
         struct diagnosticChecks diagnosticChecks;
-#if 0
         xmlNode *diagnosticChecksEx;    /* Items are struct diagnosticData */
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct enclosureInfo
@@ -959,10 +1006,7 @@ struct enclosureInfo
         short mmDepth;
         char *pduPartNumber;
         char *pduSparePartNumber;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct oaStatus
@@ -975,11 +1019,8 @@ struct oaStatus
         byte restartCause;
         enum hpoa_boolean oaRedundancy;
         struct diagnosticChecks diagnosticChecks;
-#if 0
         xmlNode *diagnosticChecksEx;    /* Items are struct diagnosticData */
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getOaStatus
@@ -1003,10 +1044,7 @@ struct oaInfo
         short mmHeight;
         short mmWidth;
         short mmDepth;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getOaInfo
@@ -1033,10 +1071,7 @@ struct bladeMpInfo
         char *loginUrl;
         char *ircFullUrl;
         char *remoteSerialUrl;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct bladeMezzSlotPort
@@ -1044,10 +1079,7 @@ struct bladeMezzSlotPort
         byte slotNumber;
         byte interconnectTrayBayNumber;
         byte interconnectTrayPortNumber;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct bladeMezzSlotInfo
@@ -1055,10 +1087,7 @@ struct bladeMezzSlotInfo
         enum bladeMezzSlotType type;
         int sizeslot;
         struct bladeMezzSlotPort slot;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct bladeMezzDevPort
@@ -1067,10 +1096,7 @@ struct bladeMezzDevPort
         char *wwpn;
         enum fabricType fabric;
         enum fabricStatus status;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct bladeMezzDevInfo
@@ -1080,10 +1106,7 @@ struct bladeMezzDevInfo
         enum bladeMezzDevStatus status;
         int sizeport;
         struct bladeMezzDevPort port;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct bladeMezzInfo
@@ -1091,10 +1114,7 @@ struct bladeMezzInfo
         byte mezzNumber;
         struct bladeMezzSlotInfo mezzSlots;
         struct bladeMezzDevInfo mezzDevices;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct bladePortMap
@@ -1105,10 +1125,7 @@ struct bladePortMap
         byte numberOfMezzes;
         int sizemezz;
         struct bladeMezzInfo mezz;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct fanInfo
@@ -1125,11 +1142,8 @@ struct fanInfo
         int lowLimitFanSpeed;
         enum opStatus operationalStatus;
         struct diagnosticChecks diagnosticChecks;
-#if 0
         xmlNode *diagnosticChecksEx;    /* Items are struct diagnosticData */
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getFanInfo
@@ -1155,11 +1169,8 @@ struct interconnectTrayStatus
         enum power powered;
         xmlNode *ports;                 /* Items are struct portEnabled */
         struct diagnosticChecks diagnosticChecks;
-#if 0
         xmlNode *diagnosticChecksEx;    /* Items are struct diagnosticData */
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getInterconnectTrayStatus
@@ -1187,10 +1198,7 @@ struct interconnectTrayInfo
         char *urlToMgmt;
         int powerOnWatts;
         int powerOffWatts;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getInterconnectTrayInfo
@@ -1208,10 +1216,7 @@ struct interconnectTrayPortInfo
         enum interconnectTrayPortEnabled portEnabled;
         enum interconnectTrayPortUidStatus portUidStatus;
         enum interconnectTrayPortLinkLedStatus portLinkLedStatus;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct interconnectTraySlotInfo
@@ -1220,10 +1225,7 @@ struct interconnectTraySlotInfo
         enum interconnectTrayType type;
         int sizeport;
         struct interconnectTrayPortInfo port;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct interconnectTrayPortMap
@@ -1235,10 +1237,7 @@ struct interconnectTrayPortMap
         byte numberOfSlots;
         int sizeslot;
         struct interconnectTraySlotInfo slot;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct powerSupplyInfo
@@ -1250,10 +1249,7 @@ struct powerSupplyInfo
         char *serialNumber;
         int capacity;
         int actualOutput;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getPowerSupplyInfo
@@ -1261,6 +1257,11 @@ struct getPowerSupplyInfo
         int bayNumber;
 };
 
+struct getPowerSupplyStatus
+{
+        int bayNumber;
+};
+
 struct powerSupplyStatus
 {
         byte bayNumber;
@@ -1268,11 +1269,8 @@ struct powerSupplyStatus
         enum opStatus operationalStatus;
         enum opStatus inputStatus;
         struct diagnosticChecks diagnosticChecks;
-#if 0
         xmlNode *diagnosticChecksEx;    /* Items are struct diagnosticData */
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct powerSubsystemInfo
@@ -1292,10 +1290,7 @@ struct powerSubsystemInfo
         byte goodPowerSupplies;
         byte wantedPowerSupplies;
         byte neededPowerSupplies;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct powerConfigInfo
@@ -1303,10 +1298,7 @@ struct powerConfigInfo
         int powerCeiling;
         enum powerRedundancy redundancyMode;
         enum hpoa_boolean dynamicPowerSaverEnabled;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct thermalInfo
@@ -1318,10 +1310,7 @@ struct thermalInfo
         byte temperatureC;
         byte cautionThreshold;
         byte criticalThreshold;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getThermalInfo
@@ -1341,10 +1330,7 @@ struct enclosureBaysSelection
         enum hpoa_boolean oaAccess;
         xmlNode *bladeBays;             /* Items are struct bayAccess */
         xmlNode *interconnectTrayBays;  /* Items are struct bayAccess */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct userInfo
@@ -1355,10 +1341,7 @@ struct userInfo
         enum hpoa_boolean isEnabled;
         enum userAcl acl;
         struct enclosureBaysSelection bayPermissions;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getUserInfo
@@ -1381,10 +1364,7 @@ struct x509CertificateInfo
         int extensionCount;
         char *md5Fingerprint;
         char *sha1Fingerprint;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct certificates
@@ -1392,10 +1372,7 @@ struct certificates
         int numberOfCertificates;
         int sizecertificate;
         xmlNode *certificate;   /* Items are struct x509CertificateInfo */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct ldapInfo
@@ -1409,10 +1386,7 @@ struct ldapInfo
         char *searchContext3;
         enum hpoa_boolean userNtAccountNameMapping;
         struct certificates certificates;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct ldapGroupInfo
@@ -1421,20 +1395,14 @@ struct ldapGroupInfo
         char *description;
         enum userAcl acl;
         struct enclosureBaysSelection bayPermissions;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct trapInfo
 {
         char *ipAddress;
         char *community;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct snmpInfo
@@ -1446,10 +1414,7 @@ struct snmpInfo
         char *rwCommunity;
         int numTraps;
         xmlNode *traps;                 /* Items are struct trapInfo */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct enclosureNetworkInfo
@@ -1467,10 +1432,7 @@ struct enclosureNetworkInfo
         enum hpoa_boolean ebipaSvbEnabled;
         enum hpoa_boolean ebipaSwmEnabled;
         enum hpoa_boolean xmlReplyEnabled;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct oaNetworkInfo
@@ -1485,10 +1447,7 @@ struct oaNetworkInfo
         xmlNode *dns;                   /* Items are char *ipAddress */
         char *elinkIpAddress;
         enum hpoa_boolean linkActive;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getOaNetworkInfo
@@ -1501,10 +1460,7 @@ struct enclosureTime
         time_t dateTime;
         char *timeZone;
         time_t universalDateTime;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct alertmailInfo
@@ -1512,10 +1468,7 @@ struct alertmailInfo
         char *server;
         char *receiver;
         char *domain;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct ebipaInfo
@@ -1534,10 +1487,7 @@ struct ebipaInfo
         xmlNode *swmNtpServer;          /* Items are char *ipAddress */
         enum hpoa_boolean isConfiguredSvb;
         enum hpoa_boolean isConfiguredSwm;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct lcdChatMessage
@@ -1548,10 +1498,7 @@ struct lcdChatMessage
         char *answerChoiceList;
         char *selectedAnswerText;
         char *customAnswerText;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct lcdUserNotes
@@ -1562,20 +1509,14 @@ struct lcdUserNotes
         char *lcdUserNotesLine4;
         char *lcdUserNotesLine5;
         char *lcdUserNotesLine6;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct lcdButtonEvent
 {
         enum lcdButton button;
         enum lcdButtonState buttonState;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct lcdStatus
@@ -1586,11 +1527,8 @@ struct lcdStatus
         enum hpoa_boolean buttonLock;
         enum lcdSetupHealth lcdSetupHealth;
         struct diagnosticChecks diagnosticChecks;
-#if 0
         xmlNode *diagnosticChecksEx;    /* Items are struct diagnosticData */
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct lcdInfo
@@ -1599,10 +1537,7 @@ struct lcdInfo
         char *partNumber;
         char *manufacturer;
         char *fwVersion;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct hpSimInfo
@@ -1610,10 +1545,7 @@ struct hpSimInfo
         enum hpSimTrustMode trustMode;
         struct certificates certificates;
         xmlNode *xeNameList;            /* Items are char *xeName */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct thermalSubsystemInfo
@@ -1623,10 +1555,7 @@ struct thermalSubsystemInfo
         byte goodFans;
         byte wantedFans;
         byte neededFans;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct bladeIpl
@@ -1643,10 +1572,7 @@ struct bladeBootInfo
         enum oneTimeBootDevice oneTimeBootDevice;
         enum oneTimeBootAgent oneTimeBootAgent;
         enum hpoa_boolean oneTimeBypassF1F2Messages;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct oaVcmMode
@@ -1655,10 +1581,7 @@ struct oaVcmMode
         char *vcmUrl;
         char *vcmDomainId;
         char *vcmDomainName;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct powerReductionStatus
@@ -1666,10 +1589,7 @@ struct powerReductionStatus
         enum powerReductionState powerReductionState;
         enum powerReductionArmedState powerReductionArmedState;
         enum powerReductionState powerReductionFiredState;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct virtualMediaStatus
@@ -1680,10 +1600,7 @@ struct virtualMediaStatus
         char *cdromUrl;
         enum virtualMediaDeviceStatus floppyStatus;
         char *floppyUrl;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct fanZone
@@ -1693,12 +1610,17 @@ struct fanZone
         enum opStatus operationalStatus;
         int targetRpm;
         int targetPwm;
-        xmlNode *deviceBayArray;                /* Items are short bay */
-        xmlNode *fanInfoArray;                  /* Items are struct fanInfo */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *deviceBayArray;        /* Items are byte bay */
+        xmlNode *fanInfoArray;          /* Items are struct fanInfo */
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
+};
+
+struct deviceBayArray {
+        xmlNode *bay;                   /* Items are byte (bay) */
+};
+
+struct fanInfoArray{
+        xmlNode *fanInfo;               /* Items are struct fanInfo */
 };
 
 struct ebipaBay
@@ -1740,10 +1662,7 @@ struct encLinkOa
         char *ipAddress;
         char *macAddress;
         char *fwVersion;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct encLink2
@@ -1760,21 +1679,15 @@ struct encLink2
         char *enclosureUrl;
         char *rackName;
         enum hpoa_boolean primaryEnclosure;
-        xmlNode *encLinkOa;                     /* Items are struct encLinkOa */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *encLinkOa;             /* Items are struct encLinkOa */
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct rackTopology2
 {
         char *ruid;
-        xmlNode *enclosures;                    /* Items are struct encLink2 */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *enclosures;            /* Items are struct encLink2 */
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct passwordSettings
@@ -1791,10 +1704,7 @@ struct oaMediaDevice
         enum presence devicePresence;
         enum presence mediaPresence;
         char *volumeLabel;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct firmwareImage
@@ -1806,10 +1716,7 @@ struct firmwareImage
 struct usbMediaFirmwareImages
 {
         xmlNode *image;                 /* Items are struct firmwareImage */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct usbMediaConfigScript
@@ -1819,13 +1726,10 @@ struct usbMediaConfigScript
 
 struct usbMediaConfigScripts
 {
-        xmlNode *usbMediaConfigScript;          /* Items are struct
-                                                 * usbMediaConfigScript
-                                                 */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *usbMediaConfigScript;  /* Items are
+                                         * struct usbMediaConfigScript
+                                         */
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct tfaSettings
@@ -1833,10 +1737,7 @@ struct tfaSettings
         enum hpoa_boolean enableTwoFactor;
         enum hpoa_boolean enableCrl;
         enum hpoa_boolean subjectAltName;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct userCertificateInfo
@@ -1853,10 +1754,7 @@ struct powerdelayBay
 {
         int bayNumber;
         int delay;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct powerdelaySettings
@@ -1864,10 +1762,23 @@ struct powerdelaySettings
         enum hpoa_boolean isPowerdelayInProgress;
         xmlNode *interconnects;         /* Items are struct powerdelayBay */
         xmlNode *servers;               /* Items are struct powerdelayBay */
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
+};
+
+struct getFanZoneArrayResponse
+{
+        xmlNode *fanZoneArray;          /* Items are struct fanZone */
+};
+
+struct bayArray
+{
+        int     size;                   /* Size of array */
+        byte    *array;                 /* Actual array */
+};
+
+struct getFanZoneArray
+{
+        struct bayArray bayArray;
 };
 
 struct getEvent
@@ -1948,12 +1859,10 @@ struct eventInfo
         enum eventType event;
         time_t eventTimeStamp;
         int queueSize;
+        int numValue;
         union _hpoa__data eventData;
-#if 0
-        int sizeextraData;
-        xmlNode *extraData;
-#endif
         enum enum_eventInfo enum_eventInfo;
+        xmlNode *extraData;             /* Items are struct extraDataInfo */
 };
 
 struct getAllEventsResponse
@@ -1961,6 +1870,30 @@ struct getAllEventsResponse
         xmlNode *eventInfoArray;
 };
 
+struct getBladeThermalInfoArray
+{
+	int bayNumber;
+};
+
+struct bladeThermalInfoArrayResponse
+{
+	xmlNode *bladeThermalInfoArray; /* Items are struct bladeThermalInfo */
+};
+
+struct bladeThermalInfo
+{
+	byte sensorNumber;
+	byte sensorType;
+	byte entityId;
+	byte entityInstance;
+	byte criticalThreshold;
+	byte cautionThreshold;
+	byte temperatureC;
+	byte oem;
+	char *description;
+	xmlNode *extraData;             /* Items are struct extraDataInfo */
+};	
+
 struct setBladePower
 {
         int bayNumber;
@@ -1978,83 +1911,105 @@ struct resetInterconnectTray
         int bayNumber;
 };
 
+struct setEnclosureUid
+{
+        enum uidControl uid;
+};
+
+struct setOaUid
+{
+        int bayNumber;
+        enum uidControl uid;
+};
+
+struct setBladeUid
+{
+        int bayNumber;
+        enum uidControl uid;
+};
+
+struct setInterconnectTrayUid
+{
+        int bayNumber;
+        enum uidControl uid;
+};
 
 /* Main OA SOAP Function prototypes */
 int soap_subscribeForEvents(SOAP_CON *connection,
                             struct eventPid *response);
 
 int soap_unSubscribeForEvents(SOAP_CON *connection,
-                              struct unSubscribeForEvents *request);
+                              const struct unSubscribeForEvents *request);
 
 int soap_getEvent(SOAP_CON *connection,
-                  struct getEvent *request,
+                  const struct getEvent *request,
                   struct eventInfo *response);
 
 int soap_getAllEvents(SOAP_CON *connection,
-                      struct getAllEvents *request,
+                      const struct getAllEvents *request,
                       struct getAllEventsResponse *response);
 
 int soap_getBladeInfo(SOAP_CON *connection,
-                      struct getBladeInfo *request,
+                      const struct getBladeInfo *request,
                       struct bladeInfo *response);
 
 int soap_getBladeMpInfo(SOAP_CON *connection,
-                        struct getBladeMpInfo *request,
+                        const struct getBladeMpInfo *request,
                         struct bladeMpInfo *response);
 
 int soap_getEnclosureInfo(SOAP_CON *connection,
                           struct enclosureInfo *response);
 
 int soap_getOaStatus(SOAP_CON *connection,
-                     struct getOaStatus *request,
+                     const struct getOaStatus *request,
                      struct oaStatus *response);
 
 int soap_getOaInfo(SOAP_CON *connection,
-                   struct getOaInfo *request,
+                   const struct getOaInfo *request,
                    struct oaInfo *response);
 
 int soap_getInterconnectTrayStatus(SOAP_CON *connection,
-                                   struct getInterconnectTrayStatus *request,
-                                   struct interconnectTrayStatus *response);
+                const struct getInterconnectTrayStatus *request,
+                struct interconnectTrayStatus *response);
 
 int soap_getInterconnectTrayInfo(SOAP_CON *connection,
-                                 struct getInterconnectTrayInfo *request,
+                                 const struct getInterconnectTrayInfo *request,
                                  struct interconnectTrayInfo *response);
 
 int soap_getFanInfo(SOAP_CON *connection,
-                    struct getFanInfo *request,
+                    const struct getFanInfo *request,
                     struct fanInfo *response);
 
 int soap_getPowerSubsystemInfo(SOAP_CON *connection,
                                struct powerSubsystemInfo *response);
 
 int soap_getPowerSupplyInfo(SOAP_CON *connection,
-                            struct getPowerSupplyInfo *request,
+                            const struct getPowerSupplyInfo *request,
                             struct powerSupplyInfo *response);
 
 int soap_getOaNetworkInfo(SOAP_CON *connection,
-                          struct getOaNetworkInfo *request,
+                          const struct getOaNetworkInfo *request,
                           struct oaNetworkInfo *response);
 
 int soap_getBladeStatus(SOAP_CON *connection,
-                        struct getBladeStatus *request,
+                        const struct getBladeStatus *request,
                         struct bladeStatus *response);
 
 int soap_setBladePower(SOAP_CON *connection,
-                       struct setBladePower *request);
+                       const struct setBladePower *request);
 
 int soap_setInterconnectTrayPower(SOAP_CON *connection,
-                                  struct setInterconnectTrayPower *request);
+                const struct setInterconnectTrayPower *request);
 
 int soap_resetInterconnectTray(SOAP_CON *connection,
-                               struct resetInterconnectTray *request);
+                               const struct resetInterconnectTray *request);
 
 int soap_getThermalInfo(SOAP_CON *connection,
-                        struct getThermalInfo *request,
+                        const struct getThermalInfo *request,
                         struct thermalInfo *response);
 
 int soap_getUserInfo(SOAP_CON *connection,
-                     struct getUserInfo *request,
+                     const struct getUserInfo *request,
                      struct userInfo *response);
 
 int soap_isValidSession(SOAP_CON *connection);
@@ -2062,8 +2017,50 @@ int soap_isValidSession(SOAP_CON *connection);
 int soap_getRackTopology2(SOAP_CON *con,
                           struct rackTopology2 *response);
 
+int soap_getThermalSubsystemInfo(SOAP_CON *con,
+                                 struct thermalSubsystemInfo *response);
+
+int soap_getFanZoneArray(SOAP_CON *con,
+                         const struct getFanZoneArray *request,
+                         struct getFanZoneArrayResponse *response);
+
+int soap_getEnclosureStatus(SOAP_CON *con,
+                            struct enclosureStatus *response);
+
+int soap_getLcdInfo(SOAP_CON *con,
+                    struct lcdInfo *response);
+
+int soap_getLcdStatus(SOAP_CON *con,
+                      struct lcdStatus *response);
+
+int soap_getPowerSupplyStatus(SOAP_CON *con,
+                              const struct getPowerSupplyStatus *request,
+                              struct powerSupplyStatus *response);
+
+int soap_setEnclosureUid(SOAP_CON *con,
+                         const struct setEnclosureUid *request);
+
+int soap_setOaUid(SOAP_CON *con,
+                  const struct setOaUid *request);
+
+int soap_setBladeUid(SOAP_CON *connection,
+                     const struct setBladeUid *request);
+
+int soap_setInterconnectTrayUid(SOAP_CON *con,
+                                const struct setInterconnectTrayUid *request);
+
+int soap_setLcdButtonLock(SOAP_CON *con,
+                          enum hpoa_boolean buttonLock);
+
+int soap_getBladeThermalInfoArray(SOAP_CON *con, 
+				  struct getBladeThermalInfoArray *request,
+				  struct bladeThermalInfoArrayResponse 
+								*response);
 
 /* Function prototypes for OA SOAP helper functions */
+void    soap_getExtraData(xmlNode *extraData, struct extraDataInfo *result);
+void    soap_getDiagnosticChecksEx(xmlNode *diag,
+                                   struct diagnosticData *result);
 void    soap_getBladeCpuInfo(xmlNode *cpus, struct bladeCpuInfo *result);
 void    soap_getBladeNicInfo(xmlNode *nics, struct bladeNicInfo *result);
 void    soap_getDiagnosticData(xmlNode *data, struct diagnosticData *result);
@@ -2072,8 +2069,11 @@ void    soap_getEncLink(xmlNode *data, struct encLink *result);
 void    soap_getPortEnabled(xmlNode *data, struct portEnabled *result);
 void    soap_getIpAddress(xmlNode *ips, char **result);
 void    soap_getEventInfo(xmlNode *events, struct eventInfo *result);
-
 void    soap_getEncLinkOa(xmlNode *data, struct encLinkOa *result);
 void    soap_getEncLink2(xmlNode *data, struct encLink2 *result);
+void    soap_fanZone(xmlNode *fanZone, struct fanZone *result);
+void    soap_fanInfo(xmlNode *fanZone, struct fanInfo *result);
+void    soap_deviceBayArray(xmlNode *node, byte *bay);
+void	soap_bladeThermalInfo(xmlNode *node, struct bladeThermalInfo *result);
 
 #endif  /* _INC_OASOAP_CALLS_H_ */
