@@ -30,6 +30,8 @@
  *
  * Author(s)
  *      Raghavendra P.G. <raghavendra.pg@hp.com>
+ *      Shuah Khan <shuah.khan@hp.com>
+ *      Raghavendra M.S.  <raghavendra.ms@hp.com>
  *
  * This file has the interconnect blade related events handling
  *
@@ -48,9 +50,6 @@
  *      process_interconnect_status_event()     - Process the interconeect
  *                                                status event
  *
- *      build_inserted_interconnect_rpt()       - Builds the inserted
- *                                                interconnect RPT entry
- *
  *      process_interconnect_thermal_event()    - Process the interconeect
  *                                                thermal event
  *
@@ -77,12 +76,11 @@ SaErrorT process_interconnect_reset_event(struct oh_handler_state *oh_handler,
                                           struct eventInfo *oa_event)
 {
         struct oa_soap_hotswap_state *hotswap_state = NULL;
-        char* entity_root = NULL;
-        SaErrorT rv = SA_OK;
-        SaHpiEntityPathT root_entity_path;
-        SaHpiEntityPathT entity_path;
         struct oh_event event;
         SaHpiRptEntryT *rpt = NULL;
+        SaHpiResourceIdT resource_id;
+        struct oa_soap_handler *oa_handler = NULL;
+        SaHpiInt32T bay_number;
 
         if (oh_handler == NULL || oa_event == NULL) {
                 err("Invalid parameters");
@@ -90,29 +88,15 @@ SaErrorT process_interconnect_reset_event(struct oh_handler_state *oh_handler,
         }
 
         update_hotswap_event(oh_handler, &event);
-        entity_root = (char *) g_hash_table_lookup(oh_handler->config,
-                                                   "entity_root");
-        rv = oh_encode_entitypath(entity_root, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
 
-        memset(&entity_path, 0, sizeof(SaHpiEntityPathT));
-        entity_path.Entry[1].EntityType = SAHPI_ENT_ROOT;
-        entity_path.Entry[1].EntityLocation = 0;
-        entity_path.Entry[0].EntityType=SAHPI_ENT_SWITCH_BLADE;
-        entity_path.Entry[0].EntityLocation =
-                oa_event->eventData.interconnectTrayStatus.bayNumber;
-        rv = oh_concat_ep(&entity_path, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        rpt = oh_get_resource_by_ep(oh_handler->rptcache, &entity_path);
+        oa_handler = (struct oa_soap_handler *) oh_handler->data;
+        bay_number = oa_event->eventData.interconnectTrayStatus.bayNumber;
+        resource_id = oa_handler->
+                oa_soap_resources.interconnect.resource_id[bay_number - 1];
+        /* Get the rpt entry of the resource */
+        rpt = oh_get_resource_by_id(oh_handler->rptcache, resource_id);
         if (rpt == NULL) {
-                err("resource rpt is NULL");
+                err("resource RPT is NULL");
                 return SA_ERR_HPI_INTERNAL_ERROR;
         }
 
@@ -152,7 +136,7 @@ SaErrorT process_interconnect_reset_event(struct oh_handler_state *oh_handler,
         event.event.EventDataUnion.HotSwapEvent.HotSwapState =
                 SAHPI_HS_STATE_INACTIVE;
         /* EXTRACTION_PENDING to INACTIVE state change happened due
-         * to Auto policy of server blade
+         * to Auto policy of the server blade
          */
         event.event.EventDataUnion.HotSwapEvent.CauseOfStateChange =
                 SAHPI_HS_CAUSE_AUTO_POLICY;
@@ -202,15 +186,15 @@ SaErrorT process_interconnect_power_event(struct oh_handler_state *oh_handler,
                                           struct eventInfo *oa_event)
 {
         struct oa_soap_hotswap_state *hotswap_state = NULL;
-        char* entity_root = NULL;
         SaErrorT rv = SA_OK;
-        SaHpiEntityPathT root_entity_path;
-        SaHpiEntityPathT entity_path;
         SaHpiRptEntryT *rpt = NULL;
         struct oh_event event;
         struct oa_soap_sensor_info *sensor_info=NULL;
         SaHpiRdrT *rdr = NULL;
-        SaHpiIdrIdT sen_rdr_num = OA_SOAP_RES_SEN_TEMP_NUM;
+        SaHpiIdrIdT sen_rdr_num = OA_SOAP_SEN_TEMP_STATUS;
+        SaHpiResourceIdT resource_id;
+        struct oa_soap_handler *oa_handler = NULL;
+        SaHpiInt32T bay_number;
 
         if (oh_handler == NULL || oa_event == NULL) {
                 err("Invalid parameters");
@@ -219,29 +203,14 @@ SaErrorT process_interconnect_power_event(struct oh_handler_state *oh_handler,
 
         update_hotswap_event(oh_handler, &event);
 
-        entity_root = (char *) g_hash_table_lookup(oh_handler->config,
-                                                   "entity_root");
-        rv = oh_encode_entitypath(entity_root, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        memset(&entity_path, 0, sizeof(SaHpiEntityPathT));
-        entity_path.Entry[1].EntityType = SAHPI_ENT_ROOT;
-        entity_path.Entry[1].EntityLocation = 0;
-        entity_path.Entry[0].EntityType = SAHPI_ENT_SWITCH_BLADE;
-        entity_path.Entry[0].EntityLocation =
-                oa_event->eventData.interconnectTrayStatus.bayNumber;
-        rv = oh_concat_ep(&entity_path, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        rpt = oh_get_resource_by_ep(oh_handler->rptcache, &entity_path);
+        oa_handler = (struct oa_soap_handler *) oh_handler->data;
+        bay_number = oa_event->eventData.interconnectTrayStatus.bayNumber;
+        resource_id = oa_handler->
+                oa_soap_resources.interconnect.resource_id[bay_number - 1];
+        /* Get the rpt entry of the server */
+        rpt = oh_get_resource_by_id(oh_handler->rptcache, resource_id);
         if (rpt == NULL) {
-                err("resource rpt is NULL");
+                err("resource RPT is NULL");
                 return SA_ERR_HPI_INTERNAL_ERROR;
         }
 
@@ -256,7 +225,7 @@ SaErrorT process_interconnect_power_event(struct oh_handler_state *oh_handler,
         }
 
         switch (oa_event->eventData.interconnectTrayStatus.powered) {
-                case (POWER_OFF) :
+                case (POWER_OFF):
                         event.resource.ResourceSeverity = SAHPI_CRITICAL;
                         /* Update the current hotswap state to INACTIVE */
                         hotswap_state->currentHsState = SAHPI_HS_STATE_INACTIVE;
@@ -296,7 +265,7 @@ SaErrorT process_interconnect_power_event(struct oh_handler_state *oh_handler,
                                           copy_oa_soap_event(&event));
                         break;
 
-                case (POWER_ON) :
+                case (POWER_ON):
                         event.resource.ResourceSeverity = SAHPI_OK;
                         /* Update the current hot swap state to ACTIVE */
                         hotswap_state->currentHsState = SAHPI_HS_STATE_ACTIVE;
@@ -367,7 +336,7 @@ SaErrorT process_interconnect_power_event(struct oh_handler_state *oh_handler,
                                           copy_oa_soap_event(&event));
                         break;
 
-                default :
+                default:
                         err("Wrong power state %d",
                             oa_event->eventData.bladeStatus.powered);
                         return SA_ERR_HPI_INTERNAL_ERROR;
@@ -403,6 +372,8 @@ SaErrorT process_interconnect_insertion_event(struct oh_handler_state
         struct oh_event event;
         SaHpiInt32T bay_number;
         SaHpiResourceIdT resource_id;
+	GSList *asserted_sensors = NULL;
+	SaHpiRptEntryT *rpt;
 
         if (oh_handler == NULL || oa_event == NULL || con == NULL) {
                 err("Invalid parameters");
@@ -420,19 +391,21 @@ SaErrorT process_interconnect_insertion_event(struct oh_handler_state
                 return SA_ERR_HPI_INTERNAL_ERROR;
         }
 
-        /* Update the serial number array */
-        strcpy(oa_handler->oa_soap_resources.interconnect.
-               serial_number[bay_number - 1], response.serialNumber);
-
         /* Build the inserted interconnect RPT entry */
-        rv = build_inserted_interconnect_rpt(oh_handler,
-                                             response.name,
-                                             bay_number, &resource_id);
+        rv = build_interconnect_rpt(oh_handler, con, response.name,
+                                    bay_number, &resource_id, TRUE);
         if (rv != SA_OK) {
                 err("Failed to build the interconnect RPT");
                 return rv;
         }
 
+        /* Update resource_status structure with resource_id,
+         * serial_number, and presence status
+         */
+        oa_soap_update_resource_status(
+                 &oa_handler->oa_soap_resources.interconnect, bay_number,
+                 response.serialNumber, resource_id, RES_PRESENT);
+
         /* Build the inserted interconnect RDRs */
         rv = build_interconnect_rdr(oh_handler, con,
                                     bay_number, resource_id);
@@ -440,10 +413,15 @@ SaErrorT process_interconnect_insertion_event(struct oh_handler_state
                 err("Failed to build the interconnect RDR");
                 rv = oh_remove_resource(oh_handler->rptcache,
                                         event.resource.ResourceId);
+                /* reset resource_status structure to default values */
+                oa_soap_update_resource_status(
+                      &oa_handler->oa_soap_resources.interconnect, bay_number,
+                      "", SAHPI_UNSPECIFIED_RESOURCE_ID, RES_ABSENT);
                 return rv;
         }
 
-        rv = populate_event(oh_handler, resource_id, &event);
+        rv = oa_soap_populate_event(oh_handler, resource_id, &event,
+				    &asserted_sensors);
         if (rv != SA_OK) {
                 err("Creating hotswap event failed");
                 return rv;
@@ -461,9 +439,11 @@ SaErrorT process_interconnect_insertion_event(struct oh_handler_state
                 SAHPI_HS_CAUSE_OPERATOR_INIT;
         oh_evt_queue_push(oh_handler->eventq, copy_oa_soap_event(&event));
 
-        /* Update the interconnect resource presence metrix to PRESENT */
-        oa_handler->oa_soap_resources.interconnect.presence[bay_number - 1] =
-                RES_PRESENT;
+	/* Raise the assert sensor events */
+	if (asserted_sensors) {
+	        rpt = oh_get_resource_by_id(oh_handler->rptcache, resource_id);
+		oa_soap_assert_sen_evt(oh_handler, rpt, asserted_sensors);
+	}
 
         return SA_OK;
 }
@@ -511,84 +491,65 @@ SaErrorT process_interconnect_extraction_event(struct oh_handler_state
  *
  * Purpose:
  *      Creates the interconnect insertion pending to active hpi hotswap event
+ *      Processes the interconnect status event and generates the sensor event
  *
  * Detailed Description:
  *      - The interconnect takes nearly 3 seconds to power on
  *        The interconnect status event which follows the insertion event
  *        indicates the power on of interconnect
  *      - Create the interconnect insertion pending to active hpi hotswap event
+ *      - Processes the interconnect status event and generates the sensor event
  *
  * Return values:
  *      SA_OK                     - success.
  *      SA_ERR_HPI_INVALID_PARAMS - on wrong parameters.
  *      SA_ERR_HPI_INTERNAL_ERROR - on failure
  **/
-SaErrorT process_interconnect_status_event(struct oh_handler_state *oh_handler,
-                                           struct eventInfo *oa_event)
+void oa_soap_proc_interconnect_status(struct oh_handler_state *oh_handler,
+				      struct interconnectTrayStatus *status)
 {
-        SaErrorT rv = SA_OK;
-        char* entity_root = NULL;
         struct oa_soap_hotswap_state *hotswap_state;
-        SaHpiEntityPathT entity_path;
-        SaHpiEntityPathT root_entity_path;
         SaHpiRptEntryT *rpt = NULL;
         struct oh_event event;
-        SaHpiInt32T bay_number;
+        SaHpiResourceIdT resource_id;
+        struct oa_soap_handler *oa_handler = NULL;
+	enum oa_soap_extra_data_health health_status;
+	SaErrorT rv;
+	enum diagnosticStatus diag_ex_status[OA_SOAP_MAX_DIAG_EX];
 
-        if (oh_handler == NULL || oa_event == NULL) {
+        if (oh_handler == NULL || status == NULL) {
                 err("Invalid parameters");
-                return SA_ERR_HPI_INVALID_PARAMS;
+                return;
         }
 
-        bay_number = oa_event->eventData.interconnectTrayStatus.bayNumber;
-        update_hotswap_event(oh_handler, &event);
+        oa_handler = (struct oa_soap_handler *) oh_handler->data;
 
-        if (oa_event->eventData.interconnectTrayStatus.powered != POWER_ON) {
-                return SA_OK;
-        }
-
-        entity_root = (char *) g_hash_table_lookup(oh_handler->config,
-                                                   "entity_root");
-        rv = oh_encode_entitypath(entity_root, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        memset(&entity_path, 0, sizeof(SaHpiEntityPathT));
-        entity_path.Entry[1].EntityType = SAHPI_ENT_ROOT;
-        entity_path.Entry[1].EntityLocation = 0;
-        entity_path.Entry[0].EntityType=SAHPI_ENT_SWITCH_BLADE;
-        entity_path.Entry[0].EntityLocation= bay_number;
-        rv = oh_concat_ep(&entity_path, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        rpt = oh_get_resource_by_ep(oh_handler->rptcache, &entity_path);
+        resource_id = oa_handler->oa_soap_resources.interconnect.
+			resource_id[status->bayNumber - 1];
+        /* Get the rpt entry of the server */
+        rpt = oh_get_resource_by_id(oh_handler->rptcache, resource_id);
         if (rpt == NULL) {
-                err("resource rpt is NULL");
-                return SA_ERR_HPI_INTERNAL_ERROR;
+                err("resource RPT is NULL");
+                return;
         }
-        memcpy(&(event.resource), rpt, sizeof(SaHpiRptEntryT));
-        event.event.Source = event.resource.ResourceId;
 
         hotswap_state = (struct oa_soap_hotswap_state *)
-                oh_get_resource_data(oh_handler->rptcache,
-                                     event.resource.ResourceId);
+                oh_get_resource_data(oh_handler->rptcache, resource_id);
         if (hotswap_state == NULL) {
                 err("Failed to get hotswap state of server blade");
-                return SA_ERR_HPI_INTERNAL_ERROR;
+                return;
         }
 
         /* Check whether blade is in the insertion pending state and it is
          * powered on
          */
-        if (hotswap_state->currentHsState == SAHPI_HS_STATE_INSERTION_PENDING) {
+        if (hotswap_state->currentHsState == SAHPI_HS_STATE_INSERTION_PENDING &&
+	    status->powered == POWER_ON) {
                 hotswap_state->currentHsState = SAHPI_HS_STATE_ACTIVE;
-                event.event.Source = event.resource.ResourceId;
 
+		update_hotswap_event(oh_handler, &event);
+		memcpy(&(event.resource), rpt, sizeof(SaHpiRptEntryT));
+		event.event.Source = event.resource.ResourceId;
                 event.event.EventDataUnion.HotSwapEvent.PreviousHotSwapState =
                         SAHPI_HS_STATE_INSERTION_PENDING;
                 event.event.EventDataUnion.HotSwapEvent.HotSwapState =
@@ -602,124 +563,94 @@ SaErrorT process_interconnect_status_event(struct oh_handler_state *oh_handler,
                                   copy_oa_soap_event(&event));
         }
 
-        return SA_OK;
-}
+	/* Build operational status sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_OPER_STATUS,
+				     status->operationalStatus, 0, 0)
 
-/**
- * build_inserted_interconnect_rpt
- *      @oh_handler:  Pointer to openhpi handler
- *      @name:        Pointer to the name of the switch blade
- *      @bay_number:  Bay number of the switch blade
- *      @resource_id: Pointer to the resource id
- *
- * Purpose:
- *      Populate the switch blade RPT.
- *      Pushes the RPT entry to infrastructure
- *
- * Detailed Description: NA
- *
- * Return values:
- *      SA_OK  - on success.
- *      SA_ERR_HPI_INVALID_PARAMS - on wrong parameters
- *      SA_ERR_HPI_OUT_OF_MEMORY - on malloc failure
- *      SA_ERR_HPI_INTERNAL_ERROR - on failure.
- **/
+	/* Build predictive failure sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_PRED_FAIL,
+				     status->operationalStatus, 0, 0)
 
-SaErrorT build_inserted_interconnect_rpt(struct oh_handler_state *oh_handler,
-                                         char *name,
-                                         SaHpiInt32T bay_number,
-                                         SaHpiResourceIdT *resource_id)
-{
-        SaErrorT rv = SA_OK;
-        SaHpiEntityPathT entity_path;
-        char *entity_root = NULL;
-        struct oa_soap_hotswap_state *hotswap_state = NULL;
-        SaHpiRptEntryT rpt;
-        char temp[MAX_NAME_LEN];
+	/* Build interconnect CPU fault sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_CPU_FAULT,
+				     status->cpuFault, 0, 0)
 
-        if (oh_handler == NULL || name == NULL || resource_id == NULL) {
-                err("invalid parameters");
-                return SA_ERR_HPI_INVALID_PARAMS;
-        }
+	/* Build interconnect health LED sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_HEALTH_LED,
+				     status->healthLed, 0, 0)
 
-        entity_root = (char *) g_hash_table_lookup(oh_handler->config,
-                                                   "entity_root");
-        rv = oh_encode_entitypath(entity_root, &entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
+	/* Build internal data error sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_INT_DATA_ERR,
+				     status->diagnosticChecks.internalDataError,
+				     0, 0)
 
-        memset(&rpt, 0, sizeof(SaHpiRptEntryT));
-        rpt.ResourceCapabilities = SAHPI_CAPABILITY_RDR |
-                                   SAHPI_CAPABILITY_RESET |
-                                   SAHPI_CAPABILITY_RESOURCE |
-                                   SAHPI_CAPABILITY_POWER |
-                                   SAHPI_CAPABILITY_FRU |
-                                   SAHPI_CAPABILITY_MANAGED_HOTSWAP |
-                                   SAHPI_CAPABILITY_SENSOR |
-                                   SAHPI_CAPABILITY_CONTROL |
-                                   SAHPI_CAPABILITY_INVENTORY_DATA;
-        rpt.ResourceEntity.Entry[1].EntityType = SAHPI_ENT_ROOT;
-        rpt.ResourceEntity.Entry[1].EntityLocation = 0;
-        rpt.ResourceEntity.Entry[0].EntityType =SAHPI_ENT_SWITCH_BLADE;
-        rpt.ResourceEntity.Entry[0].EntityLocation= bay_number;
-        rv = oh_concat_ep(&(rpt.ResourceEntity), &entity_path);
-        if (rv != SA_OK) {
-                err("concat of entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
+	/* Build management processor error sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_MP_ERR,
+				     status->diagnosticChecks.
+					managementProcessorError, 0, 0)
 
-        rpt.ResourceId = oh_uid_from_entity_path(&rpt.ResourceEntity);
+	/* Build thermal waring sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_THERM_WARN,
+				     status->diagnosticChecks.thermalWarning,
+				     0, 0)
 
-        /* Check whether the interconnect blade is from Cisco Systems
-         * TODO: Cisco interconnect blades will have name starting with "Cisco"
-         *       If this format gets changed for any reason,
-         *       then Cisco interconnect blades will have manufacture id as HP
-         *       in ManufacturerId field of rpt entry.
-         *       If the interconnect name format changes,
-         *       please change the logic accordingly.
-         */
-        convert_lower_to_upper(name, strlen(name), temp, MAX_NAME_LEN);
-        if (strstr(temp, CISCO) != NULL)
-                rpt.ResourceInfo.ManufacturerId = CISCO_MANUFACTURING_ID;
-        else
-                rpt.ResourceInfo.ManufacturerId = HP_MANUFACTURING_ID;
+	/* Build thermal danger sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_THERM_DANGER,
+				     status->diagnosticChecks.thermalDanger,
+				     0, 0)
 
-        rpt.ResourceSeverity = SAHPI_OK;
-        rpt.ResourceFailed = SAHPI_FALSE;
-        rpt.HotSwapCapabilities = SAHPI_HS_CAPABILITY_AUTOEXTRACT_READ_ONLY;
-        rpt.ResourceTag.DataType = SAHPI_TL_TYPE_TEXT;
-        rpt.ResourceTag.Language = SAHPI_LANG_ENGLISH;
-        rpt.ResourceTag.DataLength = strlen(name) + 1;
-        memset(rpt.ResourceTag.Data, 0, SAHPI_MAX_TEXT_BUFFER_LENGTH);
-        snprintf((char *) (rpt.ResourceTag.Data),
-                  rpt.ResourceTag.DataLength,"%s",
-                  name);
+	/* Build IO configuration error sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_IO_CONFIG_ERR,
+				     status->diagnosticChecks.
+					ioConfigurationError, 0, 0)
 
-        hotswap_state = (struct oa_soap_hotswap_state *)
-                g_malloc0(sizeof(struct oa_soap_hotswap_state));
-        if (hotswap_state == NULL) {
-                err("Out of memory");
-                return SA_ERR_HPI_OUT_OF_MEMORY;
-        }
-        /* The interconnect takes nearly 3 seconds to power on after insertion
-         * Put the current hotswap state as INSERTION_PENDING
-         * The INSERTION_PENDING to ACTIVE state change is handled as part of
-         * interconnect status events
-         */
-        hotswap_state->currentHsState = SAHPI_HS_STATE_INSERTION_PENDING;
+	/* Build device power request error sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_DEV_PWR_REQ,
+				     status->diagnosticChecks.
+					devicePowerRequestError, 0, 0)
 
-        rv = oh_add_resource(oh_handler->rptcache, &rpt, hotswap_state, 0);
-        if (rv != SA_OK) {
-                err("Failed to add Server rpt");
-                if (hotswap_state != NULL)
-                        g_free(hotswap_state);
-                return rv;
-        }
+	/* Build device failure error sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_DEV_FAIL,
+				     status->diagnosticChecks.deviceFailure,
+				     0, 0)
 
-        *resource_id = rpt.ResourceId;
-        return SA_OK;
+	/* Build device degraded error sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_DEV_DEGRAD,
+				     status->diagnosticChecks.deviceDegraded,
+				     0, 0)
+
+	oa_soap_parse_diag_ex(status->diagnosticChecksEx, diag_ex_status);
+
+	/* Process device not supported sensor rdr */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_DEV_NOT_SUPPORT,
+				     diag_ex_status[DIAG_EX_DEV_NOT_SUPPORT],
+				     0, 0)
+
+	/* Process Device informational sensor */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_DEV_INFO,
+				     diag_ex_status[DIAG_EX_DEV_INFO], 0, 0)
+
+	/* Process Storage device missing sensor */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_STORAGE_DEV_MISS,
+				     diag_ex_status[DIAG_EX_STORAGE_DEV_MISS],
+				     0, 0)
+
+	/* Process Duplicate management IP address sensor */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_DUP_MGMT_IP_ADDR,
+				     diag_ex_status[DIAG_EX_DUP_MGMT_IP_ADDR],
+				     0, 0)
+
+	/* Get the healthStatus enum from extraData structure */
+	oa_soap_get_health_val(status->extraData, &health_status);
+
+	/* Build health status operational sensor */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_HEALTH_OPER,
+				     health_status, 0, 0)
+
+	/* Build health status predictive failure sensor */
+	OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_HEALTH_PRED_FAIL,
+				     health_status, 0, 0)
+        return;
 }
 
 /**
@@ -737,174 +668,79 @@ SaErrorT build_inserted_interconnect_rpt(struct oh_handler_state *oh_handler,
  *      SA_ERR_HPI_INVALID_PARAMS - on wrong parameters.
  *      SA_ERR_HPI_INTERNAL_ERROR - on failure
  **/
-SaErrorT process_interconnect_thermal_event(struct oh_handler_state *oh_handler,
-                                            struct eventInfo *oa_event)
+void oa_soap_proc_interconnect_thermal(struct oh_handler_state *oh_handler,
+				       SOAP_CON *con,
+				       struct interconnectTrayStatus *response)
 {
         SaErrorT rv = SA_OK;
-        char *entity_root = NULL;
-        SaHpiEntityPathT entity_path;
-        SaHpiEntityPathT root_entity_path;
-        SaHpiRptEntryT *rpt = NULL;
-        SaHpiRdrT *rdr = NULL;
-        struct oa_soap_sensor_info *sensor_info=NULL;
-        SaHpiSensorReadingT current_reading;
-        SaHpiSeverityT event_severity;
+        SaHpiResourceIdT resource_id;
+        struct oa_soap_handler *oa_handler = NULL;
+        SaHpiInt32T bay_number;
+	SaHpiFloat64T trigger_reading;
+	SaHpiFloat64T trigger_threshold;
+	struct getThermalInfo thermal_request;
+	struct thermalInfo thermal_response;
+	struct oa_soap_sensor_info *sensor_info;
+	SaHpiRdrT *rdr;
 
-        if (oh_handler == NULL || oa_event == NULL) {
+        if (oh_handler == NULL || con== NULL || response == NULL) {
                 err("Invalid parameters");
-                return SA_ERR_HPI_INVALID_PARAMS;
+                return;
         }
 
-        entity_root = (char *) g_hash_table_lookup(oh_handler->config,
-                                                   "entity_root");
-        rv = oh_encode_entitypath(entity_root, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
+        oa_handler = (struct oa_soap_handler *) oh_handler->data;
+        bay_number = response->bayNumber;
+        resource_id = oa_handler->
+                oa_soap_resources.interconnect.resource_id[bay_number - 1];
 
-        memset(&entity_path, 0, sizeof(SaHpiEntityPathT));
-        entity_path.Entry[1].EntityType = SAHPI_ENT_ROOT;
-        entity_path.Entry[1].EntityLocation = 0;
-        entity_path.Entry[0].EntityType=SAHPI_ENT_SWITCH_BLADE;
-        entity_path.Entry[0].EntityLocation =
-                oa_event->eventData.interconnectTrayStatus.bayNumber;
+	rdr = oh_get_rdr_by_type(oh_handler->rptcache, resource_id,
+				 SAHPI_SENSOR_RDR, OA_SOAP_SEN_TEMP_STATUS);
+	sensor_info = (struct oa_soap_sensor_info *)
+			oh_get_rdr_data(oh_handler->rptcache, resource_id,
+					rdr->RecordId);
 
-        rv = oh_concat_ep(&entity_path, &root_entity_path);
-        if (rv != SA_OK) {
-                err("Encoding entity path failed");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        rpt = oh_get_resource_by_ep(oh_handler->rptcache, &entity_path);
-        if (rpt == NULL) {
-                err("resource rpt is NULL");
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        rdr = oh_get_rdr_by_type(oh_handler->rptcache,
-                                 rpt->ResourceId,
-                                 SAHPI_SENSOR_RDR,
-                                 OA_SOAP_RES_SEN_TEMP_NUM);
-        if (rdr == NULL) {
-                err("RDR not present");
-                return SA_ERR_HPI_NOT_PRESENT;
-        }
-
-        /* Get the thermal sensor information */
-        sensor_info = (struct oa_soap_sensor_info*)
-                oh_get_rdr_data(oh_handler->rptcache, rpt->ResourceId,
-                                rdr->RecordId);
-        if (sensor_info == NULL) {
-                err("No sensor data. Sensor=%s", rdr->IdString.Data);
-                return SA_ERR_HPI_INTERNAL_ERROR;
-        }
-
-        /* If the thermal sensor is enabled and sensor event is enabled
-         * Then, raise the thermal sensor events can be raised,
-         * Else, ignore the thermal event from OA
+        /* The payload of the thermal event received from OA contains
+	 * sensor status. Based on the sensor status, 
+	 * determine the threshold which triggered the thermal event from OA.
+         * Event with SENSOR_STATUS_CAUTION or SENSOR_STATUS_OK is
+         * generated only if CAUTION threshold is crossed.
+         * Event with SENSOR_STATUS_CRITICAL is generated only when CRITICAL
+         * threshold is crossed.
+         * Sensor current reading and trigger threshold are required for event
+         * generation. Sensor current reading is not provided by the event,
+         * hence make soap call to get the reading
          */
-        if (sensor_info->sensor_enable == SAHPI_FALSE) {
-                dbg("Sensor not enabled for reading");
-                return SA_OK;
-        }
+	thermal_request.bayNumber = bay_number;
+	thermal_request.sensorType = SENSOR_TYPE_INTERCONNECT;
 
-        if (sensor_info->event_enable == SAHPI_FALSE) {
-                dbg("Sensor not enabled for raising events");
-                return SA_OK;
-        }
+	rv = soap_getThermalInfo(con, &thermal_request, &thermal_response);
+	if (rv != SOAP_OK) {
+		err("soap_getThermalInfo soap call returns error");
+		return;
+	}
 
-        current_reading.IsSupported = SAHPI_FALSE;
+        trigger_reading = (SaHpiInt32T)thermal_response.temperatureC;
 
-        /* Check the current state of the sensor */
-        switch (oa_event->eventData.thermalInfo.sensorStatus) {
-                case  SENSOR_STATUS_OK:
-                        /* Sensor has changed the state from Major to OK
-                         * Update the sensor structure
-                         */
-                        sensor_info->previous_state = SAHPI_ES_UPPER_MAJOR;
-                        sensor_info->current_state = SAHPI_ES_UNSPECIFIED;
-                        event_severity = SAHPI_MAJOR;
+        if ((response->thermal == SENSOR_STATUS_CAUTION &&
+	     sensor_info->current_state != SAHPI_ES_UPPER_MAJOR) || 
+	    (response->thermal == SENSOR_STATUS_OK &&
+	      sensor_info->current_state !=  SAHPI_ES_UNSPECIFIED)) {
+		/* Trigger for this event is caution threshold */
+                trigger_threshold = thermal_response.cautionThreshold;
+        } else if (response->thermal == SENSOR_STATUS_CRITICAL  &&
+		   sensor_info->current_state != SAHPI_ES_UPPER_CRIT) {
+		/* Trigger for this event is critical threshold */
+                trigger_threshold = thermal_response.criticalThreshold;
+        } else {
+		dbg("Ignore the event. There is no change in the sensor state");
+		return;
+	}
 
-                        /* Raise the thermal sensor deassert event */
-                        rv = generate_sensor_deassert_thermal_event(oh_handler,
-                                                      OA_SOAP_RES_SEN_TEMP_NUM,
-                                                      rpt,
-                                                      rdr,
-                                                      current_reading,
-                                                      event_severity,
-                                                      sensor_info);
-                        if (rv != SA_OK) {
-                                err("Raising deassert thermal event failed");
-                                return rv;
-                        }
-                        break;
-                case SENSOR_STATUS_CAUTION:
-                        /* Sensor has changed the state to Caution from Major
-                         * or OK.  Update the sensor structure.
-                         */
-                        sensor_info->previous_state =
-                                sensor_info->current_state;
-                        sensor_info->current_state = SAHPI_ES_UPPER_MAJOR;
+        /* Process the thermal event from OA and generate appropriate HPI event
+         */
+        OA_SOAP_PROCESS_SENSOR_EVENT(OA_SOAP_SEN_TEMP_STATUS,
+                                response->thermal,
+                                trigger_reading,trigger_threshold)
 
-                        if (sensor_info->previous_state ==
-                            SAHPI_ES_UNSPECIFIED) {
-                                event_severity = SAHPI_MAJOR;
-                                /* The previous sensor state is OK
-                                 * Raise the thermal sensor assert event
-                                 */
-                                rv = generate_sensor_assert_thermal_event(
-                                        oh_handler,
-                                        OA_SOAP_RES_SEN_TEMP_NUM,
-                                        rpt, rdr, current_reading,
-                                        event_severity, sensor_info);
-                                if (rv != SA_OK) {
-                                        err("Raising assert thermal event "
-                                            "failed");
-                                        return rv;
-                                }
-                        } else {
-                                event_severity = SAHPI_CRITICAL;
-                                /* The previous sensor state is Major
-                                 * Raise the thermal sensor deassert event
-                                 */
-                                rv = generate_sensor_deassert_thermal_event(
-                                        oh_handler,
-                                        OA_SOAP_RES_SEN_TEMP_NUM,
-                                        rpt, rdr, current_reading,
-                                        event_severity, sensor_info);
-                                if (rv != SA_OK) {
-                                        err("Raising assert thermal event "
-                                            "failed");
-                                        return rv;
-                                }
-                        }
-                        break;
-                case SENSOR_STATUS_CRITICAL:
-                        /* Sensor has changed the state from Caution to Critical
-                         * Update the sensor structure
-                         */
-                        sensor_info->previous_state = SAHPI_ES_UPPER_MAJOR;
-                        sensor_info->current_state = SAHPI_ES_UPPER_CRIT;
-                        event_severity = SAHPI_CRITICAL;
-
-                        /* Raise the thermal sensor assert event */
-                        rv = generate_sensor_assert_thermal_event(oh_handler,
-                                                    OA_SOAP_RES_SEN_TEMP_NUM,
-                                                    rpt,
-                                                    rdr,
-                                                    current_reading,
-                                                    event_severity,
-                                                    sensor_info);
-                        if (rv != SA_OK) {
-                                err("Raising assert thermal event failed");
-                                return rv;
-                        }
-                        break;
-                default:
-                        err("Sensor status not handled");
-                        return SA_OK;
-        }
-        return SA_OK;
+        return;
 }
-
