@@ -12,7 +12,7 @@
  * Author(s):
  *        Christina Hernandez <hernanc@us.ibm.com>
  *        W. David Ashley <dashley@us.ibm.com>
- *	  Renier Morales <renierm@users.sourceforge.net>
+ *	  Renier Morales <renier@openhpi.org>
  */
 
 
@@ -38,13 +38,36 @@ static SaErrorT new_control(struct oh_handler_state *state,
         oh_init_textbuffer(&rdr->IdString);
         oh_append_textbuffer(&rdr->IdString, mycontrol->comment);
         rdr->RecordId =
-                get_rdr_uid(SAHPI_CTRL_RDR, rdr->RdrTypeUnion.CtrlRec.Num);
+                oh_get_rdr_uid(SAHPI_CTRL_RDR, rdr->RdrTypeUnion.CtrlRec.Num);
 
 	rdr->Entity = e->resource.ResourceEntity;
 
         //set up our private data
         info = (struct sim_control_info *)g_malloc(sizeof(struct sim_control_info));
         info->mode = mycontrol->mode;
+	info->state.Type = rdr->RdrTypeUnion.CtrlRec.Type;
+	switch (info->state.Type) {
+		case SAHPI_CTRL_TYPE_DIGITAL:
+			info->state.StateUnion.Digital = rdr->RdrTypeUnion.CtrlRec.TypeUnion.Digital.Default;
+			break;
+		case SAHPI_CTRL_TYPE_DISCRETE:
+			info->state.StateUnion.Discrete = rdr->RdrTypeUnion.CtrlRec.TypeUnion.Discrete.Default;
+			break;
+		case SAHPI_CTRL_TYPE_ANALOG:
+			info->state.StateUnion.Analog = rdr->RdrTypeUnion.CtrlRec.TypeUnion.Analog.Default;
+			break;
+		case SAHPI_CTRL_TYPE_STREAM:
+			memcpy(&info->state.StateUnion.Stream, &rdr->RdrTypeUnion.CtrlRec.TypeUnion.Stream.Default, sizeof(SaHpiCtrlStateStreamT));
+			break;
+		case SAHPI_CTRL_TYPE_TEXT:
+			memcpy(&info->state.StateUnion.Text, &rdr->RdrTypeUnion.CtrlRec.TypeUnion.Text.Default, sizeof(SaHpiCtrlStateTextT));
+			break;
+		case SAHPI_CTRL_TYPE_OEM:
+			memcpy(&info->state.StateUnion.Oem, &rdr->RdrTypeUnion.CtrlRec.TypeUnion.Oem.Default, sizeof(SaHpiCtrlStateOemT));
+			break;
+		default:
+			err("Bad Error: Unrecognized control type.");
+	}
 
         // everything ready so add the rdr and extra info to the rptcache
 	error = sim_inject_rdr(state, e, rdr, info);
@@ -66,13 +89,13 @@ SaErrorT sim_discover_chassis_controls(struct oh_handler_state *state,
         while (sim_chassis_controls[i].index != 0) {
                 rc = new_control(state, e, &sim_chassis_controls[i]);
                 if (rc) {
-                        dbg("Error %d returned when adding chassis control", rc);
+                        err("Error %d returned when adding chassis control", rc);
                 } else {
                         j++;
                 }
                 i++;
         }
-        trace("%d of %d chassis controls injected", j, i);
+        dbg("%d of %d chassis controls injected", j, i);
 
         return 0;
 }
@@ -87,13 +110,13 @@ SaErrorT sim_discover_cpu_controls(struct oh_handler_state *state,
         while (sim_cpu_controls[i].index != 0) {
                 rc = new_control(state, e, &sim_cpu_controls[i]);
                 if (rc) {
-                        dbg("Error %d returned when adding cpu control", rc);
+                        err("Error %d returned when adding cpu control", rc);
                 } else {
                         j++;
                 }
                 i++;
         }
-        trace("%d of %d cpu controls injected", j, i);
+        dbg("%d of %d cpu controls injected", j, i);
 
         return 0;
 }
@@ -108,13 +131,13 @@ SaErrorT sim_discover_dasd_controls(struct oh_handler_state *state,
         while (sim_dasd_controls[i].index != 0) {
                 rc = new_control(state, e, &sim_dasd_controls[i]);
                 if (rc) {
-                        dbg("Error %d returned when adding dasd control", rc);
+                        err("Error %d returned when adding dasd control", rc);
                 } else {
                         j++;
                 }
                 i++;
         }
-        trace("%d of %d dasd controls injected", j, i);
+        dbg("%d of %d dasd controls injected", j, i);
 
         return 0;
 }
@@ -129,13 +152,13 @@ SaErrorT sim_discover_hs_dasd_controls(struct oh_handler_state *state,
         while (sim_hs_dasd_controls[i].index != 0) {
                 rc = new_control(state, e, &sim_hs_dasd_controls[i]);
                 if (rc) {
-                        dbg("Error %d returned when adding hs dasd control", rc);
+                        err("Error %d returned when adding hs dasd control", rc);
                 } else {
                         j++;
                 }
                 i++;
         }
-        trace("%d of %d hs dasd controls injected", j, i);
+        dbg("%d of %d hs dasd controls injected", j, i);
 
         return 0;
 }
@@ -150,13 +173,13 @@ SaErrorT sim_discover_fan_controls(struct oh_handler_state *state,
         while (sim_fan_controls[i].index != 0) {
                 rc = new_control(state, e, &sim_fan_controls[i]);
                 if (rc) {
-                        dbg("Error %d returned when adding fan control", rc);
+                        err("Error %d returned when adding fan control", rc);
                 } else {
                         j++;
                 }
                 i++;
         }
-        trace("%d of %d fan controls injected", j, i);
+        dbg("%d of %d fan controls injected", j, i);
 
         return 0;
 }
