@@ -10,7 +10,7 @@
  * full licensing terms.
  *
  * Author(s):
- *      Renier Morales <renierm@users.sf.net>
+ *      Renier Morales <renier@openhpi.org>
  *      Steve Sherman <stevees@us.ibm.com>
  */
 
@@ -36,7 +36,7 @@ SaErrorT snmp_bc_get_event(void *hnd)
         struct snmp_bc_hnd *custom_handle;
 	
         if (!hnd) {
-                dbg("Invalid parameter");
+                err("Invalid parameter");
                 return(SA_ERR_HPI_INVALID_PARAMS);
         }
 
@@ -50,7 +50,7 @@ SaErrorT snmp_bc_get_event(void *hnd)
 	/* log error but take no corrected action.      */
 	/* New entry will still be there next time      */
 	if (err) {
-		dbg("Event Log cache build/sync failed. Error=%s", oh_lookup_error(err));
+		err("Event Log cache build/sync failed. Error=%s", oh_lookup_error(err));
 		/* return(err); */
 	}
 
@@ -79,7 +79,7 @@ SaErrorT snmp_bc_get_event(void *hnd)
  * Return values:
  * SA_OK - Normal case.
  * SA_ERR_HPI_INVALID_PARAMS - @tag is NULL or invalid.
- * SA_ERR_HPI_OUT_OF_SPACE - No memory to allocate event.
+ * SA_ERR_HPI_OUT_OF_MEMORY - No memory to allocate event.
  **/
 SaErrorT snmp_bc_set_resource_tag(void *hnd, SaHpiResourceIdT rid, SaHpiTextBufferT *tag)
 {
@@ -92,7 +92,7 @@ SaErrorT snmp_bc_set_resource_tag(void *hnd, SaHpiResourceIdT rid, SaHpiTextBuff
 	struct ResourceInfo *res_info_ptr;
 
 	if (!oh_valid_textbuffer(tag) || !hnd) {
-		dbg("Invalid parameter");
+		err("Invalid parameter");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 	
@@ -103,7 +103,7 @@ SaErrorT snmp_bc_set_resource_tag(void *hnd, SaHpiResourceIdT rid, SaHpiTextBuff
 	rpt = oh_get_resource_by_id(handle->rptcache, rid);
         if (!rpt) {
 		snmp_bc_unlock_handler(custom_handle);
-		dbg("No RID.");
+		err("No RID.");
                 return(SA_ERR_HPI_INVALID_RESOURCE);
         }
 
@@ -111,14 +111,14 @@ SaErrorT snmp_bc_set_resource_tag(void *hnd, SaHpiResourceIdT rid, SaHpiTextBuff
 						handle->rptcache, rpt->ResourceId);
         if (!res_info_ptr) {
 		snmp_bc_unlock_handler(custom_handle);
-		dbg("No resource information.");
+		err("No resource information.");
                 return(SA_ERR_HPI_INVALID_RESOURCE);
         }	
 						
 	err = oh_copy_textbuffer(&(rpt->ResourceTag), tag);
 	if (err) {
 		snmp_bc_unlock_handler(custom_handle);
-		dbg("Cannot copy textbuffer");
+		err("Cannot copy textbuffer");
 		return(err);
 	}
 
@@ -126,8 +126,8 @@ SaErrorT snmp_bc_set_resource_tag(void *hnd, SaHpiResourceIdT rid, SaHpiTextBuff
         e = snmp_bc_alloc_oh_event();
 	if (e == NULL) {
 		snmp_bc_unlock_handler(custom_handle);
-		dbg("Out of memory.");
-		return(SA_ERR_HPI_OUT_OF_SPACE);
+		err("Out of memory.");
+		return(SA_ERR_HPI_OUT_OF_MEMORY);
 	}
 			
         e->resource = *rpt;
@@ -157,7 +157,7 @@ SaErrorT snmp_bc_set_resource_tag(void *hnd, SaHpiResourceIdT rid, SaHpiTextBuff
  * Return values:
  * SA_OK - Normal case.
  * SA_ERR_HPI_INVALID_PARAMS - @sev is invalid.
- * SA_ERR_HPI_OUT_OF_SPACE - No memory to allocate event.
+ * SA_ERR_HPI_OUT_OF_MEMORY - No memory to allocate event.
  **/
 SaErrorT snmp_bc_set_resource_severity(void *hnd, SaHpiResourceIdT rid, SaHpiSeverityT sev)
 {
@@ -168,7 +168,7 @@ SaErrorT snmp_bc_set_resource_severity(void *hnd, SaHpiResourceIdT rid, SaHpiSev
 	struct ResourceInfo *res_info_ptr;
 
 	if (oh_lookup_severity(sev) == NULL) {
-		dbg("Invalid parameter");
+		err("Invalid parameter");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 	
@@ -179,7 +179,7 @@ SaErrorT snmp_bc_set_resource_severity(void *hnd, SaHpiResourceIdT rid, SaHpiSev
 	rpt = oh_get_resource_by_id(handle->rptcache, rid);
         if (!rpt) {
 		snmp_bc_unlock_handler(custom_handle);
-                dbg("No RID.");
+                err("No RID.");
                 return(SA_ERR_HPI_INVALID_RESOURCE);
         }
 
@@ -187,7 +187,7 @@ SaErrorT snmp_bc_set_resource_severity(void *hnd, SaHpiResourceIdT rid, SaHpiSev
 						handle->rptcache, rpt->ResourceId);
         if (!res_info_ptr) {
 		snmp_bc_unlock_handler(custom_handle);
-		dbg("No resource information.");
+		err("No resource information.");
                 return(SA_ERR_HPI_INVALID_RESOURCE);
         }	
 
@@ -199,8 +199,8 @@ SaErrorT snmp_bc_set_resource_severity(void *hnd, SaHpiResourceIdT rid, SaHpiSev
         e = snmp_bc_alloc_oh_event();
 	if (e == NULL) {
 		snmp_bc_unlock_handler(custom_handle);
-		dbg("Out of memory.");
-		return(SA_ERR_HPI_OUT_OF_SPACE);
+		err("Out of memory.");
+		return(SA_ERR_HPI_OUT_OF_MEMORY);
 	}
 			
         e->resource = *rpt;
@@ -239,11 +239,11 @@ SaErrorT snmp_bc_control_parm(void *hnd, SaHpiResourceIdT rid, SaHpiParmActionT
 	struct snmp_bc_hnd *custom_handle;
 
 	if (!hnd) {
-		printf("Invalid parameter - hnd");
+		dbg("Invalid parameter - hnd");
 		return(SA_ERR_HPI_INVALID_PARAMS);	
 	}
 	if (oh_lookup_parmaction(act) == NULL) {
-		printf("Invalid parameter - act");
+		dbg("Invalid parameter - act");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 	
@@ -254,13 +254,13 @@ SaErrorT snmp_bc_control_parm(void *hnd, SaHpiResourceIdT rid, SaHpiParmActionT
 	snmp_bc_lock_handler(custom_handle);
 	rpt = oh_get_resource_by_id(handle->rptcache, rid);
 	if (!rpt) {
-                dbg("No RID.");
+                err("No RID.");
 		snmp_bc_unlock_handler(custom_handle);
                 return(SA_ERR_HPI_INVALID_RESOURCE);
 	}
 
 	if (rpt->ResourceCapabilities & SAHPI_CAPABILITY_CONFIGURATION) {
-		dbg("Resource configuration saving not supported.");
+		err("Resource configuration saving not supported.");
 		snmp_bc_unlock_handler(custom_handle);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
@@ -273,12 +273,11 @@ SaErrorT snmp_bc_control_parm(void *hnd, SaHpiResourceIdT rid, SaHpiParmActionT
 
 #define snmp_bc_internal_retry()                   \
 	if (l_retry >= 2) {                        \
-        	custom_handle->handler_retries++;  \
+        	custom_handle->handler_retries = SNMP_BC_MAX_SNMP_RETRY_ATTEMPTED;  \
 		err = SA_ERR_HPI_BUSY;             \
 		break;                             \
 	} else {                                   \
 		l_retry++;                         \
-		trace("Retrying OID=%s.", objid);  \
 		continue;                          \
 	}
 
@@ -314,34 +313,34 @@ SaErrorT snmp_bc_snmp_get(struct snmp_bc_hnd *custom_handle,
 	
 	do {	
         	err = snmp_get(custom_handle->sessp, objid, value);
-        	if (err == SA_ERR_HPI_TIMEOUT) {
-                	if (custom_handle->handler_retries == SNMP_BC_MAX_SNMP_RETRY_ATTEMPTED) {
-                        	custom_handle->handler_retries = 0;
-                        	err = SA_ERR_HPI_NO_RESPONSE;
-				break;
+	        if ((err == SA_ERR_HPI_TIMEOUT) || (err == SA_ERR_HPI_ERROR)) {
+                	if ( (err == SA_ERR_HPI_ERROR) || 
+				(custom_handle->handler_retries == SNMP_BC_MAX_SNMP_RETRY_ATTEMPTED)) {
+				err = snmp_bc_recover_snmp_session(custom_handle);
+				if (err) {
+                        		custom_handle->handler_retries = 0;
+                        		err = SA_ERR_HPI_NO_RESPONSE;
+					break;
+				} else {
+					if (retry) l_retry = 0;
+					else l_retry = 2;
+					custom_handle->handler_retries = 0;
+				}
                 	} else {
-				trace("HPI_TIMEOUT %s", objid);
+				dbg("HPI_TIMEOUT %s", objid);
 				snmp_bc_internal_retry();  /* l_retry got incremented here */			
 			}
         	} else {
                 	custom_handle->handler_retries = 0;
 			if ((err == SA_OK) && (value->type == ASN_OCTET_STR)) {
-#if 0
-				if ( (g_ascii_strncasecmp(value->string,"(No temperature)", sizeof("(No temperature)")) == 0) ||
-			     		(g_ascii_strncasecmp(value->string,"(No voltage)", sizeof("(No voltage)")) == 0) )
-				{
-					snmp_bc_internal_retry();
-				}
-				else
-#endif
 				if ((g_ascii_strncasecmp(value->string,"Not Readable!", sizeof("Not Readable!")) == 0) ||
 				    (g_ascii_strncasecmp(value->string,"Not Readable", sizeof("Not Readable")) == 0) ||
 				    (g_ascii_strncasecmp(value->string,"(No temperature)", sizeof("(No temperature)")) == 0) ||
 				    (g_ascii_strncasecmp(value->string,"NO_TEMPERATURE", sizeof("NO_TEMPERATURE")) == 0) ||
-				    (!value->string) ||
-				    (value->string[0] == '\0')) {
+				    (!value->string) ) /*||
+				    (value->string[0] == '\0'))*/ {
 					custom_handle->handler_retries = 0;
-					trace("Not readable reading from OID=%s.", objid);
+					dbg("Not readable reading from OID=%s.", objid);
                         		err = SA_ERR_HPI_NO_RESPONSE;
 					break;
 				} else {
@@ -388,7 +387,7 @@ SaErrorT snmp_bc_oid_snmp_get(struct snmp_bc_hnd *custom_handle,
 	oid = oh_derive_string(ep, loc_offset, 10, oidstr);
 	
 	if (oid == NULL) {
-		dbg("Cannot derive %s.", oidstr); 
+		err("Cannot derive %s.", oidstr); 
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 	
@@ -469,7 +468,7 @@ SaErrorT snmp_bc_oid_snmp_set(struct snmp_bc_hnd *custom_handle,
 	rv = SA_OK;
 	oid = oh_derive_string(ep, loc_offset, 10, oidstr);
 	if (oid == NULL) {
-		dbg("NULL SNMP OID returned for %s.", oidstr);
+		err("NULL SNMP OID returned for %s.", oidstr);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 	rv = snmp_bc_snmp_set(custom_handle, oid, value);
