@@ -50,7 +50,7 @@ SaErrorT snmp_bc_get_sensor_reading(void *hnd,
         SaHpiRdrT *rdr;
 
 	if (!hnd) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -58,7 +58,7 @@ SaErrorT snmp_bc_get_sensor_reading(void *hnd,
 	custom_handle = (struct snmp_bc_hnd *)handle->data;
 	
 	if (!custom_handle) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 	snmp_bc_lock_handler(custom_handle);
@@ -84,7 +84,7 @@ SaErrorT snmp_bc_get_sensor_reading(void *hnd,
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
 		snmp_bc_unlock_handler(custom_handle);
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}       
 	
@@ -96,7 +96,7 @@ SaErrorT snmp_bc_get_sensor_reading(void *hnd,
 	memset(&working_reading, 0, sizeof(SaHpiSensorReadingT));
 	working_state = SAHPI_ES_UNSPECIFIED;
 
-	trace("Sensor Reading: Resource=%s; RDR=%s", rpt->ResourceTag.Data, rdr->IdString.Data);
+	dbg("Sensor Reading: Resource=%s; RDR=%s", rpt->ResourceTag.Data, rdr->IdString.Data);
 	
 	/************************************************************
 	 * Get sensor's reading.
@@ -128,7 +128,7 @@ SaErrorT snmp_bc_get_sensor_reading(void *hnd,
 		}
 	
 		if (err) {
-			dbg("Cannot determine sensor's reading. Error=%s", oh_lookup_error(err));
+			err("Cannot determine sensor's reading. Error=%s", oh_lookup_error(err));
 			snmp_bc_unlock_handler(custom_handle);
 			return(err);
 		}
@@ -144,7 +144,7 @@ SaErrorT snmp_bc_get_sensor_reading(void *hnd,
 	 ******************************************************************/
 	err = snmp_bc_get_sensor_eventstate(hnd, rid, sid, &working_reading, &working_state);
 	if (err) {
-		dbg("Cannot determine sensor's event state. Error=%s", oh_lookup_error(err));
+		err("Cannot determine sensor's event state. Error=%s", oh_lookup_error(err));
 		snmp_bc_unlock_handler(custom_handle);
 		return(err);
 	}
@@ -201,7 +201,7 @@ SaErrorT snmp_bc_get_sensor_eventstate(void *hnd,
 	SaErrorT err;
 
 	if (!hnd || !reading || !state) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -216,7 +216,7 @@ SaErrorT snmp_bc_get_sensor_eventstate(void *hnd,
 	if (rdr == NULL) return(SA_ERR_HPI_NOT_PRESENT);
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}       
 	if (sinfo->sensor_enabled == SAHPI_FALSE) return(SA_ERR_HPI_INVALID_REQUEST);
@@ -246,7 +246,7 @@ SaErrorT snmp_bc_get_sensor_eventstate(void *hnd,
 
 		err = snmp_bc_get_sensor_thresholds(hnd, rid, sid, &thres);
 		if (err) {
-			dbg("Cannot get sensor thresholds for Sensor=%s. Error=%s", 
+			err("Cannot get sensor thresholds for Sensor=%s. Error=%s", 
 			    rdr->IdString.Data, oh_lookup_error(err));
 			return(err);
 		}
@@ -288,7 +288,11 @@ SaErrorT snmp_bc_get_sensor_eventstate(void *hnd,
 		}
 		
 	} else if (rdr->RdrTypeUnion.SensorRec.Category == SAHPI_EC_PRESENCE) {
-		*state = SAHPI_ES_PRESENT;
+		if ((sid == BLADECENTER_SENSOR_NUM_SLOT_STATE) ||
+			(sid == BLADECENTER_SENSOR_NUM_MGMNT_STANDBY))
+			*state = sinfo->cur_state;
+		else
+			*state = SAHPI_ES_PRESENT;
 		
 	} else {		
 	
@@ -347,7 +351,7 @@ do { \
         if (rdr->RdrTypeUnion.SensorRec.ThresholdDefn.ReadThold & thdmask) { \
 		if (sinfo->mib.threshold_oids.thdname == NULL || \
 		    sinfo->mib.threshold_oids.thdname[0] == '\0') { \
-			dbg("No OID defined for readable threshold. Sensor=%s", rdr->IdString.Data); \
+			err("No OID defined for readable threshold. Sensor=%s", rdr->IdString.Data); \
 			snmp_bc_unlock_handler(custom_handle); \
 			return(SA_ERR_HPI_INTERNAL_ERROR); \
 		} \
@@ -359,7 +363,7 @@ do { \
 			return(err); \
 		} \
 		if (working.thdname.Type == SAHPI_SENSOR_READING_TYPE_BUFFER) { \
-			dbg("Sensor type SAHPI_SENSOR_READING_TYPE_BUFFER cannot have thresholds. Sensor=%s", \
+			err("Sensor type SAHPI_SENSOR_READING_TYPE_BUFFER cannot have thresholds. Sensor=%s", \
 			    rdr->IdString.Data); \
 			snmp_bc_unlock_handler(custom_handle); \
 			return(SA_ERR_HPI_INTERNAL_ERROR); \
@@ -405,7 +409,7 @@ SaErrorT snmp_bc_get_logical_sensors(void *hnd,
 
 
 	if (!hnd) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -414,7 +418,7 @@ SaErrorT snmp_bc_get_logical_sensors(void *hnd,
 	custom_handle = (struct snmp_bc_hnd *)handle->data;
 	
 	if (!custom_handle) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 	
@@ -424,7 +428,7 @@ SaErrorT snmp_bc_get_logical_sensors(void *hnd,
 	/* Fetch Active MM ID */
 	err = snmp_bc_snmp_get(custom_handle, SNMP_BC_MGMNT_ACTIVE, &active_mm_id, SAHPI_TRUE);
         if (err || active_mm_id.type != ASN_INTEGER) {
-		dbg("Cannot get SNMP_BC_MGMNT_ACTIVE=%s; Received Type=%d; Error=%s.",
+		err("Cannot get SNMP_BC_MGMNT_ACTIVE=%s; Received Type=%d; Error=%s.",
 		      SNMP_BC_MGMNT_ACTIVE, active_mm_id.type, oh_lookup_error(err));
 		if (err) { return(err); }
 		else { return(SA_ERR_HPI_INTERNAL_ERROR); }
@@ -446,13 +450,13 @@ SaErrorT snmp_bc_get_logical_sensors(void *hnd,
 						mm_id = 1;
 						break;
 					default:
-						dbg("Internal Error.");
+						err("Internal Error.");
 						break;
 				}
 			}
 			break; 
 		default:
-			dbg("Should not be here. sid is not one of the special sensors.");
+			err("Should not be here. sid is not one of the special sensors.");
 			break;
 	}
 
@@ -463,7 +467,7 @@ SaErrorT snmp_bc_get_logical_sensors(void *hnd,
 	if (mm_id != SNMP_BC_NOT_VALID) {
 		root_tuple = (char *)g_hash_table_lookup(handle->config, "entity_root");
         	if (root_tuple == NULL) {
-                	dbg("Cannot find configuration parameter.");
+                	err("Cannot find configuration parameter.");
                 	snmp_bc_unlock_handler(custom_handle);
                 	return(SA_ERR_HPI_INTERNAL_ERROR);
         	}
@@ -515,7 +519,7 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 	SaErrorT err;
 
 	if (!hnd || !thres) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 		
@@ -544,7 +548,7 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 	
         sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		snmp_bc_unlock_handler(custom_handle);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
@@ -607,13 +611,13 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 		SaHpiSensorReadingT reading;
 
 		if (found_thresholds & SAHPI_STM_LOW_HYSTERESIS) {
-			dbg("Cannot define both delta and total negative hysteresis. Sensor=%s",
+			err("Cannot define both delta and total negative hysteresis. Sensor=%s",
 			    rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
 		if (lower_thresholds == 0) {
-			dbg("No lower thresholds are defined for total negative hysteresis. Sensor=%s",
+			err("No lower thresholds are defined for total negative hysteresis. Sensor=%s",
 			    rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
@@ -645,7 +649,7 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 			}
 
 			if (delta < 0) {
-				dbg("Negative hysteresis delta is less than 0");
+				err("Negative hysteresis delta is less than 0");
 				working.NegThdHysteresis.IsSupported = SAHPI_FALSE;
 			}
 			else {
@@ -671,7 +675,7 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 			}
 
 			if (delta < 0) {
-				dbg("Negative hysteresis delta is less than 0");
+				err("Negative hysteresis delta is less than 0");
 				working.NegThdHysteresis.IsSupported = SAHPI_FALSE;
 			}
 			else {
@@ -684,7 +688,7 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 		case SAHPI_SENSOR_READING_TYPE_UINT64:
 		case SAHPI_SENSOR_READING_TYPE_BUFFER:
 		default:
-			dbg("Invalid reading type for threshold. Sensor=%s", rdr->IdString.Data);
+			err("Invalid reading type for threshold. Sensor=%s", rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
@@ -695,13 +699,13 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 		SaHpiSensorReadingT reading;
 
 		if (found_thresholds & SAHPI_STM_UP_HYSTERESIS) {
-			dbg("Cannot define both delta and total positive hysteresis. Sensor=%s",
+			err("Cannot define both delta and total positive hysteresis. Sensor=%s",
 			    rdr->IdString.Data);			    
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
 		if (upper_thresholds == 0) {
-			dbg("No upper thresholds are defined for total positive hysteresis. Sensor=%s",
+			err("No upper thresholds are defined for total positive hysteresis. Sensor=%s",
 			    rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
@@ -733,7 +737,7 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 			}
 
 			if (delta < 0) {
-				dbg("Positive hysteresis delta is less than 0");
+				err("Positive hysteresis delta is less than 0");
 				working.PosThdHysteresis.IsSupported = SAHPI_FALSE;
 			}
 			else {
@@ -759,7 +763,7 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 			}
 
 			if (delta < 0) {
-				dbg("Positive hysteresis delta is less than 0");
+				err("Positive hysteresis delta is less than 0");
 				working.PosThdHysteresis.IsSupported = SAHPI_FALSE;
 			}
 			else {
@@ -773,14 +777,14 @@ SaErrorT snmp_bc_get_sensor_thresholds(void *hnd,
 		case SAHPI_SENSOR_READING_TYPE_UINT64:
 		case SAHPI_SENSOR_READING_TYPE_BUFFER:
 		default:
-			dbg("Invalid reading type for threshold. Sensor=%s", rdr->IdString.Data);
+			err("Invalid reading type for threshold. Sensor=%s", rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
 	}
 
 	if (found_thresholds == 0) {
-		dbg("No readable thresholds found. Sensor=%s", rdr->IdString.Data);
+		err("No readable thresholds found. Sensor=%s", rdr->IdString.Data);
 		snmp_bc_unlock_handler(custom_handle);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
@@ -807,7 +811,7 @@ do { \
 		        break; \
         	case SAHPI_SENSOR_READING_TYPE_BUFFER: \
         	default: \
-        		dbg("Invalid threshold reading type."); \
+        		err("Invalid threshold reading type."); \
 			snmp_bc_unlock_handler(custom_handle); \
         		return(SA_ERR_HPI_INVALID_CMD); \
         	} \
@@ -819,7 +823,7 @@ do { \
 	if (thres->thdname.IsSupported) { \
 		if (sinfo->mib.threshold_write_oids.thdname == NULL || \
 		    sinfo->mib.threshold_oids.thdname[0] == '\0') { \
-			dbg("No writable threshold OID defined for thdname."); \
+			err("No writable threshold OID defined for thdname."); \
 			snmp_bc_unlock_handler(custom_handle); \
 			return(SA_ERR_HPI_INTERNAL_ERROR); \
 		} \
@@ -864,7 +868,7 @@ SaErrorT snmp_bc_set_sensor_thresholds(void *hnd,
         SaHpiRdrT *rdr;
 
 	if (!hnd || !thres) {
-		dbg("Invalid parameter");
+		err("Invalid parameter");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 		
@@ -893,7 +897,7 @@ SaErrorT snmp_bc_set_sensor_thresholds(void *hnd,
 	
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		snmp_bc_unlock_handler(custom_handle);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}       
@@ -966,7 +970,7 @@ SaErrorT snmp_bc_get_sensor_oid_reading(void *hnd,
 	if (rdr == NULL) return(SA_ERR_HPI_NOT_PRESENT);
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 
@@ -975,7 +979,7 @@ SaErrorT snmp_bc_get_sensor_oid_reading(void *hnd,
 	err = snmp_bc_oid_snmp_get(custom_handle, &valEntity, sinfo->mib.loc_offset,
 				   raw_oid, &get_value, SAHPI_TRUE);
 	if (err) {
-		dbg("SNMP cannot read sensor OID=%s. Type=%d", raw_oid, get_value.type);
+		err("SNMP cannot read sensor OID=%s. Type=%d", raw_oid, get_value.type);
 		return(err);
 	}
 		
@@ -994,7 +998,7 @@ SaErrorT snmp_bc_get_sensor_oid_reading(void *hnd,
 					      rdr->RdrTypeUnion.SensorRec.DataFormat.ReadingType,
 					      &working);
 		if (err) {
-			dbg("Cannot convert sensor OID=%s value=%s. Error=%s",
+			err("Cannot convert sensor OID=%s value=%s. Error=%s",
 			    sinfo->mib.oid, buffer.Data, oh_lookup_error(err));
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
@@ -1022,7 +1026,7 @@ SaErrorT snmp_bc_set_threshold_reading(void *hnd,
 	SaHpiRdrT *rdr;
 
 	if (!hnd || !reading || !raw_oid) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 
@@ -1033,7 +1037,7 @@ SaErrorT snmp_bc_set_threshold_reading(void *hnd,
 	if (rdr == NULL) return(SA_ERR_HPI_NOT_PRESENT);
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 
@@ -1053,7 +1057,7 @@ SaErrorT snmp_bc_set_threshold_reading(void *hnd,
 		break;
 	case SAHPI_SENSOR_READING_TYPE_BUFFER:
 		default:
-			dbg("Invalid type for threshold. Sensor=%s", rdr->IdString.Data);
+			err("Invalid type for threshold. Sensor=%s", rdr->IdString.Data);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 
@@ -1071,7 +1075,7 @@ SaErrorT snmp_bc_set_threshold_reading(void *hnd,
 	err = snmp_bc_oid_snmp_set(custom_handle, &valEntity, sinfo->mib.loc_offset,
 				   raw_oid, set_value);
 	if (err) {
-		dbg("SNMP cannot set sensor OID=%s.", raw_oid);
+		err("SNMP cannot set sensor OID=%s.", raw_oid);
 		return(err);
 	}
 		
@@ -1105,7 +1109,7 @@ SaErrorT snmp_bc_get_sensor_enable(void *hnd,
         SaHpiRdrT *rdr;
 
 	if (!hnd || !enable) {
-		dbg("Invalid parameter");
+		err("Invalid parameter");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -1134,7 +1138,7 @@ SaErrorT snmp_bc_get_sensor_enable(void *hnd,
 	
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		snmp_bc_unlock_handler(custom_handle);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}       
@@ -1171,7 +1175,7 @@ SaErrorT snmp_bc_set_sensor_enable(void *hnd,
 	struct SensorInfo *sinfo;
 
 	if (!hnd ) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -1199,10 +1203,10 @@ SaErrorT snmp_bc_set_sensor_enable(void *hnd,
 	}
 	
 	if (rdr->RdrTypeUnion.SensorRec.EnableCtrl == SAHPI_TRUE) {
-		dbg("BladeCenter/RSA do not support snmp_bc_set_sensor_enable");
+		err("BladeCenter/RSA do not support snmp_bc_set_sensor_enable");
 		sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
 		if (sinfo == NULL) {
-			dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+			err("No sensor data. Sensor=%s", rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
@@ -1248,7 +1252,7 @@ SaErrorT snmp_bc_get_sensor_event_enable(void *hnd,
         SaHpiRdrT *rdr;
 
 	if (!hnd || !enable) {
-		dbg("Invalid parameter");
+		err("Invalid parameter");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -1277,7 +1281,7 @@ SaErrorT snmp_bc_get_sensor_event_enable(void *hnd,
 	
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		snmp_bc_unlock_handler(custom_handle);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}       
@@ -1314,7 +1318,7 @@ SaErrorT snmp_bc_set_sensor_event_enable(void *hnd,
 	struct SensorInfo *sinfo;
 
 	if (!hnd ) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -1344,10 +1348,10 @@ SaErrorT snmp_bc_set_sensor_event_enable(void *hnd,
 	
 	if (rdr->RdrTypeUnion.SensorRec.EventCtrl == SAHPI_SEC_PER_EVENT ||
 	    rdr->RdrTypeUnion.SensorRec.EventCtrl == SAHPI_SEC_READ_ONLY_MASKS) {
-		dbg("BladeCenter/RSA do not support snmp_bc_set_sensor_event_enable.");    
+		err("BladeCenter/RSA do not support snmp_bc_set_sensor_event_enable.");    
 		sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
 		if (sinfo == NULL) {
-			dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+			err("No sensor data. Sensor=%s", rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
@@ -1395,7 +1399,7 @@ SaErrorT snmp_bc_get_sensor_event_masks(void *hnd,
         SaHpiRdrT *rdr;
 
 	if (!hnd ) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 		
@@ -1424,7 +1428,7 @@ SaErrorT snmp_bc_get_sensor_event_masks(void *hnd,
 	
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		snmp_bc_unlock_handler(custom_handle);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}       
@@ -1478,7 +1482,7 @@ SaErrorT snmp_bc_set_sensor_event_masks(void *hnd,
 	SaHpiEventStateT orig_deassert_mask;
 
 	if (!hnd ) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -1510,11 +1514,11 @@ SaErrorT snmp_bc_set_sensor_event_masks(void *hnd,
 	}
 	
 	if (rdr->RdrTypeUnion.SensorRec.EventCtrl == SAHPI_SEC_PER_EVENT) {
-		dbg("BladeCenter/RSA do not support snmp_bc_set_sensor_event_masks");
+		err("BladeCenter/RSA do not support snmp_bc_set_sensor_event_masks");
                 /* Probably need to drive an OID, if hardware supported it */
 		sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
 		if (sinfo == NULL) {
-			dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+			err("No sensor data. Sensor=%s", rdr->IdString.Data);
 			snmp_bc_unlock_handler(custom_handle);
 			return(SA_ERR_HPI_INTERNAL_ERROR);
 		}
@@ -1603,7 +1607,9 @@ SaErrorT snmp_bc_set_sensor_event_masks(void *hnd,
  * SA_OK - Normal case.
  * SA_ERR_HPI_INVALID_PARAMS - Resource doesn't have SAHPI_CAPABILITY_SENSOR.
  **/
-SaErrorT snmp_bc_set_slot_state_sensor(void *hnd, struct oh_event *e, SaHpiEntityPathT *slot_ep)
+SaErrorT snmp_bc_set_slot_state_sensor(void *hnd, 
+					struct oh_event *e, 
+					SaHpiEntityPathT *slot_ep)
 {
 
 	SaErrorT err;
@@ -1623,7 +1629,7 @@ SaErrorT snmp_bc_set_slot_state_sensor(void *hnd, struct oh_event *e, SaHpiEntit
 	res = oh_get_resource_by_ep(handle->rptcache, slot_ep);
 	
         if (!res) {
-		dbg("No valid resource or rdr at hand. Could not process new rdr.");
+		err("No valid resource or rdr at hand. Could not process new rdr.");
                 return(SA_ERR_HPI_INVALID_DATA);
 	}
 
@@ -1633,9 +1639,10 @@ SaErrorT snmp_bc_set_slot_state_sensor(void *hnd, struct oh_event *e, SaHpiEntit
 		if ((rdr->RdrType == SAHPI_SENSOR_RDR) && 
 		               (rdr->RdrTypeUnion.SensorRec.Num == BLADECENTER_SENSOR_NUM_SLOT_STATE))
 		{
-			sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, res->ResourceId, rdr->RecordId);
+			sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, 
+								res->ResourceId, rdr->RecordId);
 			sinfo->cur_state = SAHPI_ES_PRESENT;
-			sinfo->cur_child_rid = 	e->u.res_event.entry.ResourceId;
+			sinfo->cur_child_rid = 	e->resource.ResourceId;
 			
 			err = oh_add_rdr(handle->rptcache,
 					 res->ResourceId,
@@ -1683,7 +1690,7 @@ SaErrorT snmp_bc_reset_slot_state_sensor(void *hnd, SaHpiEntityPathT *slot_ep)
 	res = oh_get_resource_by_ep(handle->rptcache, slot_ep);
 
         if (!res) {
-		dbg("No valid resource or rdr at hand. Could not process new rdr.");
+		err("No valid resource or rdr at hand. Could not process new rdr.");
                 return(SA_ERR_HPI_INVALID_DATA);
 	}
 
@@ -1731,15 +1738,16 @@ SaErrorT snmp_bc_set_resource_slot_state_sensor(void *hnd, struct oh_event *e, g
 	struct oh_handler_state *handle;
 	struct snmp_bc_hnd *custom_handle;
 		
-	if (!e || (e->type != OH_ET_RESOURCE) ) 
+	if (!e) 
 		return(SA_ERR_HPI_INVALID_PARAMS);
 
 	handle = (struct oh_handler_state *) hnd;
 	custom_handle = (struct snmp_bc_hnd *)handle->data;				
-	err = snmp_bc_extract_slot_ep( &(e->u.res_event.entry.ResourceEntity), &slot_ep);
+	err = snmp_bc_extract_slot_ep( &(e->resource.ResourceEntity), &slot_ep);
 
 	j = slot_ep.Entry[0].EntityLocation;
-	if ( (custom_handle->platform == SNMP_BC_PLATFORM_BC) || (custom_handle->platform == SNMP_BC_PLATFORM_BCH))
+	if ( (custom_handle->platform == SNMP_BC_PLATFORM_BC) || 
+			(custom_handle->platform == SNMP_BC_PLATFORM_BCH))
 	{
 		for (i = 0; i < resourcewidth; i++) {
 			oh_set_ep_location(&slot_ep,
@@ -1747,7 +1755,8 @@ SaErrorT snmp_bc_set_resource_slot_state_sensor(void *hnd, struct oh_event *e, g
 	
 			err = snmp_bc_set_slot_state_sensor(handle, e, &slot_ep);
 		}
-	} else if (custom_handle->platform == SNMP_BC_PLATFORM_BCT){
+	} else if ( (custom_handle->platform == SNMP_BC_PLATFORM_BCT) || 
+			(custom_handle->platform == SNMP_BC_PLATFORM_BCHT) ){
 		for (i = 0; i < resourcewidth; i++) {
 			oh_set_ep_location(&slot_ep,
 				   slot_ep.Entry[0].EntityType, j - i);
@@ -1790,7 +1799,7 @@ SaErrorT snmp_bc_get_slot_state_sensor(void *hnd,
 	if (rdr == NULL) return(SA_ERR_HPI_NOT_PRESENT);
 	sinfo = (struct SensorInfo *)oh_get_rdr_data(handle->rptcache, rid, rdr->RecordId);
  	if (sinfo == NULL) {
-		dbg("No sensor data. Sensor=%s", rdr->IdString.Data);
+		err("No sensor data. Sensor=%s", rdr->IdString.Data);
 		return(SA_ERR_HPI_INTERNAL_ERROR);
 	}
 					
@@ -1821,7 +1830,7 @@ SaErrorT snmp_bc_reset_resource_slot_state_sensor(void *hnd, SaHpiRptEntryT *res
 	SaErrorT err;
 	guint resourcewidth;
 	SaHpiEntityPathT slot_ep;
-	struct snmp_value get_value;
+
 	struct oh_handler_state *handler;
 	struct snmp_bc_hnd *custom_handler;
 	struct ResourceInfo *res_info_ptr;
@@ -1833,17 +1842,12 @@ SaErrorT snmp_bc_reset_resource_slot_state_sensor(void *hnd, SaHpiRptEntryT *res
 	err = snmp_bc_extract_slot_ep( &(res->ResourceEntity), &slot_ep);
 	res_info_ptr =  (struct ResourceInfo *)oh_get_resource_data(handler->rptcache, res->ResourceId);
 	
-	resourcewidth = 1;
-	if (res_info_ptr->mib.OidResourceWidth != NULL) {
-		err = snmp_bc_oid_snmp_get(custom_handler,  &(res->ResourceEntity), 0,
-					   res_info_ptr->mib.OidResourceWidth, &get_value, SAHPI_TRUE);
-		if (!err && (get_value.type == ASN_INTEGER)) {
-				resourcewidth = get_value.integer;
-		}
-	}			
-
+	resourcewidth = res_info_ptr->resourcewidth;
+	res_info_ptr->resourcewidth = 1;
+	
 	j = slot_ep.Entry[0].EntityLocation;
-	if ( (custom_handler->platform == SNMP_BC_PLATFORM_BC) || (custom_handler->platform == SNMP_BC_PLATFORM_BCH))
+	if ( (custom_handler->platform == SNMP_BC_PLATFORM_BC) || 
+		(custom_handler->platform == SNMP_BC_PLATFORM_BCH))
 	{
 		for (i = 0; i < resourcewidth; i++) {
 			oh_set_ep_location(&slot_ep,
@@ -1851,7 +1855,8 @@ SaErrorT snmp_bc_reset_resource_slot_state_sensor(void *hnd, SaHpiRptEntryT *res
 	
 			err = snmp_bc_reset_slot_state_sensor(handler, &slot_ep);
 		}
-	} else if (custom_handler->platform == SNMP_BC_PLATFORM_BCT){
+	} else if ( (custom_handler->platform == SNMP_BC_PLATFORM_BCT) || 
+			(custom_handler->platform == SNMP_BC_PLATFORM_BCHT) ) {
 		for (i = 0; i < resourcewidth; i++) {
 			oh_set_ep_location(&slot_ep,
 				   slot_ep.Entry[0].EntityType, j - i);
@@ -1878,7 +1883,7 @@ do { \
 			thisOID = SNMP_BC_PD1POWERMIN; \
 			break; \
 		default: \
-			dbg("Not one of the Slot Power Sensors."); \
+			err("Not one of the Slot Power Sensors."); \
 			return(SA_ERR_HPI_INTERNAL_ERROR); \
 			break; \
 	} \
@@ -1898,7 +1903,7 @@ do { \
 			thisOID = SNMP_BC_PD2POWERMIN; \
 			break; \
 		default: \
-			dbg("Not one of the Slot Power Sensors."); \
+			err("Not one of the Slot Power Sensors."); \
 			return(SA_ERR_HPI_INTERNAL_ERROR); \
 			break; \
 	} \
@@ -1958,8 +1963,9 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 			usepowerdomain1;			
 			break;
 			
-		case BLADECENTER_INTERCONNECT_SLOT:
-			if (custom_handle->platform == SNMP_BC_PLATFORM_BCT) {
+		case BLADECENTER_SWITCH_SLOT:
+			if (custom_handle->platform == SNMP_BC_PLATFORM_BCT)  
+			{
 				 switch (slotnum) {
 				 	case 1:
 						oidIndex = 9;
@@ -1975,7 +1981,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 12;
 						break;					
 					default:
-						dbg("Not one of the valid BC-T Swich Slots.");
+						err("Not one of the valid BC-T Swich Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -1998,7 +2004,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 10;
 						break;					
 					default:
-						dbg("Not one of the valid BC Switch Slots.");
+						err("Not one of the valid BC Switch Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2038,7 +2044,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 16;
 						break;
 					default:
-						dbg("Not one of the valid BC H Switch Slots.");
+						err("Not one of the valid BC H Switch Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2046,9 +2052,51 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 					usepowerdomain2;
 				} else {
 					usepowerdomain1;
-				}										
+				}
+			} else if (custom_handle->platform == SNMP_BC_PLATFORM_BCHT) {
+				 switch (slotnum) {
+				 	case 1:
+						oidIndex = 19;
+						break;
+					case 2:
+						oidIndex = 20;
+						break;					
+					case 3:
+						oidIndex = 21;
+						break;					
+					case 4:
+						oidIndex = 22;
+						break;
+					case 5:
+					case 6:
+						/* Reading is not supported on BC-HT*/
+						oidIndex = SNMP_BC_NOT_VALID;
+						thisOID = NULL;
+						break;										
+					case 7:
+						oidIndex = 9;
+						break;
+					case 8:
+						oidIndex = 10;
+						break;
+					case 9:
+						oidIndex = 11;
+						break;
+					case 10:
+						oidIndex = 12;
+						break;
+					default:
+						err("Not one of the valid BC HT Switch Slots.");
+						return(SA_ERR_HPI_INTERNAL_ERROR);
+						break;
+				}
+				if (slotnum > 6){
+					usepowerdomain2;
+				} else if (slotnum < 5) {
+					usepowerdomain1;
+				}														
 			} else { 
-				dbg("Not one of the supported platform.");
+				err("Not one of the supported platform.");
 				return(SA_ERR_HPI_INTERNAL_ERROR);		
 			}
 			break;
@@ -2063,7 +2111,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 8;
 						break;					
 					default:
-						dbg("Not one of the valid BC-T MM Slots.");
+						err("Not one of the valid BC-T MM Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2079,7 +2127,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 6;
 						break;					
 					default:
-						dbg("Not one of the valid BC MM Slots.");
+						err("Not one of the valid BC MM Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2095,14 +2143,30 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 8;
 						break;					
 					default:
-						dbg("Not one of the valid BC H MM Slots.");
+						err("Not one of the valid BC H MM Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
 				
 				usepowerdomain1;
+			} else if (custom_handle->platform == SNMP_BC_PLATFORM_BCHT) {
+				 switch (slotnum) {
+				 	case 1:
+						oidIndex = 17;
+						break;
+					case 2:
+						oidIndex = 18;
+						break;					
+					default:
+						err("Not one of the valid BC HT MM Slots.");
+						return(SA_ERR_HPI_INTERNAL_ERROR);
+						break;
+				}
+				
+				usepowerdomain1;
+			
 			} else { 
-				dbg("Not one of the supported platform.");
+				err("Not one of the supported platform.");
 				return(SA_ERR_HPI_INTERNAL_ERROR);		
 			}
 			break;
@@ -2142,7 +2206,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 							oidIndex = 2;
 						break;					
 					default:
-						dbg("Not one of the valid BC-T Fan Slots.");
+						err("Not one of the valid BC-T Fan Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2165,7 +2229,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 4;
 						break;							
 					default:
-						dbg("Not one of the valid BC Fan Slots.");
+						err("Not one of the valid BC Fan Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2177,9 +2241,12 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 				/* Reading is not supported on BC-H */
 				oidIndex = SNMP_BC_NOT_VALID;
 				thisOID = NULL;
-				
+			} else if (custom_handle->platform == SNMP_BC_PLATFORM_BCHT) {
+				/* pdp - FIX ME - Reading is not supported on BC-H */
+				oidIndex = SNMP_BC_NOT_VALID;
+				thisOID = NULL;			
 			} else { 
-				dbg("Not one of the supported platform.");
+				err("Not one of the supported platform.");
 				return(SA_ERR_HPI_INTERNAL_ERROR);		
 			}
 			break;		
@@ -2212,7 +2279,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 6;
 						break;
 					default:
-						dbg("Not one of the valid BC-T Blade Slots.");
+						err("Not one of the valid BC-T Blade Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2269,7 +2336,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 8;
 						break;
 					default:
-						dbg("Not one of the valid BC Blade Slots.");
+						err("Not one of the valid BC Blade Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2312,7 +2379,7 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 23;
 						break;
 					default:
-						dbg("Not one of the valid BC H Switch Slots.");
+						err("Not one of the valid BC H Switch Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
@@ -2321,16 +2388,66 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 					usepowerdomain2;
 				} else {
 					usepowerdomain1;
-				}										
+				}
+			} else if (custom_handle->platform == SNMP_BC_PLATFORM_BCHT) {
+				 switch (slotnum) {
+				 	case 1:
+						oidIndex = 23;
+						break;
+					case 2:
+						oidIndex = 24;
+						break;					
+					case 3:
+						oidIndex = 25;
+						break;					
+
+					case 4:
+						oidIndex = 26;
+						break;					
+					case 5:
+						oidIndex = 27;
+						break;					
+					case 6:
+						oidIndex = 28;
+						break;					
+					case 7:
+						oidIndex = 13;
+						break;
+					case 8:
+						oidIndex = 14;
+						break;
+					case 9:
+						oidIndex = 15;
+						break;
+					case 10:
+						oidIndex = 16;
+						break;
+					case 11:
+						oidIndex = 17;
+						break;
+					case 12:
+						oidIndex = 18;
+						break;												
+					default:
+						err("Not one of the valid BC H Switch Slots.");
+						return(SA_ERR_HPI_INTERNAL_ERROR);
+						break;
+				}
+				if ( slotnum > 6){		
+					usepowerdomain2;
+				} else {
+					usepowerdomain1;
+				}			
 			} else { 
-				dbg("Not one of the supported platform.");
+				err("Not one of the supported platform.");
 				return(SA_ERR_HPI_INTERNAL_ERROR);		
 			}
 			break;		
 		case BLADECENTER_POWER_SUPPLY_SLOT:
 			if ((custom_handle->platform == SNMP_BC_PLATFORM_BCT) || 
-					 (custom_handle->platform == SNMP_BC_PLATFORM_BC)) {
-				/* Reading is not supported on BC and BC-T */
+					 (custom_handle->platform == SNMP_BC_PLATFORM_BC) ||
+					 (custom_handle->platform == SNMP_BC_PLATFORM_BCHT)) {
+				/* Reading is not supported on BC, BC-T and BC-HT*/
 				oidIndex = SNMP_BC_NOT_VALID;
 				thisOID = NULL;
 							
@@ -2350,23 +2467,24 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 						oidIndex = 6;
 						break;					
 					default:
-						dbg("Not one of the valid BC H Power Module Slots.");
+						err("Not one of the valid BC H Power Module Slots.");
 						return(SA_ERR_HPI_INTERNAL_ERROR);
 						break;
 				}
 				usepowerdomain1;
 			} else { 
-				dbg("Not one of the supported platform.");
+				err("Not one of the supported platform.");
 				return(SA_ERR_HPI_INTERNAL_ERROR);		
 			}
 			break;
 		case SAHPI_ENT_SYS_MGMNT_MODULE:
+			/* Assign Midplane Power reading to Virtual management module */
 			switch (slotnum) {
 				case 0:
 					oidIndex = 1;
 					break;
 				default:
-					dbg("Not one of the valid resources.");
+					err("Not one of the valid resources.");
 					return(SA_ERR_HPI_INTERNAL_ERROR);
 					break;
 				}
@@ -2413,8 +2531,16 @@ SaErrorT snmp_bc_get_slot_power_sensor(void *hnd,
 			usepowerdomain2;
 			snprintf(oid, SNMP_BC_MAX_OID_LENGTH, "%s.%d", thisOID, 24);
 			get_string_object(oid, pm4_state);
+		} else if (custom_handle->platform == SNMP_BC_PLATFORM_BCHT) {
+			usepowerdomain1;
+			snprintf(oid, SNMP_BC_MAX_OID_LENGTH, "%s.%d", thisOID, 29);
+			get_string_object(oid, pm3_state);
+		
+			usepowerdomain2;
+			snprintf(oid, SNMP_BC_MAX_OID_LENGTH, "%s.%d", thisOID, 19);
+			get_string_object(oid, pm4_state);		
 		} else { 
-			dbg("Not one of the supported platform.\n");
+			err("Not one of the supported platform.\n");
 			return(SA_ERR_HPI_INTERNAL_ERROR);		
 		}
 		power_substrs = g_strsplit(pm3_state.string, " ", -1);
@@ -2504,3 +2630,4 @@ void * oh_set_sensor_event_masks (void *, SaHpiResourceIdT, SaHpiSensorNumT,
                                   SaHpiEventStateT,
                                   SaHpiEventStateT)
                 __attribute__ ((weak, alias("snmp_bc_set_sensor_event_masks")));
+
