@@ -10,7 +10,7 @@
  * full licensing terms.
  *
  * Authors:
- *      Renier Morales <renierm@users.sf.net>
+ *      Renier Morales <renier@openhpi.org>
  *	David Judkovics <djudkovi@us.ibm.com>
  *
  */
@@ -73,7 +73,7 @@ SaErrorT snmp_get( void *sessp,
 			} else if ( !(CHECK_END(vars->type)) ) {
 				/* This is one of the exception condition */
 				returncode = SA_ERR_HPI_NOT_PRESENT;
-				trace("Warning: OID=%s gets snmp exception %d \n",objid, vars->type);
+				dbg("Warning: OID=%s gets snmp exception %d \n",objid, vars->type);
 
                     	} else if ( (vars->type == ASN_INTEGER) || 
 				    (vars->type == ASN_COUNTER) || 
@@ -84,14 +84,16 @@ SaErrorT snmp_get( void *sessp,
                         	value->str_len = vars->val_len;
                         	if (value->str_len >= MAX_ASN_STR_LEN)
                                 		value->str_len = MAX_ASN_STR_LEN;
-                        	else value->string[value->str_len] = '\0';
-
-                        	memcpy(value->string, vars->val.string, value->str_len);
+				if (value->str_len > 0)
+                        	    memcpy(value->string, vars->val.string, value->str_len);						
+						
+                        	value->string[value->str_len] = '\0'; /* guarantee NULL terminated string */
+				
                 	}
 
 		} else {
-                        trace("Error in packet %s\nReason: %s\n",
-                               	 objid, snmp_errstring(response->errstat));
+                        dbg("Error in packet %s\nReason: %s\n",
+                            objid, snmp_errstring(response->errstat));
 			returncode = errstat2hpi(response->errstat);
 		}
 
@@ -99,7 +101,7 @@ SaErrorT snmp_get( void *sessp,
                 value->type = (u_char)0x00; 
 		session = snmp_sess_session(sessp);
                 snmp_sess_perror("snmpget", session);
-		trace("OID=%s", objid);
+                dbg("OID %s, error status: %d\n",objid, status);
 		returncode = snmpstat2hpi(status);
         }
 
@@ -155,7 +157,7 @@ SaErrorT snmp_set(
                         break;
                 default:
                         rtncode = SA_ERR_HPI_INVALID_PARAMS;
-                        dbg("datatype %c not yet supported by snmp_set()\n", value.type);
+                        err("datatype %c not yet supported by snmp_set()\n", value.type);
                         break;
         }
 
@@ -248,7 +250,7 @@ SaErrorT snmp_get2(void *sessp,
 			} else if ( !(CHECK_END(vars->type)) ) {
 				/* This is one of the exception condition */
 				returncode = SA_ERR_HPI_NOT_PRESENT;
-				trace("snmp exception %d \n",vars->type);
+				dbg("snmp exception %d \n",vars->type);
 
                     	} else if ( (vars->type == ASN_INTEGER) || 
 				    (vars->type == ASN_COUNTER) || 
@@ -279,7 +281,7 @@ SaErrorT snmp_get2(void *sessp,
 						vars);
 				fprintf(stderr, "********************************************************\n");
 			}  else {
-				dbg("snmp_get2(): No idea.Unknown Type: %X", vars->type);
+				err("snmp_get2(): No idea.Unknown Type: %X", vars->type);
 				fprint_variable(stderr, 
 						vars->name, 
 						vars->name_length, 
@@ -287,7 +289,7 @@ SaErrorT snmp_get2(void *sessp,
 			}		
 #endif
 		} else {
-                       dbg("Error, Reason: %s", 
+                       err("Error, Reason: %s", 
 				snmp_errstring(response->errstat));
 			fprintf(stderr, "objid: ");
 			for(i = 0; i<objid_len; i++ )
@@ -352,7 +354,7 @@ SaErrorT snmp_set2(void *sessp,
                         break;
                 default:
                         rtncode = SA_ERR_HPI_INVALID_PARAMS;
-                        dbg("datatype %c not yet supported by snmp_set2()", 
+                        err("datatype %c not yet supported by snmp_set2()", 
 				value->type);
                         break;
         }
@@ -391,10 +393,10 @@ SaErrorT snmp_set2(void *sessp,
 				if (!(CHECK_END(response->variables->type)) ) {
                                 	/* This is one of the exception condition */
 				        rtncode = SA_ERR_HPI_NOT_PRESENT;
-                                	dbg("snmp exception %d \n",vars->type);
+                                	err("snmp exception %d \n",vars->type);
 				}
 			} else {
-                        	dbg("snmp_set2: Error in packet, Reason: %s",
+                        	err("snmp_set2: Error in packet, Reason: %s",
 						snmp_errstring(response->errstat));
                                 rtncode = errstat2hpi(response->errstat);
 
@@ -494,10 +496,12 @@ SaErrorT errstat2hpi(long pdu_errstat)
 		case SNMP_ERR_NOTWRITABLE:
 			hpicode = SA_ERR_HPI_READ_ONLY;
 			break;		
+		case SNMP_ERR_NOSUCHNAME:
+			hpicode = SA_ERR_HPI_NOT_PRESENT;
+			break;
 		case SNMP_ERR_NOACCESS:
 		case SNMP_ERR_AUTHORIZATIONERROR:
 		case SNMP_ERR_INCONSISTENTNAME:
-		case SNMP_ERR_NOSUCHNAME:
 		case SNMP_ERR_NOCREATION:
 			hpicode = SA_ERR_HPI_INVALID_PARAMS;
 			break;
@@ -527,7 +531,7 @@ SaErrorT snmpstat2hpi(int snmpstat)
 			break;
 		case STAT_ERROR:
 		default:
-			hpicode = SA_ERR_HPI_UNKNOWN;
+			hpicode = SA_ERR_HPI_ERROR;
 			break;
 	}
 	
