@@ -23,7 +23,6 @@
 #include <unistd.h>
 #include <oh_config.h>
 #include <oh_plugin.h>
-#include <oh_domain.h>
 #include <oh_error.h>
 #include <oh_lock.h>
 #include <config.h>
@@ -43,6 +42,7 @@ static const char *known_globals[] = {
         "OPENHPI_PATH",
         "OPENHPI_VARPATH",
         "OPENHPI_CONF",
+	"OPENHPICLIENT_CONF",
         NULL
 };
 
@@ -58,6 +58,7 @@ static struct {
         char path[OH_MAX_TEXT_BUFFER_LENGTH];
         char varpath[OH_MAX_TEXT_BUFFER_LENGTH];
         char conf[OH_MAX_TEXT_BUFFER_LENGTH];
+        char client_conf[OH_MAX_TEXT_BUFFER_LENGTH];	
         unsigned char read_env;
         GStaticRecMutex lock;
 } global_params = { /* Defaults for global params are set here */
@@ -72,6 +73,7 @@ static struct {
         .path = OH_PLUGIN_PATH,
         .varpath = VARPATH,
         .conf = OH_DEFAULT_CONF,
+	.client_conf = OH_CLIENT_DEFAULT_CONF,
         .read_env = 0,
         .lock = G_STATIC_REC_MUTEX_INIT
 };
@@ -82,18 +84,13 @@ static struct {
  */
 static GSList *handler_configs = NULL;
 
-
-/* List of domain configurations. Domains are later created from this list. */
-static GSList *domain_configs = NULL;
-
 /*******************************************************************************
  *  In order to use the glib lexical parser we need to define token
  *  types which we want to switch on
  ******************************************************************************/
 
 enum {
-        HPI_CONF_TOKEN_HANDLER = G_TOKEN_LAST,
-        HPI_CONF_TOKEN_DOMAIN
+        HPI_CONF_TOKEN_HANDLER = G_TOKEN_LAST
 } hpiConfType;
 
 struct tokens {
@@ -105,10 +102,6 @@ static struct tokens oh_conf_tokens[] = {
         {
                 .name = "handler",
                 .token = HPI_CONF_TOKEN_HANDLER
-        },
-        {
-                .name = "domain",
-                .token = HPI_CONF_TOKEN_DOMAIN
         }
 
 };
@@ -211,7 +204,12 @@ static void process_global_param(const char *name, char *value)
                 memset(global_params.conf, 0, OH_MAX_TEXT_BUFFER_LENGTH);
                 strncpy(global_params.conf, value, OH_MAX_TEXT_BUFFER_LENGTH-1);
                 g_static_rec_mutex_unlock(&global_params.lock);
-        } else {
+        } else if (!strcmp("OPENHPICLIENT_CONF", name)) {
+                g_static_rec_mutex_lock(&global_params.lock);
+                memset(global_params.client_conf, 0, OH_MAX_TEXT_BUFFER_LENGTH);
+                strncpy(global_params.client_conf, value, OH_MAX_TEXT_BUFFER_LENGTH-1);
+                g_static_rec_mutex_unlock(&global_params.lock);
+	} else {
                 err("ERROR. Invalid global parameter %s in config file", name);
         }
 
@@ -436,171 +434,6 @@ quit:
         return -1;
 }
 
-/**
- * process_domain_token
- * @scanner: Object parser
- * 
- * Returns: 0 on success.
- **/
-static int process_domain_token(GScanner *scanner)
-{
-	GHashTable *domain_stanza = NULL;
-        char *tablekey, *tablevalue;
-        int found_right_curly = 0;
-        int v_signed = 0;
-
-        data_access_lock();
-
-        if (g_scanner_get_next_token(scanner) != HPI_CONF_TOKEN_DOMAIN) {
-                err("Processing domain: Unexpected token.");
-                data_access_unlock();
-                return -1;
-        }
-
-        /* Get the domain id and store in Hash Table */
-        if (g_scanner_get_next_token(scanner) != G_TOKEN_INT) {
-                err("Processing handler: Expected domain id.");
-                data_access_unlock();
-                return -1;
-        } else {
-                if ((SaHpiDomainIdT)scanner->value.v_int == SAHPI_UNSPECIFIED_DOMAIN_ID) {
-                        err("Processing domain: value for id cannot be SAHPI_UNSPECIFIED_DOMAIN_ID (4294967295).");
-                        return -1;
-                }
-                SaHpiDomainIdT *id = (SaHpiDomainIdT *)g_malloc0(sizeof(SaHpiDomainIdT));
-                *id = (SaHpiDomainIdT)scanner->value.v_int;
-                domain_stanza = g_hash_table_new_full(g_str_hash, g_str_equal,
-                                                      g_free, g_free);
-                tablekey = g_strdup("id");
-                tablevalue = (gpointer)id;
-                g_hash_table_insert(domain_stanza,
-                                    (gpointer)tablekey,
-                                    (gpointer)tablevalue);
-        }
-
-        /* Check for Left Brace token type. If we have it, then continue parsing. */
-        if (g_scanner_get_next_token(scanner) != G_TOKEN_LEFT_CURLY) {
-                err("Processing domain: Expected left curly token.");
-                goto free_table;
-        }
-
-        while (!found_right_curly) {
-                int current_token;
-                /* get key token in key\value pair set (e.g. key = value) */
-                if (g_scanner_get_next_token(scanner) != G_TOKEN_STRING) {
-                        err("Processing domain: Expected string token.");
-                        goto free_table;
-                } else {
-                        tablekey = g_strdup(scanner->value.v_string);
-                }
-
-                /* Check for the equal sign next. If we have it, continue parsing */
-                if (g_scanner_get_next_token(scanner) != G_TOKEN_EQUAL_SIGN) {
-                        err("Processing domain: Expected equal sign token.");
-                        goto free_table_and_key;
-                }
-
-                /*
-                 * Now check for the value token in the key\value set.
-                 * Store the key\value value pair in the hash table and continue on.
-                 */
-                current_token = g_scanner_get_next_token(scanner);
-                if (strcmp("entity_pattern", tablekey) == 0 || /* Required */
-                    strcmp("tag", tablekey) == 0) { /* Optional */
-                        if (current_token != G_TOKEN_STRING) {
-                                err("Processing domain: value for %s is not a string!", tablekey);
-                                goto free_table_and_key;
-                        }
-                } else if (strcmp("child_of", tablekey) == 0 || /* Optional. 0 means default domain. */
-                           strcmp("peer_of", tablekey) == 0 || /* Optional. 0 means default domain. */
-                           strcmp("ai_readonly", tablekey) == 0) { /* Optional. 1 (default) means yes, 0 means no */
-                        if (current_token != G_TOKEN_INT) {
-                                err("Processing domain: value for %s is not a valid integer!", tablekey);
-                                goto free_table_and_key;
-                        }
-                } else if (strcmp("ai_timeout", tablekey) == 0) { /* Optional. 0 (default) is IMMEDIATE. -1 is BLOCK. In seconds. */
-                        if (current_token == '-') {
-                            v_signed = 1;
-                            current_token = g_scanner_get_next_token(scanner);
-                        }
-
-                        if (current_token != G_TOKEN_INT &&
-                            current_token != G_TOKEN_FLOAT) {
-                                err("Processing domain: Invalid value for %s!", tablekey);
-                                goto free_table_and_key;
-                        }
-                } else {
-                        dbg("Dropping unknown name/value pair. going on to next.");
-                        g_free(tablekey);
-                        goto find_right_curly;
-                }
-
-                /* The type of token tells us how to fetch the value from scanner */
-                gpointer value = NULL;
-                if (current_token == G_TOKEN_INT) {
-                        gulong *value_int =
-                                (gulong *)g_malloc(sizeof(gulong));
-                        *value_int = (gulong)scanner->value.v_int;
-                        if (v_signed) {
-                                *value_int = -(*value_int);
-                                v_signed = 0;
-                        }
-                        value = (gpointer)value_int;
-                } else if (current_token == G_TOKEN_FLOAT) {
-                        gdouble *value_double =
-                                (gdouble *)g_malloc(sizeof(gdouble));
-                        *value_double = (gdouble)scanner->value.v_float;
-                        value = (gpointer)value_double;
-                } else if (current_token == G_TOKEN_STRING) {
-                        gchar *value_string =
-                                        g_strdup(scanner->value.v_string);
-                        value = (gpointer)value_string;
-                }
-
-                if (!value) {
-                        err("Processing domain:"
-                            " Unable to extract value."
-                            " Token Type: %d",
-                            current_token);
-                        goto free_table_and_key;
-                } else {
-                        g_hash_table_insert(domain_stanza,
-                                            (gpointer)tablekey,
-                                            value);
-                }
-                
-find_right_curly:
-                if (g_scanner_peek_next_token(scanner) == G_TOKEN_RIGHT_CURLY) {
-                        g_scanner_get_next_token(scanner);
-                        found_right_curly = 1;
-                }
-        } /* end of while(!found_right_curly) */
-
-        /* Attach table describing handler stanza to the global linked list of handlers */
-        if (domain_stanza != NULL) {
-                domain_configs = g_slist_append(
-                        domain_configs,
-                        (gpointer)domain_stanza);
-        }
-
-        data_access_unlock();
-
-        return 0;
-
-free_table_and_key:
-        g_free(tablekey);
-free_table:
-        /**
-        There was an error reading a token so we need to error out,
-        but not before cleaning up. Destroy the table.
-        */
-        g_hash_table_destroy(domain_stanza);
-
-        data_access_unlock();
-
-        return -1;
-}
-
 /**
  * scanner_msg_handler: a reference of this function is passed into the GScanner.
  * Used by the GScanner object to output messages that come up during parsing.
@@ -680,9 +513,6 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
                 case HPI_CONF_TOKEN_HANDLER:
                         process_handler_token(oh_scanner);
                         break;
-                case HPI_CONF_TOKEN_DOMAIN:
-                        process_domain_token(oh_scanner);
-                        break;
                 case G_TOKEN_STRING:
                         process_global_token(oh_scanner);
                         break;
@@ -710,10 +540,8 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
         dbg("Done processing conf file.\nNumber of parse errors:%d", done);
 
         config->handler_configs = handler_configs;
-	config->domain_configs = domain_configs;
 
         handler_configs = NULL;
-	domain_configs = NULL;
 
         return 0;
 }
@@ -752,21 +580,6 @@ SaErrorT oh_process_config(struct oh_parsed_config *config)
                 config->handlers_defined++;
         }
 
-        /* Initialize domains */
-        for (node = config->domain_configs; node; node = node->next) {
-                GHashTable *domain_config = (GHashTable *)node->data;
-                SaHpiDomainIdT *did =
-                        (SaHpiDomainIdT *)g_hash_table_lookup(domain_config, "id");
-                if (*did == 0) config->default_domain = TRUE;
-                if (!oh_create_domain_from_table(domain_config)) {
-                        dbg("Created domain %u", *did);
-                        config->domains_loaded++;
-                } else {
-                        err("Couldn't load domain %u", (did) ? *did : 999999);
-                }
-                config->domains_defined++;
-        }
-
         return SA_OK;
 }
 
@@ -775,12 +588,6 @@ void oh_clean_config(struct oh_parsed_config *config)
         /* Free list of handler configuration blocks */
         g_slist_free(config->handler_configs);
 
-        /* Free list of domain configuration blocks */
-        GSList *node = NULL;
-        for (node = config->domain_configs; node; node = node->next) {
-                g_hash_table_destroy((GHashTable *)node->data);
-        }
-        g_slist_free(config->domain_configs);
 }
 
 /**
@@ -854,7 +661,14 @@ int oh_get_global_param(struct oh_global_param *param)
                                 OH_MAX_TEXT_BUFFER_LENGTH);
                         g_static_rec_mutex_unlock(&global_params.lock);
                         break;
-                default:
+                case OPENHPICLIENT_CONF:
+                        g_static_rec_mutex_lock(&global_params.lock);
+                        strncpy(param->u.conf,
+                                global_params.client_conf,
+                                OH_MAX_TEXT_BUFFER_LENGTH);
+                        g_static_rec_mutex_unlock(&global_params.lock);
+                        break;
+               default:
                         err("ERROR. Invalid global parameter %d!", param->type);
                         return -2;
         }
@@ -928,6 +742,14 @@ int oh_set_global_param(struct oh_global_param *param)
                                 OH_MAX_TEXT_BUFFER_LENGTH-1);
                         g_static_rec_mutex_unlock(&global_params.lock);
                         break;
+                case OPENHPICLIENT_CONF:
+                        g_static_rec_mutex_lock(&global_params.lock);
+                        memset(global_params.conf, 0, OH_MAX_TEXT_BUFFER_LENGTH);
+                        strncpy(global_params.client_conf,
+                                param->u.conf,
+                                OH_MAX_TEXT_BUFFER_LENGTH-1);
+                        g_static_rec_mutex_unlock(&global_params.lock);
+                        break;			
                 default:
                         err("ERROR. Invalid global parameter %d!", param->type);
                         return -2;
