@@ -1,6 +1,6 @@
 /*      -*- linux-c -*-
  *
- * (C) Copright IBM Corp 2004
+ * (C) Copright IBM Corp 2004,2006
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -10,156 +10,39 @@
  * full licensing terms.
  *
  * Authors:
- *     Renier Morales <renierm@users.sourceforge.net>
+ *     Renier Morales <renier@openhpi.org>
  */
 
 #include <oHpi.h>
 #include <oh_config.h>
 #include <oh_init.h>
 #include <oh_plugin.h>
+#include <oh_event.h>
+#include <oh_domain.h>
+#include <oh_session.h>
+#include <oh_utils.h>
 #include <oh_error.h>
 #include <oh_lock.h>
+#include <sahpimacros.h>
 #include <config.h>
-/* Version Call */
+
 
 /**
  * oHpiVersionGet
  *
- * Returns the version of the library as an SaHpiUint64T.  The version
- * consists of 4 16 bit ints, MAJOR, MINOR, PATCH, and TYPE.  TYPE
- * is used to determine if this is the stand alone library or the client library.
+ * Returns the version of the library as a SaHpiUint64T type.
+ * The version consists of 3 16-bit integers: MAJOR, MINOR, and PATCH.
  */
 
 SaHpiUint64T oHpiVersionGet()
 {
         SaHpiUint64T v = 0;
-        char * version = VERSION;
-        char * start = version;
-        char * end = version;
 
-        v += (strtoull(start, &end, 10) << 48);
-        end++;
-        start = end;
-        v += (strtoull(start, &end, 10) << 32);
-        end++;
-        start = end;
-        v += (strtoull(start, &end, 10) << 16);
+	OHPI_VERSION_GET(v, VERSION);
+
         return v;
 }
 
-/* Plugin operations */
-
-/**
- * oHpiPluginLoad
- * @name: IN. String. name of plugin to load (e.g. "libdummy")
- *
- * Loads plugin into library creating a plugin object.
- *
- * Returns: SA_OK on success. Minus SA_OK on error.
- **/
-SaErrorT oHpiPluginLoad(char *name)
-{
-        if (!name) {
-                dbg("Invalid parameters.");
-                return SA_ERR_HPI_INVALID_PARAMS;
-        }
-        
-        if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
-
-        if (oh_load_plugin(name))
-                return SA_ERR_HPI_ERROR;
-
-        return SA_OK;
-}
-
-/**
- * oHpiPluginUnload
- * @name: IN. String. name of plugin to unload (e.g. "libdummy")
- *
- * Unload plugin from library, destroying the plugin object.
- * This will return an error if there are any handlers referencing
- * the plugin (e.g. refcount > 1).
- *
- * Returns: SA_OK on success. Minus SA_OK on error.
- **/
-SaErrorT oHpiPluginUnload(char *name)
-{
-        if (!name) {
-                dbg("Invalid parameters.");
-                return SA_ERR_HPI_INVALID_PARAMS;
-        }
-        
-        if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
-
-        if (oh_unload_plugin(name))
-                return SA_ERR_HPI_ERROR;
-
-        return SA_OK;
-}
-
-/**
- * oHpiPluginInfo
- * @name: IN. String. name of plugin to query (e.g. "libdummy")
- * @info: IN/OUT. Reference to information structure on the plugin.
- *
- * Fetches the information associated with the plugin and puts it
- * in @info. As of yet, @info only contains the refcount for the
- * plugin.
- *
- * Returns: SA_OK on success. Minus SA_OK on error.
- **/
-SaErrorT oHpiPluginInfo(char *name, oHpiPluginInfoT *info)
-{
-        struct oh_plugin *p = NULL;
-
-        if (!name || !info) {
-                dbg("Invalid parameters.");
-                return SA_ERR_HPI_INVALID_PARAMS;
-        }
-        
-        if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
-
-        p = oh_get_plugin(name);
-        if (!p) {
-                dbg("Plugin %s not found.", name);
-                return SA_ERR_HPI_NOT_PRESENT;
-        }
-
-        info->refcount = p->handler_count;
-        oh_release_plugin(p);
-
-        return SA_OK;
-}
-
-/**
- * oHpiPluginGetNext
- * @name: IN. String. name of plugin to search for (e.g. "libdummy")
- * @next_name: IN/OUT. Next plugin after @name will be placed here.
- * @size: IN. Size in bytes of the @next_name buffer.
- *
- * Searches for the specified plugin and returns the next plugin name
- * after that one in the list. If you pass NULL in @name, you will get
- * the name of the first plugin in @next_name. Used to iterate through
- * all loaded plugins.
- *
- * Returns: SA_OK on success. Minus SA_OK on error.
- **/
-SaErrorT oHpiPluginGetNext(char *name, char *next_name, int size)
-{
-        if (!next_name) {
-                dbg("Invalid parameters.");
-                return SA_ERR_HPI_INVALID_PARAMS;
-        }
-        
-        if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
-
-        if (oh_getnext_plugin_name(name, next_name, size))
-                return SA_ERR_HPI_NOT_PRESENT;
-
-        return SA_OK;
-}
-
-
 /* Handler operations */
 
 /**
@@ -172,28 +55,25 @@ SaErrorT oHpiPluginGetNext(char *name, char *next_name, int size)
  * @config needs to have an entry for "plugin" in order to know for which
  * plugin the handler is being created.
  *
- * Returns: SA_OK on success. Minus SA_OK on error.
+ * Returns: SA_OK on success. SA_ERR_HPI_INTERNAL_ERROR if a handler is
+ * created, but failed to open. oHpiHandlerRetry can be used to retry
+ * opening the handler.
  **/
 SaErrorT oHpiHandlerCreate(GHashTable *config,
                            oHpiHandlerIdT *id)
 {
-        oHpiHandlerIdT hid = 0;
+	SaErrorT error = SA_OK;
 
         if (!config || !id) {
-                dbg("Invalid parameters.");
+                err("Invalid parameters.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
         
-        if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
+        if (oh_init()) return SA_ERR_HPI_ERROR;
 
-        if (!(hid = oh_create_handler(config))) {
-             *id = 0;
-             return SA_ERR_HPI_ERROR;
-        }
+	error = oh_create_handler(config, id);
 
-        *id = hid;
-
-        return SA_OK;
+	return error;
 }
 
 /**
@@ -237,11 +117,18 @@ SaErrorT oHpiHandlerInfo(oHpiHandlerIdT id, oHpiHandlerInfoT *info)
 
         h = oh_get_handler(id);
         if (!h) {
-                dbg("Handler %d not found.", id);
+                err("Handler %d not found.", id);
                 return SA_ERR_HPI_NOT_PRESENT;
         }
 
+	info->id = id;
         strncpy(info->plugin_name, h->plugin_name, MAX_PLUGIN_NAME_LENGTH);
+	oh_encode_entitypath((const char *)g_hash_table_lookup(h->config, "entity_root"),
+			     &info->entity_root);
+	
+	if (!h->hnd) info->load_failed = 1;
+	else info->load_failed = 0;
+
         oh_release_handler(h);
 
         return SA_OK;
@@ -262,7 +149,7 @@ SaErrorT oHpiHandlerInfo(oHpiHandlerIdT id, oHpiHandlerInfoT *info)
 SaErrorT oHpiHandlerGetNext(oHpiHandlerIdT id, oHpiHandlerIdT *next_id)
 {
         if (!next_id) {
-                dbg("Invalid parameters.");
+                err("Invalid parameters.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
         
@@ -274,6 +161,83 @@ SaErrorT oHpiHandlerGetNext(oHpiHandlerIdT id, oHpiHandlerIdT *next_id)
         return SA_OK;
 }
 
+/**
+ * oHpiHandlerFind
+ * @sid: a valid session id
+ * @rid: resource id
+ * @id: pointer where handler id found will be placed.
+ *
+ * Inputs are the @sid and @rid. @rid corresponds to some resource available
+ * in that session. The function then will return the handler that served such
+ * resource.
+ *
+ * Returns: SA_OK if handler was found.
+ **/
+SaErrorT oHpiHandlerFind(SaHpiSessionIdT sid,
+			 SaHpiResourceIdT rid,
+			 oHpiHandlerIdT *id)
+{
+	SaHpiDomainIdT did;
+        struct oh_domain *d = NULL;
+        unsigned int *hid = NULL;
+
+        OH_CHECK_INIT_STATE(sid);
+        OH_GET_DID(sid, did);
+
+        if (sid == 0 || rid == 0 || !id) {
+                return SA_ERR_HPI_INVALID_PARAMS;
+        }
+
+        if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
+
+        OH_GET_DOMAIN(did, d); /* Lock domain */
+
+        hid = (unsigned int *)oh_get_resource_data(&d->rpt, rid);
+
+        if (hid == NULL) {
+                err("No such Resource Id %d in Domain %d", rid, did);
+                oh_release_domain(d); /* Unlock domain */
+                return SA_ERR_HPI_INVALID_RESOURCE;
+        }
+
+        *id = *hid;
+        oh_release_domain(d); /* Unlock domain */
+
+        return SA_OK;
+}
+
+/**
+ * oHpiHandlerRetry
+ * @id: handler id
+ *
+ * Returns: SA_OK if handler opens successfully.
+ **/
+SaErrorT oHpiHandlerRetry(oHpiHandlerIdT id)
+{
+	struct oh_handler *h = NULL;
+	SaErrorT error = SA_OK;
+
+	if (id == 0) return SA_ERR_HPI_INVALID_PARAMS;
+
+        if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
+
+	h = oh_get_handler(id);
+	if (!h) return SA_ERR_HPI_NOT_PRESENT;
+
+	if (h->hnd != NULL) {
+		oh_release_handler(h);
+		return SA_OK;
+	}
+
+	h->hnd = h->abi->open(h->config, h->id, &oh_process_q);
+	if (h->hnd == NULL) error = SA_ERR_HPI_INTERNAL_ERROR;
+	else error = SA_OK;
+
+	oh_release_handler(h);
+
+	return error;
+}
+
 /* Global parameters */
 
 /**
@@ -289,7 +253,7 @@ SaErrorT oHpiGlobalParamGet(oHpiGlobalParamT *param)
         struct oh_global_param p;
 
         if (!param || !param->Type) {
-                dbg("Invalid parameters. oHpiGlobalParamGet()");
+                err("Invalid parameters. oHpiGlobalParamGet()");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
         
@@ -319,7 +283,7 @@ SaErrorT oHpiGlobalParamSet(oHpiGlobalParamT *param)
         struct oh_global_param p;
 
         if (!param || !param->Type) {
-                dbg("Invalid parameters. oHpiGlobalParamSet()");
+                err("Invalid parameters. oHpiGlobalParamSet()");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
         
@@ -334,3 +298,61 @@ SaErrorT oHpiGlobalParamSet(oHpiGlobalParamT *param)
         return SA_OK;
 }
 
+/**
+ * oHpiInjectEvent
+ * @id: id of handler into which the event will be injected.
+ * @event: pointer to the event to be injected.
+ * @rpte: pointer to the resource to be injected.
+ * @rdrs: pointer to the list of RDRs to be injected along with @resoruce
+ *
+ * @id and @event are required parameters. @rpte is only required if the event
+ * is of RESOURCE type or HOTSWAP type. @rdrs is an optional argument in all
+ * cases and can be NULL. If @rdrs is passed, it will be copied. It is the
+ * responsibility of the caller to clean up the RDRs list once it is used here.
+ *
+ * Returns: SA_OK on success. This call will set the event.Source, rpte.ResourceId,
+ * rpte.ResourceEntity so that the caller knows what the final assigned values were.
+ * For rpte.ResourceEntity, the entity_root configuration parameter for the plugin
+ * is used to complete it. In addition, for each rdr in @rdrs, a Num, RecordId,
+ * and Entity will be assigned. This will also be reflected in the passed @rdrs
+ * list so that the caller can know what the assigned values were.
+ **/
+SaErrorT oHpiInjectEvent(oHpiHandlerIdT id,
+                         SaHpiEventT *event,
+                         SaHpiRptEntryT *rpte,
+                         SaHpiRdrT *rdr)
+{
+	SaErrorT (*inject_event)(void *hnd,
+                            	 SaHpiEventT *evt,
+                            	 SaHpiRptEntryT *rpte,
+                                 SaHpiRdrT *rdr); /* TODO: Allow for an array/list of RDRs */
+
+	struct oh_handler *h = NULL;
+	SaErrorT error = SA_OK;
+
+	if (!id) {
+		err("Invalid handler id %d passed",id);
+		return SA_ERR_HPI_INVALID_PARAMS;
+	} else if (!event) {
+		err("Invalid NULL event passed");
+		return SA_ERR_HPI_INVALID_PARAMS;
+	}
+
+	if (oh_init()) return SA_ERR_HPI_INTERNAL_ERROR;
+
+	h = oh_get_handler(id);
+	inject_event = h ? h->abi->inject_event : NULL;
+        if (!inject_event) {
+                oh_release_handler(h);
+                return SA_ERR_HPI_INVALID_CMD;
+        }
+
+	error = inject_event(h->hnd, event, rpte, rdr);
+        if (error) {
+                err("Event injection into handler %d failed", id);
+        }
+
+        oh_release_handler(h);
+        return error;
+}
+
