@@ -10,7 +10,7 @@
  * full licensing terms.
  *
  * Authors:
- *      Renier Morales <renierm@users.sf.net>
+ *      Renier Morales <renier@openhpi.org>
  */
 
 #ifndef __RPT_UTILS_H
@@ -44,15 +44,16 @@ typedef struct {
 /* General RPT calls */
 SaErrorT oh_init_rpt(RPTable *table);
 SaErrorT oh_flush_rpt(RPTable *table);
-void rpt_diff(RPTable *cur_rpt, RPTable *new_rpt,
-              GSList **res_new, GSList **rdr_new,
-              GSList **res_gone, GSList **rdr_gone);
+SaErrorT rpt_diff(RPTable *cur_rpt, RPTable *new_rpt,
+                  GSList **res_new, GSList **rdr_new,
+                  GSList **res_gone, GSList **rdr_gone);
 SaErrorT oh_get_rpt_info(RPTable *table,
                          SaHpiUint32T *update_count,
                          SaHpiTimeT *update_timestamp);
 
 /* Resource calls */
-SaErrorT oh_add_resource(RPTable *table, SaHpiRptEntryT *entry, void *data, int owndata);
+SaErrorT oh_add_resource(RPTable *table, SaHpiRptEntryT *entry,
+                         void *data, int owndata);
 
 SaErrorT oh_remove_resource(RPTable *table, SaHpiResourceIdT rid);
 
@@ -62,16 +63,26 @@ SaHpiRptEntryT *oh_get_resource_by_ep(RPTable *table, SaHpiEntityPathT *ep);
 SaHpiRptEntryT *oh_get_resource_next(RPTable *table, SaHpiResourceIdT rid_prev);
 
 /* RDR calls */
-SaErrorT oh_add_rdr(RPTable *table, SaHpiResourceIdT rid, SaHpiRdrT *rdr, void *data, int owndata);
+SaErrorT oh_add_rdr(RPTable *table, SaHpiResourceIdT rid, SaHpiRdrT *rdr,
+                    void *data, int owndata);
 
-SaErrorT oh_remove_rdr(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT rdrid);
+SaErrorT oh_remove_rdr(RPTable *table, SaHpiResourceIdT rid,
+                       SaHpiEntryIdT rdrid);
 
-void *oh_get_rdr_data(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT rdrid);
-SaHpiRdrT *oh_get_rdr_by_id(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT rdrid);
+void *oh_get_rdr_data(RPTable *table, SaHpiResourceIdT rid,
+                      SaHpiEntryIdT rdrid);
+SaHpiRdrT *oh_get_rdr_by_id(RPTable *table, SaHpiResourceIdT rid,
+                            SaHpiEntryIdT rdrid);
 SaHpiRdrT *oh_get_rdr_by_type(RPTable *table, SaHpiResourceIdT rid,
                               SaHpiRdrTypeT type, SaHpiInstrumentIdT num);
-SaHpiRdrT *oh_get_rdr_next(RPTable *table, SaHpiResourceIdT rid, SaHpiEntryIdT rdrid_prev);
-SaHpiUint32T get_rdr_uid(SaHpiRdrTypeT type, SaHpiInstrumentIdT num);
+SaHpiRdrT *oh_get_rdr_next(RPTable *table, SaHpiResourceIdT rid,
+                           SaHpiEntryIdT rdrid_prev);
+SaHpiRdrT *oh_get_rdr_by_type_first(RPTable *table, SaHpiResourceIdT rid,
+                                    SaHpiRdrTypeT type);
+SaHpiRdrT *oh_get_rdr_by_type_next(RPTable *table, SaHpiResourceIdT rid,
+                                   SaHpiRdrTypeT type, SaHpiInstrumentIdT num);
+SaHpiUint32T oh_get_rdr_uid(SaHpiRdrTypeT type, SaHpiInstrumentIdT num);
+SaHpiInstrumentIdT oh_get_rdr_num(SaHpiEntryIdT rdrid);
 
 
 #ifdef __cplusplus
