@@ -66,7 +66,7 @@ int main(int argc, char **argv)
 
         	retc = oh_el_append(el, &event, NULL, NULL);
         	if (retc != SA_OK) {
-              	dbg("ERROR: oh_el_append failed.");
+              	err("ERROR: oh_el_append failed.");
                	return 1;
         	}       
 	}
@@ -74,20 +74,20 @@ int main(int argc, char **argv)
        /* save the EL to file */
         retc = oh_el_map_to_file(el, "./elTest.data");
         if (retc != SA_OK) {
-                dbg("ERROR: oh_el_map_to_file failed.");
+                err("ERROR: oh_el_map_to_file failed.");
                 return 1;
         }
 
         /* get EL from file (el2) */
         retc = oh_el_map_from_file(el2, "./elTest.data");
 	if (retc != SA_OK) {
-                dbg("ERROR: oh_el_map_from_file failed.");
+                err("ERROR: oh_el_map_from_file failed.");
                 return 1;
         }
 
 
         if(g_list_length(el->list) != g_list_length(el2->list)) {
-                 dbg("ERROR: el->list != el2->list.");
+                 err("ERROR: el->list != el2->list.");
                  return 1;
          }
 
@@ -95,7 +95,7 @@ int main(int argc, char **argv)
         /* close the el */
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                dbg("ERROR: oh_el_close failed.");
+                err("ERROR: oh_el_close failed.");
                 return 1;
         }
 
