@@ -61,7 +61,7 @@ int main(int argc, char **argv)
 
         retc = oh_el_append(el, &event, NULL, NULL);
         if (retc == SA_OK) {
-                dbg("ERROR: oh_el_append failed.");
+                err("ERROR: oh_el_append failed.");
                 return 1;
         }  
 	
@@ -69,7 +69,7 @@ int main(int argc, char **argv)
 	/* close el */
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                dbg("ERROR: oh_el_close on el failed.");
+                err("ERROR: oh_el_close on el failed.");
                 return 1;
         }
 
