@@ -46,7 +46,7 @@ int main(int argc, char **argv)
 
 	retc = oh_el_clear(el);
         if (retc == SA_OK) {
-                dbg("ERROR: el clear failed.");
+                err("ERROR: el clear failed.");
                 return 1;
         }
 
