@@ -48,14 +48,14 @@ int main(int argc, char **argv)
 
  	retc = oh_el_setgentimestampflag(el, flag);
         if (retc != SA_OK) {
-        	dbg("ERROR: oh_el_get failed.");
+        	err("ERROR: oh_el_get failed.");
         	return 1;
         }
 
 	/* close el */
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                dbg("ERROR: oh_el_close on el failed.");
+                err("ERROR: oh_el_close on el failed.");
                 return 1;
         }
 
