@@ -49,7 +49,7 @@ int main(int argc, char **argv)
 	el = oh_el_create(20);
 	retc = oh_el_map_from_file(el, "./elTest.data");
 	if (retc != SA_OK) {
-                dbg("ERROR: oh_el_map_from_file failed.");
+                err("ERROR: oh_el_map_from_file failed.");
                 return 1;
         }
 
@@ -57,14 +57,14 @@ int main(int argc, char **argv)
 
  	retc = oh_el_get(el, entry->event.EntryId, NULL, &next, &entry);
         if (retc == SA_OK) {
-        	dbg("ERROR: oh_el_get failed.");
+        	err("ERROR: oh_el_get failed.");
         	return 1;
         }
 	
         /* close el */
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                dbg("ERROR: oh_el_close on el failed.");
+                err("ERROR: oh_el_close on el failed.");
                 return 1;
         }
 
