@@ -50,14 +50,14 @@ int main(int argc, char **argv)
 
         retc = oh_el_info(el, NULL);
         if (retc == SA_OK) {
-                dbg("ERROR: oh_el_info failed.");
+                err("ERROR: oh_el_info failed.");
                 return 1;
         }
 
         /* close el without saving to file*/
         retc = oh_el_close(el);
         if (retc != SA_OK) {
-                dbg("ERROR: oh_el_close on el failed.");
+                err("ERROR: oh_el_close on el failed.");
                 return 1;
         }
 
